@@ -3,6 +3,7 @@
  * Osmo - a handy personal organizer
  *
  * Copyright (C) 2007 Tomasz Maka <pasp@users.sourceforge.net>
+ *           (C) 2007 Piotr Maka <silloz@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,19 +20,10 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-
-#include <stdio.h>
-#include <string.h>
-#include <glib/gprintf.h>
-#include <glib.h>
-#include <time.h>
-#include <ctype.h>
-
+#include "calendar_calc.h"
 #include "i18n.h"
 #include "calendar.h"
-#include "calendar_calc.h"
-#include "time_utils.h"
-#include "date_utils.h"
+#include "calendar_utils.h"
 #include "options_prefs.h"
 #include "stock_icons.h"
 #include "gui_utils.h"
@@ -226,19 +218,14 @@ gint days, weeks;
 guint64 hours, minutes, seconds;
 gchar tmpbuf[BUFFER_SIZE];
 
-    date_from.year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton_start_year));
-    date_from.month = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton_start_month)) - 1;
-    date_from.day = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton_start_day));
-    time_from.hour = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton_start_hour));
-    time_from.minute = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton_start_minute));
-    time_from.second = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton_start_second));
-    days = (gint)get_number_of_days_in_month (date_from.month, date_from.year);
+    date_from.year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_year));
+    date_from.month = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_month)) - 1;
+    date_from.day = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_day));
+    time_from.hour = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_hour));
+    time_from.minute = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_minute));
+    time_from.second = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_start_second));
+
+    days = g_date_get_days_in_month (date_from.month + 1, date_from.year);
     if (date_from.day > days) {
         date_from.day = days;
         gui_change_bg_widget_state (appGUI->cal->spinbutton_start_day, COLOR_BG_FAIL, appGUI);
@@ -246,19 +233,14 @@ gchar tmpbuf[BUFFER_SIZE];
         gui_change_bg_widget_state (appGUI->cal->spinbutton_start_day, NULL, appGUI);
     }
 
-    date_to.year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton_end_year));
-    date_to.month = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton_end_month)) - 1;
-    date_to.day = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton_end_day));
-    time_to.hour = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton_end_hour));
-    time_to.minute = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton_end_minute));
-    time_to.second = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton_end_second));
-    days = (gint)get_number_of_days_in_month (date_to.month, date_to.year);
+    date_to.year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_end_year));
+    date_to.month = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_end_month)) - 1;
+    date_to.day = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_end_day));
+    time_to.hour = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_end_hour));
+    time_to.minute = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_end_minute));
+    time_to.second = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton_end_second));
+
+    days = g_date_get_days_in_month (date_to.month + 1, date_to.year);
     if (date_to.day > days) {
         date_to.day = days;
         gui_change_bg_widget_state (appGUI->cal->spinbutton_end_day, COLOR_BG_FAIL, appGUI);
@@ -271,19 +253,19 @@ gchar tmpbuf[BUFFER_SIZE];
     if (days == -1)
         days = calculate_date_time_diff (date_to, time_to, date_from, time_from, &date_diff, &time_diff);
 
-    sprintf (tmpbuf, "<big>%d %s, %d %s, %d %s</big>",
+    g_snprintf (tmpbuf, BUFFER_SIZE, "<big>%d %s, %d %s, %d %s</big>",
         date_diff.year, ngettext ("year", "years", date_diff.year),
         date_diff.month, ngettext ("month", "months", date_diff.month),
         date_diff.day, ngettext ("day", "days", date_diff.day));
     gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_result_1), tmpbuf);
 
-    sprintf (tmpbuf, "<big>%d %s, %d %s, %d %s</big>",
+    g_snprintf (tmpbuf, BUFFER_SIZE, "<big>%d %s, %d %s, %d %s</big>",
         time_diff.hour, ngettext ("hour", "hours", time_diff.hour),
         time_diff.minute, ngettext ("minute", "minutes", time_diff.minute),
         time_diff.second, ngettext ("second", "seconds", time_diff.second));
     gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_result_1_2), tmpbuf);
 
-    sprintf (tmpbuf, "<small>(%s: %d %s, %d %s, %d %s, %d %s)</small>",
+    g_snprintf (tmpbuf, BUFFER_SIZE, "<small>(%s: %d %s, %d %s, %d %s, %d %s)</small>",
         _("or"),
         days, ngettext ("day", "days", days),
         time_diff.hour, ngettext ("hour", "hours", time_diff.hour),
@@ -319,35 +301,22 @@ guint32 julian;
 gchar timebuf[BUFFER_SIZE];
 gchar tmpbuf[BUFFER_SIZE];
 
-    year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton2_start_year));
-    month = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton2_start_month)) - 1;
-    day = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton2_start_day));
-    hour = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton2_start_hour));
-    minute = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton2_start_minute));
-    second = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton2_start_second));
+    year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton2_start_year));
+    month = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton2_start_month)) - 1;
+    day = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton2_start_day));
+    hour = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton2_start_hour));
+    minute = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton2_start_minute));
+    second = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton2_start_second));
 
-    year2 = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton2_end_year));
-    month2 = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton2_end_month));
-    week2 = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton2_end_week));
-    day2 = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton2_end_day));
-    hour2 = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton2_end_hour));
-    minute2 = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton2_end_minute));
-    second2 = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton2_end_second));
+    year2 = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton2_end_year));
+    month2 = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton2_end_month));
+    week2 = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton2_end_week));
+    day2 = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton2_end_day));
+    hour2 = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton2_end_hour));
+    minute2 = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton2_end_minute));
+    second2 = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->spinbutton2_end_second));
 
-    if (day > (gint)get_number_of_days_in_month (month, year)) {
+    if (day > g_date_get_days_in_month (month + 1, year)) {
         gui_change_bg_widget_state (appGUI->cal->spinbutton2_start_day, COLOR_BG_FAIL, appGUI);
     } else {
         gui_change_bg_widget_state (appGUI->cal->spinbutton2_start_day, NULL, appGUI);
@@ -361,7 +330,7 @@ gchar tmpbuf[BUFFER_SIZE];
         month %= 12;
 
         /* 31 January + one month = 28 or 29 February */
-        n = (gint)get_number_of_days_in_month (month, year);
+        n = g_date_get_days_in_month (month + 1, year);
         if (day > n) {
             day = n;
         }
@@ -390,7 +359,7 @@ gchar tmpbuf[BUFFER_SIZE];
 
         if (year > 0) {
             /* 31 March - one month = 28 or 29 February */
-            n = (gint)get_number_of_days_in_month (month, year);
+            n = g_date_get_days_in_month (month + 1, year);
             if (day > n) {
                 day = n;
             }
@@ -426,50 +395,42 @@ gchar tmpbuf[BUFFER_SIZE];
         }
     }
 
-    if (year < 1) {
-        gtk_label_set_text (GTK_LABEL (appGUI->cal->label2_result), 
-            _("This calculator only supports dates after year 1."));
+	if (year < 1) {
 
-    } else {
-        if (hour == 0 && minute == 0 && second == 0) {
-            sprintf (tmpbuf, "<big>%s</big>", julian_to_str (julian, DATE_FULL));
-        } else {
-            sprintf (timebuf, "%02d:%02d.%02d", hour, minute, second);
-            sprintf (tmpbuf, "<big>%s, %s</big>", timebuf, julian_to_str (julian, DATE_FULL));
-        }
-        gtk_label_set_markup (GTK_LABEL (appGUI->cal->label2_result), tmpbuf);
-    }
+		gtk_label_set_text (GTK_LABEL (appGUI->cal->label2_result), _("This calculator only supports dates after year 1."));
 
-    appGUI->cal->julian_jumpto = julian;
+	} else {
+
+		if (hour == 0 && minute == 0 && second == 0) {
+			g_snprintf (tmpbuf, BUFFER_SIZE, "<big>%s</big>", julian_to_str (julian, DATE_FULL));
+		} else {
+			g_snprintf (timebuf, BUFFER_SIZE, "%02d:%02d.%02d", hour, minute, second);
+			g_snprintf (tmpbuf, BUFFER_SIZE, "<big>%s, %s</big>", timebuf, julian_to_str (julian, DATE_FULL));
+		}
+		gtk_label_set_markup (GTK_LABEL (appGUI->cal->label2_result), tmpbuf);
+
+	}
+
+	appGUI->cal->julian_jumpto = julian;
 }
 
 /*------------------------------------------------------------------------------*/
 
 void
-jumpto_and_window_close_cb (GtkButton *button, gpointer user_data) {
-
-GUI *appGUI = (GUI *)user_data;
-gint year, month, day;
-
+jumpto_and_window_close_cb (GtkButton *button, gpointer user_data)
+{
 GDate *cdate;
 
-    cdate = g_date_new_julian (appGUI->cal->julian_jumpto);
+	GUI *appGUI = (GUI *) user_data;
 
-    if (cdate != NULL) {
-        if (g_date_valid (cdate)) {
-            day = g_date_get_day (cdate);
-            month = g_date_get_month (cdate) - 1;
-            year = g_date_get_year (cdate);
-        }
-        g_date_free (cdate);
-    }
+	cdate = g_date_new_julian (appGUI->cal->julian_jumpto);
+	g_return_if_fail (cdate != NULL);
 
-    if (is_valid_date2 (day, month, year) == TRUE) {
-        jump_to_date (day, month, year, appGUI);
-        update_aux_calendars (appGUI);
-    }
+	calendar_jump_to_date (cdate, appGUI);
+	update_aux_calendars (appGUI);
 
-    window_date_calculator_close_cb (GTK_WIDGET(button), NULL, user_data);
+	window_date_calculator_close_cb (GTK_WIDGET (button), NULL, user_data);
+	g_date_free (cdate);
 }
 
 /*------------------------------------------------------------------------------*/
