@@ -19,19 +19,17 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-
-#include <stdio.h>
-#include <string.h>
-#include <time.h>
-#include <ctype.h>
-#include <unistd.h>
-#include <config.h>
-#include <glib.h>
-#include <glib/gstdio.h>
-#include <libxml/xmlmemory.h>
-#include <libxml/parser.h>
+#include "calendar_ical.h"
+#include "i18n.h"
+#include "calendar.h"
+#include "gui_utils.h"
+#include "calendar_notes.h"
+#include "options_prefs.h"
+#include "options_gui_calendar.h"
+#include "stock_icons.h"
 
 #ifdef HAVE_LIBICAL
+
 #include <ical.h>
 #undef PACKAGE
 #undef PACKAGE_BUGREPORT
@@ -40,48 +38,30 @@
 #undef PACKAGE_TARNAME
 #undef PACKAGE_VERSION
 #undef VERSION
-#endif  /* HAVE_LIBICAL */
-
-#include "i18n.h"
-#include "calendar.h"
-#include "gui.h"
-#include "gui_utils.h"
-#include "calendar_notes.h"
-#include "options_prefs.h"
-#include "options_gui_calendar.h"
-#include "calendar_ical.h"
-#include "time_utils.h"
-#include "date_utils.h"
-#include "stock_icons.h"
-
-
-#ifdef HAVE_LIBICAL
 
 /*------------------------------------------------------------------------------*/
 
-gboolean
+void
 ics_initialize_timezone (void) {
 
 gchar *tz_search_paths [] = {
+/* FIXME: doesn't work with libical 0.27 */
+/*    "/usr/share/zoneinfo/",*/
     "/opt/usr/share/libical/zoneinfo/",
     "/usr/share/libical/zoneinfo/",
     "/usr/local/share/libical/zoneinfo/"
 };
 
 gint i;
-gboolean ret = FALSE;
 
 #define N_SEARCH_PATHS (sizeof (tz_search_paths) / sizeof (tz_search_paths [0]))
 
     for (i = 0; i < N_SEARCH_PATHS; i++) {
 		if (!g_access (tz_search_paths[i], F_OK | R_OK)) {
             set_zone_directory (tz_search_paths[i]);
-            ret = TRUE;
 			break;
 		}
 	}
-
-    return ret;
 }
 
 /*------------------------------------------------------------------------------*/
@@ -117,14 +97,14 @@ add_ics_entry_to_day_info_panel (gchar *name, gchar *entry, gchar *entry_desc, g
 
 gchar tmpbuf[BUFFER_SIZE];
 
-    sprintf(tmpbuf, "%s:\n", name);
+    g_snprintf (tmpbuf, BUFFER_SIZE, "%s:\n", name);
     gtk_text_buffer_insert_with_tags_by_name (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter, tmpbuf, -1, "bold", NULL);
 
-    sprintf(tmpbuf, "%s\n", str_remove_backslash(entry));
+    g_snprintf (tmpbuf, BUFFER_SIZE, "%s\n", str_remove_backslash (entry));
     gtk_text_buffer_insert (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter, tmpbuf, -1);
 
     if (entry_desc != NULL && desc_flag == TRUE) {
-        sprintf(tmpbuf, "(%s)\n\n", str_remove_backslash(entry_desc));
+        g_snprintf (tmpbuf, BUFFER_SIZE, "(%s)\n\n", str_remove_backslash (entry_desc));
         gtk_text_buffer_insert (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter, tmpbuf, -1);
     } else {
         gtk_text_buffer_insert (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter, "\n", -1);
@@ -139,105 +119,106 @@ ics_parse_file (struct ics_file *file_entry, gchar *name, gchar *filename, gbool
 
 FILE *ics_stream;
 icalparser *ics_parser;
-icalcomponent *ics_component; 
-icalcomponent *h, *l; 
+icalcomponent *ics_component;
+icalcomponent *h, *l;
 icalproperty *p, *r;
 struct icaltimetype tt;
 struct ics_entry *item;
 gint n = 0;
 
-    ics_parser = icalparser_new ();
+	ics_parser = icalparser_new ();
+	g_return_val_if_fail (ics_parser != NULL, n);
 
-    if (ics_parser != NULL) {
+	ics_stream = fopen (filename, "r");
 
-        ics_stream = fopen(filename, "r");
+	if (ics_stream == NULL) {
+		icalparser_free (ics_parser);
+		return n;
+	}
 
-        if (ics_stream != NULL) {
+	icalparser_set_gen_data (ics_parser, ics_stream);
+	ics_component = icalparser_parse (ics_parser, ics_read_stream);
 
-            icalparser_set_gen_data(ics_parser, ics_stream);
+	if (ics_component == NULL) {
+		fclose (ics_stream);
+		icalparser_free (ics_parser);
+		return n;
+	}
 
-            ics_component = icalparser_parse(ics_parser, ics_read_stream);
+	/* FIXME */
+	if (icalcomponent_get_first_component (ics_component, ICAL_VEVENT_COMPONENT) != NULL) {
 
-            if (ics_component != NULL) {
+		for (h = icalcomponent_get_first_component (ics_component, ICAL_VEVENT_COMPONENT); h;
+			 h = icalcomponent_get_next_component (ics_component, ICAL_VEVENT_COMPONENT)) {
 
-                if (icalcomponent_get_first_component(ics_component, ICAL_VEVENT_COMPONENT) != NULL) {
+			p = icalcomponent_get_first_property (h, ICAL_DTSTART_PROPERTY);
+			tt = icaltime_from_string (icalproperty_get_value_as_string (p));
 
-                    for (h = icalcomponent_get_first_component(ics_component, ICAL_VEVENT_COMPONENT); h;
-                         h = icalcomponent_get_next_component(ics_component, ICAL_VEVENT_COMPONENT)) {
-                      
-                        p = icalcomponent_get_first_property(h, ICAL_DTSTART_PROPERTY);
-                        tt = icaltime_from_string(icalproperty_get_value_as_string(p));
+				p = icalcomponent_get_first_property (h, ICAL_SUMMARY_PROPERTY);
+				if (p != NULL && count_only == FALSE) {
+					r = icalcomponent_get_first_property (h, ICAL_DESCRIPTION_PROPERTY);
 
-                            p = icalcomponent_get_first_property(h, ICAL_SUMMARY_PROPERTY);
-                            if (p != NULL && count_only == FALSE) {
-                                r = icalcomponent_get_first_property(h, ICAL_DESCRIPTION_PROPERTY);
+					item = g_malloc (sizeof (struct ics_entry));
 
-                                item = g_malloc(sizeof(struct ics_entry));
+					if (item != NULL) {
 
-                                if (item != NULL) {
- 
-                                    item->date.day = tt.day;
-                                    item->date.month = tt.month;
-                                    item->date.year = tt.year;
-                                    item->summary = g_strdup(icalproperty_get_value_as_string(p));
+						item->date.day = tt.day;
+						item->date.month = tt.month;
+						item->date.year = tt.year;
+						item->summary = g_strdup (icalproperty_get_value_as_string (p));
 
-                                    if (r != NULL) {
-                                        item->description = g_strdup(icalproperty_get_value_as_string(r));
-                                    } else {
-                                        item->description = NULL;
-                                    }
+						if (r != NULL) {
+							item->description = g_strdup (icalproperty_get_value_as_string (r));
+						} else {
+							item->description = NULL;
+						}
 
-                                    file_entry->entries_list = g_slist_append (file_entry->entries_list, item);
-                                }
-                            }
-                        n++;
-                    }
+						file_entry->entries_list = g_slist_append (file_entry->entries_list, item);
+					}
+				}
+			n++;
+		}
 
-                } else if (icalcomponent_get_first_component(ics_component, ICAL_VCALENDAR_COMPONENT) != NULL) {
+	} else if (icalcomponent_get_first_component (ics_component, ICAL_VCALENDAR_COMPONENT) != NULL) {
 
-                    for (l = icalcomponent_get_first_component(ics_component, ICAL_VCALENDAR_COMPONENT); l;
-                         l = icalcomponent_get_next_component(ics_component, ICAL_VCALENDAR_COMPONENT)) {
- 
-                        h = icalcomponent_get_first_component(l, ICAL_VEVENT_COMPONENT);
-                        p = icalcomponent_get_first_property(h, ICAL_DTSTART_PROPERTY);
-                        tt = icaltime_from_string(icalproperty_get_value_as_string(p));
+		for (l = icalcomponent_get_first_component (ics_component, ICAL_VCALENDAR_COMPONENT); l;
+			 l = icalcomponent_get_next_component (ics_component, ICAL_VCALENDAR_COMPONENT)) {
 
-                            p = icalcomponent_get_first_property(h, ICAL_SUMMARY_PROPERTY);
-                            if (p != NULL && count_only == FALSE) {
-                                r = icalcomponent_get_first_property(h, ICAL_DESCRIPTION_PROPERTY);
- 
-                                item = g_malloc(sizeof(struct ics_entry));
+			h = icalcomponent_get_first_component (l, ICAL_VEVENT_COMPONENT);
+			p = icalcomponent_get_first_property (h, ICAL_DTSTART_PROPERTY);
+			tt = icaltime_from_string (icalproperty_get_value_as_string (p));
 
-                                if (item != NULL) {
- 
-                                    item->date.day = tt.day;
-                                    item->date.month = tt.month;
-                                    item->date.year = tt.year;
-                                    item->summary = g_strdup(icalproperty_get_value_as_string(p));
+				p = icalcomponent_get_first_property (h, ICAL_SUMMARY_PROPERTY);
+				if (p != NULL && count_only == FALSE) {
+					r = icalcomponent_get_first_property (h, ICAL_DESCRIPTION_PROPERTY);
 
-                                    if (r != NULL) {
-                                        item->description = g_strdup(icalproperty_get_value_as_string(r));
-                                    } else {
-                                        item->description = NULL;
-                                    }
+					item = g_malloc (sizeof (struct ics_entry));
 
-                                    file_entry->entries_list = g_slist_append (file_entry->entries_list, item);
-                                }
-                            }
-                        n++;
-                    }
-                }
+					if (item != NULL) {
 
-                icalcomponent_free (ics_component);
-            }
+						item->date.day = tt.day;
+						item->date.month = tt.month;
+						item->date.year = tt.year;
+						item->summary = g_strdup (icalproperty_get_value_as_string(p));
 
-            fclose (ics_stream);
-        }
+						if (r != NULL) {
+							item->description = g_strdup (icalproperty_get_value_as_string (r));
+						} else {
+							item->description = NULL;
+						}
 
-        icalparser_free (ics_parser);
-    }
+						file_entry->entries_list = g_slist_append (file_entry->entries_list, item);
+					}
+				}
+			n++;
+		}
+	}
 
-    return n;
+	icalcomponent_free (ics_component);
+	fclose (ics_stream);
+	icalparser_free (ics_parser);
+
+	return n;
 }
 
 /*------------------------------------------------------------------------------*/
@@ -284,7 +265,7 @@ gboolean status;
 /*------------------------------------------------------------------------------*/
 
 void
-calendar_display_ics (DATE *date, GUI *appGUI) {
+calendar_display_ics (GDate *date, GUI *appGUI) {
 
 gchar *ical_name, *ical_filename;
 GtkTreeIter iter;
@@ -325,12 +306,13 @@ gint i, j, k;
 
                 if (year_flag == TRUE) {
 
-                    if (date->day == item->date.day && date->month+1 == item->date.month && date->year == item->date.year) {
+                    if (g_date_get_day (date) == item->date.day && g_date_get_month (date) == item->date.month &&
+					    g_date_get_year (date) == item->date.year) {
                         add_ics_entry_to_day_info_panel (ical_name, item->summary, item->description, desc_flag, appGUI);
                         break;
                     }
 
-                } else if (date->day == item->date.day && date->month+1 == item->date.month) {
+                } else if (g_date_get_day (date) == item->date.day && g_date_get_month (date) == item->date.month) {
                     add_ics_entry_to_day_info_panel (ical_name, item->summary, item->description, desc_flag, appGUI);
                     break;
                 }
@@ -354,9 +336,7 @@ GtkTreeIter iter;
 gint i;
 gboolean flag, desc_flag;
 
-    if (ics_initialize_timezone () == FALSE) {
-        return;
-    }
+    ics_initialize_timezone ();
 
     appGUI->cal->ics_files_list = NULL;
 
@@ -449,10 +429,10 @@ gboolean desc_flag;
 gchar item_name[BUFFER_SIZE], item_filename[BUFFER_SIZE];
 GtkTreeIter iter;
 
-    if (g_file_test (prefs_get_config_filename(ICAL_ENTRIES_FILENAME), G_FILE_TEST_IS_REGULAR) == FALSE) 
+    if (g_file_test (prefs_get_config_filename(ICAL_ENTRIES_FILENAME, appGUI), G_FILE_TEST_IS_REGULAR) == FALSE) 
         return;
 
-    if((doc = xmlParseFile(prefs_get_config_filename(ICAL_ENTRIES_FILENAME)))) {
+    if((doc = xmlParseFile(prefs_get_config_filename(ICAL_ENTRIES_FILENAME, appGUI)))) {
 
         if(!(node = xmlDocGetRootElement(doc))) {
             xmlFreeDoc(doc);
@@ -557,7 +537,7 @@ gchar tmpbuf[BUFFER_SIZE];
         xmlNewChild(entry_node, NULL, (const xmlChar *) "use_year", (xmlChar *) tmpbuf);
     }
 
-    xmlSaveFormatFileEnc(prefs_get_config_filename(ICAL_ENTRIES_FILENAME), doc, "utf-8", 1);
+    xmlSaveFormatFileEnc(prefs_get_config_filename(ICAL_ENTRIES_FILENAME, appGUI), doc, "utf-8", 1);
     xmlFreeDoc(doc);
 
     ics_calendar_close (appGUI);
