@@ -19,17 +19,10 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-
-#include <stdio.h>
-#include <string.h>
-#include <glib.h>
-#include <ctype.h>
-
+#include "calendar_jumpto.h"
 #include "i18n.h"
 #include "calendar.h"
-#include "calendar_jumpto.h"
-#include "time_utils.h"
-#include "date_utils.h"
+#include "calendar_utils.h"
 #include "options_prefs.h"
 #include "stock_icons.h"
 
@@ -136,23 +129,33 @@ gint a;
 }
 
 /*------------------------------------------------------------------------------*/
-
+/* FIXME */
 void
-jumpto_go_window_close_cb (GtkButton *button, gpointer user_data) {
+jumpto_go_window_close_cb (GtkButton *button, gpointer user_data)
+{
+GDate *cdate;
 
-    GUI *appGUI = (GUI *)user_data;
+	GUI *appGUI = (GUI *)user_data;
 
-    appGUI->cal->jday = atoi (gtk_entry_get_text(GTK_ENTRY(appGUI->cal->day_entry)));
-    appGUI->cal->jmonth = atoi (gtk_entry_get_text(GTK_ENTRY(appGUI->cal->month_entry)));
-    appGUI->cal->jyear = atoi (gtk_entry_get_text(GTK_ENTRY(appGUI->cal->year_entry)));
+	appGUI->cal->jday = atoi (gtk_entry_get_text (GTK_ENTRY (appGUI->cal->day_entry)));
+	appGUI->cal->jmonth = atoi (gtk_entry_get_text (GTK_ENTRY (appGUI->cal->month_entry)));
+	appGUI->cal->jyear = atoi (gtk_entry_get_text (GTK_ENTRY (appGUI->cal->year_entry)));
 
-    if (is_valid_date2(appGUI->cal->jday, appGUI->cal->jmonth-1, appGUI->cal->jyear) == TRUE) {
-        jump_to_date (appGUI->cal->jday, appGUI->cal->jmonth-1, appGUI->cal->jyear, appGUI);
-        update_aux_calendars (appGUI);
-    }
+	if ((appGUI->cal->jyear > JULIAN_GREGORIAN_YEAR) &&
+	    (appGUI->cal->jmonth > 0 && appGUI->cal->jmonth <= 12)) {
+		if (appGUI->cal->jday > 0 &&
+		    appGUI->cal->jday <= g_date_get_days_in_month (appGUI->cal->jmonth, appGUI->cal->jyear)) {
 
-    jumpto_window_close_cb (GTK_WIDGET(button), NULL, user_data);
+			cdate = g_date_new_dmy (appGUI->cal->jday, appGUI->cal->jmonth, appGUI->cal->jyear);
+			g_return_if_fail (cdate != NULL);
 
+			calendar_jump_to_date (cdate, appGUI);
+			update_aux_calendars (appGUI);
+			g_date_free (cdate);
+		}
+	}
+
+	jumpto_window_close_cb (GTK_WIDGET (button), NULL, user_data);
 }
 
 /*------------------------------------------------------------------------------*/
