@@ -19,30 +19,20 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include <stdio.h>
-#include <string.h>
-#include <ctype.h>
-#include <time.h>
-#include <stdlib.h>
-#include <glib.h>
-#include <math.h>
-#include <ctype.h>
-#include <limits.h>
-#include <unistd.h>
-#include <sys/stat.h>
-
-#include "i18n.h"
 #include "contacts.h"
+#include "i18n.h"
 #include "contacts_items.h"
-#include "gui.h"
 #include "gui_utils.h"
 #include "options_prefs.h"
 #include "stock_icons.h"
 #include "contacts_birthdays.h"
 #include "contacts_import.h"
 #include "contacts_export.h"
-#include "time_utils.h"
-#include "date_utils.h"
+#include "calendar_utils.h"
+
+#ifdef HAVE_LIBSYNCML
+#include "contacts_import_syncml.h"
+#endif
 
 /*------------------------------------------------------------------------------*/
 
@@ -243,17 +233,21 @@ GtkTreePath     *path;
 void
 contacts_item_selected_cb (GtkTreeSelection *selection, gpointer data) {
 
+GtkTextChildAnchor *anchor;
 GtkTreeIter iter;
 GtkTreeModel *model;
-gchar *text;
-GtkTextIter titer;
+gchar *text, *markup;
+GtkTextIter titer, www_titer, email_titer, blog_titer;
 GtkTextBuffer *text_buffer;
-gint i, j;
-gchar photo_full_path[PATH_MAX], space_line[PATH_MAX];
+GtkWidget *table, *label;
+GdkColor color;
+gint i, j_www, j_email, n, n_www, n_email;
+gchar photo_full_path[PATH_MAX];
 char tmpbuf[BUFFER_SIZE];
 gboolean activate_home_phone, activate_work_phone, activate_cell_phone;
 gboolean activate_email, activate_www;
 guint32 date;
+PangoFontDescription *item_font;
 
     GUI *appGUI = (GUI *)data;
 
@@ -271,7 +265,85 @@ guint32 date;
             appGUI->cnt->photo_image = NULL;
         }
 
-        gui_url_remove_links (&appGUI->cnt->contacts_links_list, &appGUI->cnt->contacts_link_index);
+        anchor = NULL;
+ 
+        /* initialize WWW links textview */
+
+        n_www = 0;
+        for(i=COLUMN_WWW_1; i <= COLUMN_WWW_4; i++) {
+            gtk_tree_model_get (model, &iter, i, &text, -1);
+            if (text != NULL) {
+                n_www++;
+                g_free (text);
+            }
+        }
+
+        if (G_IS_OBJECT(appGUI->cnt->contacts_www_textview)) {
+            gui_url_remove_links (&appGUI->cnt->contacts_www_links_list, &appGUI->cnt->contacts_www_link_index);
+            g_object_ref_sink (appGUI->cnt->contacts_www_textview);
+        }
+
+        appGUI->cnt->contacts_www_textview = gtk_text_view_new ();
+        gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW(appGUI->cnt->contacts_www_textview), FALSE);
+        gtk_text_view_set_editable (GTK_TEXT_VIEW(appGUI->cnt->contacts_www_textview), FALSE);
+        gtk_text_view_set_pixels_above_lines(GTK_TEXT_VIEW(appGUI->cnt->contacts_www_textview), 2);
+        gtk_text_view_set_pixels_below_lines(GTK_TEXT_VIEW(appGUI->cnt->contacts_www_textview), 2);
+        gtk_widget_show (appGUI->cnt->contacts_www_textview);
+        gui_url_setup(&appGUI->cnt->contacts_www_links_list, 
+                      &appGUI->cnt->contacts_www_link_index, appGUI->cnt->contacts_www_textview, appGUI);
+
+        /* initialize EMAIL links textview */
+
+        n_email = 0;
+        for(i=COLUMN_EMAIL_1; i <= COLUMN_EMAIL_4; i++) {
+            gtk_tree_model_get (model, &iter, i, &text, -1);
+            if (text != NULL) {
+                n_email++;
+                g_free (text);
+            }
+        }
+
+        if (G_IS_OBJECT(appGUI->cnt->contacts_email_textview)) {
+            gui_url_remove_links (&appGUI->cnt->contacts_email_links_list, &appGUI->cnt->contacts_email_link_index);
+            g_object_ref_sink (appGUI->cnt->contacts_email_textview);
+        }
+
+        appGUI->cnt->contacts_email_textview = gtk_text_view_new ();
+        gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW(appGUI->cnt->contacts_email_textview), FALSE);
+        gtk_text_view_set_editable (GTK_TEXT_VIEW(appGUI->cnt->contacts_email_textview), FALSE);
+        gtk_text_view_set_pixels_above_lines(GTK_TEXT_VIEW(appGUI->cnt->contacts_email_textview), 2);
+        gtk_text_view_set_pixels_below_lines(GTK_TEXT_VIEW(appGUI->cnt->contacts_email_textview), 2);
+        gtk_widget_show (appGUI->cnt->contacts_email_textview);
+        gui_url_setup(&appGUI->cnt->contacts_email_links_list, 
+                      &appGUI->cnt->contacts_email_link_index, appGUI->cnt->contacts_email_textview, appGUI);
+
+        /* initialize BLOG link textview */
+
+        if (G_IS_OBJECT(appGUI->cnt->contacts_blog_textview)) {
+            gui_url_remove_links (&appGUI->cnt->contacts_blog_links_list, &appGUI->cnt->contacts_blog_link_index);
+            g_object_ref_sink (appGUI->cnt->contacts_blog_textview);
+        }
+
+        appGUI->cnt->contacts_blog_textview = gtk_text_view_new ();
+        gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW(appGUI->cnt->contacts_blog_textview), FALSE);
+        gtk_text_view_set_editable (GTK_TEXT_VIEW(appGUI->cnt->contacts_blog_textview), FALSE);
+        gtk_text_view_set_pixels_above_lines(GTK_TEXT_VIEW(appGUI->cnt->contacts_blog_textview), 2);
+        gtk_text_view_set_pixels_below_lines(GTK_TEXT_VIEW(appGUI->cnt->contacts_blog_textview), 2);
+        gtk_widget_show (appGUI->cnt->contacts_blog_textview);
+        gui_url_setup(&appGUI->cnt->contacts_blog_links_list, 
+                      &appGUI->cnt->contacts_blog_link_index, appGUI->cnt->contacts_blog_textview, appGUI);
+
+        gdk_color_parse (config.contact_tag_color, &color);
+        item_font = pango_font_description_from_string (config.contact_item_font);
+
+        table = gtk_table_new (1, 2, FALSE);
+        gtk_widget_show (table);
+        gtk_table_set_row_spacings (GTK_TABLE (table), 4);
+        gtk_table_set_col_spacings (GTK_TABLE (table), 8);
+
+        n = 0;          /* row */
+        j_www = 0;      /* www links counter */
+        j_email = 0;    /* email links counter */
 
         for(i=0; i < CONTACTS_NUM_COLUMNS; i++) {
 
@@ -307,9 +379,12 @@ guint32 date;
                                 gtk_text_buffer_insert(text_buffer, &titer, "\n", -1);
                             }
 
-                        } else if (text != NULL && i!= COLUMN_GROUP) {
+                        } else if (text != NULL && i != COLUMN_GROUP) {
 
-                            gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, "\n", -1, "normal", NULL);
+                            if (anchor == NULL) {
+                                gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, "\n", -1, "normal", NULL);
+                                anchor = gtk_text_buffer_create_child_anchor (text_buffer, &titer);
+                            }
 
                             activate_home_phone = (i == COLUMN_HOME_PHONE_2 || i == COLUMN_HOME_PHONE_3 || i == COLUMN_HOME_PHONE_4) && strlen(text);
                             activate_work_phone = (i == COLUMN_WORK_PHONE_2 || i == COLUMN_WORK_PHONE_3 || i == COLUMN_WORK_PHONE_4) && strlen(text);
@@ -317,8 +392,6 @@ guint32 date;
                             activate_email = (i == COLUMN_EMAIL_2 || i == COLUMN_EMAIL_3 || i == COLUMN_EMAIL_4) && strlen(text);
                             activate_www = (i == COLUMN_WWW_2 || i == COLUMN_WWW_3 || i == COLUMN_WWW_4) && strlen(text);
 
-                            for(j=0;j<PATH_MAX;j++) space_line[j] = ' ';
-
                             if ((i >= COLUMN_HOME_PHONE_1 && i <= COLUMN_HOME_PHONE_4)  ||
                                 (i >= COLUMN_WORK_PHONE_1 && i <= COLUMN_WORK_PHONE_4)  ||
                                 (i >= COLUMN_CELL_PHONE_1 && i <= COLUMN_CELL_PHONE_4)  ||
@@ -333,27 +406,98 @@ guint32 date;
 
                                     sprintf(tmpbuf, "%s: ", gettext(appGUI->cnt->contact_fields_tags_name[2*i]));
                                 } else {
-                                    sprintf(tmpbuf, " ");
+                                    tmpbuf[0] = 0;
                                 }
 
                             } else {
                                 sprintf(tmpbuf, "%s: ", gettext(appGUI->cnt->contact_fields_tags_name[2*i]));
                             }
 
-                            if (i != COLUMN_INFO) {
-                                space_line[appGUI->cnt->longest_tag_name - strlen(tmpbuf) + 2] = '\0';
-                                strcat(tmpbuf, space_line);
-                            }
-                            gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, tmpbuf, -1, "tag_name", NULL);
+                            if (text != NULL) {
 
-                            if (i == COLUMN_INFO) {
-                                gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, "\n", -1, "normal", NULL);
-                            }
+                                if (strlen(tmpbuf)) {
+                                    label = gtk_label_new (NULL);
+                                    gtk_widget_show (label);
+                                    gtk_label_set_selectable (GTK_LABEL(label), TRUE);
+                                    markup = g_markup_printf_escaped ("<b>%s</b>", tmpbuf);
+                                    gtk_label_set_markup (GTK_LABEL (label), markup);
+                                    g_free (markup);
+                                    gtk_widget_modify_fg (label, GTK_STATE_NORMAL, &color);
+                                    gtk_widget_modify_font (label, item_font);
+                                    gtk_table_attach (GTK_TABLE (table), label, 0, 1, n, n+1,
+                                                      (GtkAttachOptions) (GTK_FILL),
+                                                      (GtkAttachOptions) (0), 0, 0);
+                                    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+                                    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+                                }
 
-                            if (i == COLUMN_BLOG || (i >= COLUMN_EMAIL_1 && i <= COLUMN_EMAIL_4) || (i >= COLUMN_WWW_1 && i <= COLUMN_WWW_4)) { /* insert link */
-                                gui_url_insert_link(&appGUI->cnt->contacts_links_list, &appGUI->cnt->contacts_link_index, appGUI->cnt->contacts_desc_textview , &titer, config.contact_link_color, config.tags_font_size, text, FALSE, appGUI);
-                            } else {
-                                 gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, text, -1, "normal", NULL);
+                                if (i == COLUMN_BLOG || (i >= COLUMN_EMAIL_1 && i <= COLUMN_EMAIL_4) || (i >= COLUMN_WWW_1 && i <= COLUMN_WWW_4)) { /* insert link */
+
+                                    if (i == COLUMN_WWW_1) {
+                                        gtk_table_attach (GTK_TABLE (table), appGUI->cnt->contacts_www_textview, 1, 2, n, n+1,
+                                                          (GtkAttachOptions) (GTK_FILL),
+                                                          (GtkAttachOptions) (0), 0, 0);
+                                        gui_clear_text_buffer (gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->cnt->contacts_www_textview)), &www_titer);
+                                    }
+                                    if (i >= COLUMN_WWW_1 && i <= COLUMN_WWW_4) {
+                                        gui_url_insert_link(&appGUI->cnt->contacts_www_links_list, 
+                                                            &appGUI->cnt->contacts_www_link_index, 
+                                                            appGUI->cnt->contacts_www_textview, 
+                                                            &www_titer, config.contact_link_color, 
+                                                            config.contact_item_font, text, FALSE, appGUI);
+                                        j_www++;
+                                        if (j_www < n_www) {
+                                            gtk_text_buffer_insert (gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->cnt->contacts_www_textview)), &www_titer, "\n", -1);
+                                        }
+                                    }
+
+                                    if (i == COLUMN_EMAIL_1) {
+                                        gtk_table_attach (GTK_TABLE (table), appGUI->cnt->contacts_email_textview, 1, 2, n, n+1,
+                                                          (GtkAttachOptions) (GTK_FILL),
+                                                          (GtkAttachOptions) (0), 0, 0);
+                                        gui_clear_text_buffer (gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->cnt->contacts_email_textview)), &email_titer);
+                                    }
+                                    if (i >= COLUMN_EMAIL_1 && i <= COLUMN_EMAIL_4) {
+                                        gui_url_insert_link(&appGUI->cnt->contacts_email_links_list, 
+                                                            &appGUI->cnt->contacts_email_link_index, 
+                                                            appGUI->cnt->contacts_email_textview, 
+                                                            &email_titer, config.contact_link_color, 
+                                                            config.contact_item_font, text, FALSE, appGUI);
+                                        j_email++;
+                                        if (j_email < n_email) {
+                                            gtk_text_buffer_insert (gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->cnt->contacts_email_textview)), &email_titer, "\n", -1);
+                                        }
+                                    }
+
+                                    if (i == COLUMN_BLOG) {
+                                        gtk_table_attach (GTK_TABLE (table), appGUI->cnt->contacts_blog_textview, 1, 2, n, n+1,
+                                                          (GtkAttachOptions) (GTK_FILL),
+                                                          (GtkAttachOptions) (0), 0, 0);
+                                        gui_clear_text_buffer (gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->cnt->contacts_blog_textview)), &blog_titer);
+                                        gui_url_insert_link(&appGUI->cnt->contacts_blog_links_list, 
+                                                            &appGUI->cnt->contacts_blog_link_index, 
+                                                            appGUI->cnt->contacts_blog_textview, 
+                                                            &blog_titer, config.contact_link_color, 
+                                                            config.contact_item_font, text, FALSE, appGUI);
+                                    }
+
+                                } else if (i == COLUMN_INFO) {
+                                    gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, "\n", -1, "normal", NULL);
+                                    gtk_text_buffer_insert_with_tags_by_name (text_buffer, &titer, text, -1, "normal", NULL);
+                                } else {
+                                    label = gtk_label_new (text);
+                                    gtk_widget_show (label);
+                                    gtk_widget_modify_font (label, item_font);
+                                    gtk_label_set_selectable (GTK_LABEL(label), TRUE);
+                                    gtk_table_attach (GTK_TABLE (table), label, 1, 2, n, n+1,
+                                                      (GtkAttachOptions) (GTK_FILL),
+                                                      (GtkAttachOptions) (0), 0, 0);
+                                    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+                                    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+                                }
+
+                                n++;
+                                gtk_table_resize (GTK_TABLE(table), n, 2);
                             }
                         }
                     }
@@ -362,6 +506,10 @@ guint32 date;
             }
         }
 
+        if (anchor != NULL) {
+            gtk_text_view_add_child_at_anchor (GTK_TEXT_VIEW(appGUI->cnt->contacts_desc_textview), table, anchor);
+        }
+
         /* insert photo */
         gtk_tree_model_get (model, &iter, COLUMN_PHOTO, &text, -1);
 
@@ -370,6 +518,8 @@ guint32 date;
             insert_photo(photo_full_path, &titer, appGUI);
             g_free(text);
         }
+    
+        pango_font_description_free (item_font);
 
     } else {
         gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->cnt->contacts_uim_widget, "/toolbar/edit"), FALSE);
@@ -688,7 +838,12 @@ void
 contacts_import_items_cb (GtkWidget *widget, gpointer data) {
 
     GUI *appGUI = (GUI *)data;
-    import_contacts_from_csv_file(appGUI);
+
+#ifdef HAVE_LIBSYNCML
+    import_contacts_show_dialog (appGUI);
+#else
+    import_contacts_from_csv_file (appGUI);
+#endif
 }
 
 /*------------------------------------------------------------------------------*/
@@ -713,6 +868,19 @@ contacts_list_dbclick_cb(GtkWidget * widget, GdkEventButton * event, gpointer fu
 
 /*------------------------------------------------------------------------------*/
 
+void
+contacts_selection_activate (gboolean active, GUI *appGUI) {
+    if (active == TRUE) {
+        g_signal_connect(G_OBJECT(appGUI->cnt->contacts_list_selection), "changed",
+                         G_CALLBACK(contacts_item_selected_cb), appGUI);
+    } else {
+        g_signal_handlers_disconnect_by_func (G_OBJECT (appGUI->cnt->contacts_list_selection),
+                                              G_CALLBACK (contacts_item_selected_cb), appGUI);
+    }
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 gui_create_contacts(GUI *appGUI) {
 
@@ -732,7 +900,7 @@ gint            i;
 GError          *error = NULL;
 GtkActionGroup  *action_group = NULL;
 GtkAdjustment   *adjustment;
-char tmpbuf[BUFFER_SIZE];
+gchar tmpbuf[BUFFER_SIZE];
 
 static gchar *contact_fields_tags_name[] = {
     N_("Group"), "group", N_("First name"), "first_name", N_("Second name"), "second_name", 
@@ -774,8 +942,8 @@ static gchar *contact_fields_tags_name[] = {
 const gchar *ui_info =
 "  <toolbar name=\"toolbar\">\n"
 "    <toolitem name=\"add\" action=\"add\" />\n"
-"    <toolitem name=\"delete\" action=\"delete\" />\n"
 "    <toolitem name=\"edit\" action=\"edit\" />\n"
+"    <toolitem name=\"delete\" action=\"delete\" />\n"
 "    <separator name=\"sep1\" />\n"
 "    <toolitem name=\"birthdays\" action=\"birthdays\" />\n"
 "    <separator name=\"sep2\" />\n"
@@ -795,15 +963,6 @@ GtkActionEntry entries[] = {
 guint n_entries = G_N_ELEMENTS (entries);
 
     appGUI->cnt->contact_fields_tags_name = contact_fields_tags_name;
-    appGUI->cnt->longest_tag_name = 0;
-
-    for(i=0; i < CONTACTS_NUM_COLUMNS; i++) {
-        if (i != COLUMN_ID) {
-            if (appGUI->cnt->longest_tag_name < strlen(gettext(contact_fields_tags_name[i*2]))) {
-                appGUI->cnt->longest_tag_name = strlen(gettext(contact_fields_tags_name[i*2]));
-            }
-        }
-    }
 
     vbox1 = gtk_vbox_new (FALSE, 0);
     gtk_widget_show (vbox1);
@@ -943,8 +1102,7 @@ guint n_entries = G_N_ELEMENTS (entries);
                      G_CALLBACK(contacts_list_dbclick_cb), appGUI);
 
     appGUI->cnt->contacts_list_selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (appGUI->cnt->contacts_list));
-    g_signal_connect(G_OBJECT(appGUI->cnt->contacts_list_selection), "changed",
-                     G_CALLBACK(contacts_item_selected_cb), appGUI);
+    contacts_selection_activate (TRUE, appGUI);
 
     /* columns setup */
 
@@ -1023,7 +1181,14 @@ guint n_entries = G_N_ELEMENTS (entries);
     gtk_widget_show (appGUI->cnt->contacts_desc_textview);
     gtk_container_add (GTK_CONTAINER (appGUI->cnt->contacts_panel_scrolledwindow), appGUI->cnt->contacts_desc_textview);
 
-    gui_url_setup(&appGUI->cnt->contacts_links_list, &appGUI->cnt->contacts_link_index, appGUI->cnt->contacts_desc_textview, appGUI);
+    /*gui_url_setup(&appGUI->cnt->contacts_links_list, &appGUI->cnt->contacts_link_index, appGUI->cnt->contacts_desc_textview, appGUI);*/
+
+    /*appGUI->cnt->contacts_www_textview = gtk_text_view_new ();*/
+    /*gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW(appGUI->cnt->contacts_www_textview), FALSE);*/
+    /*gtk_text_view_set_editable (GTK_TEXT_VIEW(appGUI->cnt->contacts_www_textview), FALSE);*/
+    /*gtk_widget_show (appGUI->cnt->contacts_www_textview);*/
+    /*gui_url_setup(&appGUI->cnt->contacts_www_links_list, */
+                  /*&appGUI->cnt->contacts_www_link_index, appGUI->cnt->contacts_www_textview, appGUI);*/
 
     adjustment = gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(appGUI->cnt->contacts_panel_scrolledwindow));
     g_signal_connect(G_OBJECT(adjustment), "value-changed", G_CALLBACK(contacts_desc_scrolled), appGUI);
@@ -1033,12 +1198,9 @@ guint n_entries = G_N_ELEMENTS (entries);
     text_buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->cnt->contacts_desc_textview));
 
     appGUI->cnt->contact_name_tag_object = gtk_text_buffer_create_tag (text_buffer, "big",
-                                                          "size", config.name_font_size * PANGO_SCALE, NULL);
+                                                          "font", config.contact_name_font, NULL);
     appGUI->cnt->contact_tags_value_tag_object = gtk_text_buffer_create_tag (text_buffer, "normal",
-                                                                "size", config.tags_font_size * PANGO_SCALE, NULL);
-    appGUI->cnt->contact_color_tag_object = gtk_text_buffer_create_tag (text_buffer, "tag_name",
-                               "foreground", config.contact_tag_color, "font", "Monospace",
-                               "size", config.tags_font_size * PANGO_SCALE, "weight", PANGO_WEIGHT_SEMIBOLD, NULL);
+                                                                "font", config.contact_item_font, NULL);
 
     gtk_combo_box_set_active (GTK_COMBO_BOX (appGUI->cnt->contacts_find_combobox), config.find_mode);
 
