@@ -19,26 +19,15 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-
-#include <stdio.h>
-#include <string.h>
-#include <glib/gprintf.h>
-#include <glib.h>
-#include <time.h>
-#include <ctype.h>
-
+#include "contacts_birthdays.h"
 #include "i18n.h"
 #include "calendar.h"
-#include "gui.h"
 #include "contacts.h"
 #include "calendar_notes.h"
 #include "options_prefs.h"
 #include "stock_icons.h"
-#include "time_utils.h"
+#include "calendar_utils.h"
 #include "gui_utils.h"
-#include "date_utils.h"
-#include "contacts_birthdays.h"
-
 
 /*------------------------------------------------------------------------------*/
 
@@ -101,6 +90,8 @@ gint id, id_c;
             gtk_tree_model_get (model, &iter, B_COLUMN_ID, &id, -1);
             gtk_widget_destroy(appGUI->cnt->birthdays_window);
 
+            contacts_selection_activate (FALSE, appGUI);
+
             if (gtk_tree_model_get_iter_first(GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter) == TRUE) {
 
                 sort_path = gtk_tree_model_get_path (GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter);
@@ -119,10 +110,12 @@ gint id, id_c;
                             gtk_tree_model_get_iter(GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, path);
                             gtk_tree_model_get(GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, COLUMN_ID, &id_c, -1);
                             if (id == id_c) {
+                                contacts_selection_activate (TRUE, appGUI);
                                 gtk_tree_view_set_cursor (GTK_TREE_VIEW (appGUI->cnt->contacts_list), sort_path, NULL, FALSE);
                                 show_contacts_desc_panel (TRUE, appGUI);
                                 gtk_tree_path_free(path);
                                 gtk_tree_path_free(filter_path);
+                                g_signal_emit_by_name(G_OBJECT(appGUI->cnt->contacts_list_selection), "changed");
                                 break;
                             }
                             gtk_tree_path_free(path);
@@ -138,7 +131,6 @@ gint id, id_c;
                 gtk_tree_path_free(sort_path);
  
             }
-
         }
     
         return TRUE;
