@@ -19,19 +19,11 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-
-#include <stdio.h>
-#include <string.h>
-#include <glib.h>
-#include <glib/gstdio.h>
-
+#include "contacts_export.h"
 #include "i18n.h"
-#include "gui.h"
 #include "gui_utils.h"
 #include "contacts.h"
-#include "contacts_export.h"
-#include "time_utils.h"
-#include "date_utils.h"
+#include "calendar_utils.h"
 #include "stock_icons.h"
 #include "options_prefs.h"
 
@@ -799,7 +791,6 @@ static MESSAGE msg_select[3]; /* select all, select none, select invert */
 
     appGUI->cnt->output_file_entry = gtk_entry_new ();
     gtk_widget_show (appGUI->cnt->output_file_entry);
-    gtk_widget_set_sensitive (appGUI->cnt->output_file_entry, FALSE);
     gtk_box_pack_start (GTK_BOX (hbox3), appGUI->cnt->output_file_entry, TRUE, TRUE, 0);
     GTK_WIDGET_UNSET_FLAGS(appGUI->cnt->output_file_entry, GTK_CAN_FOCUS);
     gtk_editable_set_editable (GTK_EDITABLE(appGUI->cnt->output_file_entry), FALSE);
