@@ -19,35 +19,61 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-
-#include <stdio.h>
-#include <string.h>
-#include <glib.h>
-#include <glib/gstdio.h>
-#include <unistd.h>
-
+#include "contacts_import.h"
+#include "contacts_import_csv.h"
+#include "contacts_import_syncml.h"
 #include "i18n.h"
-#include "gui.h"
 #include "gui_utils.h"
 #include "contacts.h"
-#include "contacts_import.h"
-#include "time_utils.h"
-#include "date_utils.h"
+#include "calendar_utils.h"
 #include "stock_icons.h"
 #include "options_prefs.h"
 
+/*-------------------------------------------------------------------------------------*/
+
+void
+import_store_values (GUI *appGUI) {
+
+    config.import_type = gtk_combo_box_get_active (GTK_COMBO_BOX (appGUI->cnt->import_type_combobox));
+
+    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->cnt->bluetooth_radiobutton)) == TRUE) {
+        config.import_interface_type = SYNCML_BLUETOOTH;
+    }
+    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->cnt->usb_radiobutton)) == TRUE) {
+        config.import_interface_type = SYNCML_USB;
+    }
+
+    strncpy(config.import_bluetooth_address, 
+            gtk_entry_get_text (GTK_ENTRY(appGUI->cnt->bluetooth_address_entry)), MAXADDRESS-1);
+
+    config.import_binary_xml = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->cnt->use_wbxml_checkbutton));
+
+    config.import_bluetooth_channel = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(appGUI->cnt->bluetooth_channel_spinbutton)); 
+    config.import_usb_interface = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(appGUI->cnt->usb_interface_spinbutton)); 
+}
 
 /*-------------------------------------------------------------------------------------*/
 
+#ifndef HAVE_LIBSYNCML
 gboolean
-import_contacts_from_csv_file (GUI *appGUI) {
+import_contacts_select_file (GUI *appGUI) {
+#else
+void
+import_contacts_select_file_cb (GtkWidget *widget, gpointer user_data) {
+#endif
 
 GtkWidget *dialog;
-gboolean ret = FALSE;
 GtkFileFilter *filter_1, *filter_2;
+#ifndef HAVE_LIBSYNCML
+gboolean ret;
+#endif
+
+#ifdef HAVE_LIBSYNCML
+    GUI *appGUI = (GUI *)user_data;
+#endif
 
     dialog = gtk_file_chooser_dialog_new(_("Select CSV file"),
-                                         GTK_WINDOW(appGUI->main_window),
+                                         GTK_WINDOW(appGUI->cnt->import_sel_window),
                                          GTK_FILE_CHOOSER_ACTION_OPEN,
                                          GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                          GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
@@ -72,162 +98,483 @@ GtkFileFilter *filter_1, *filter_2;
 
     if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT) {
 
+#ifdef HAVE_LIBSYNCML
+        gtk_widget_hide(dialog);
+
+        gtk_entry_set_text (GTK_ENTRY(appGUI->cnt->input_file_entry), 
+                            gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog)));
+
+#else
         gtk_widget_hide(dialog);
         while (g_main_context_iteration(NULL, FALSE));
 
         ret = add_csv_records(gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog)), appGUI);
+#endif
 
     }
 
     gtk_widget_destroy(dialog);
 
+#ifndef HAVE_LIBSYNCML
     return ret;
+#endif
+
+}
+
+/*-------------------------------------------------------------------------------------*/
+
+gboolean
+import_contacts_from_csv_file (GUI *appGUI) {
+#ifndef HAVE_LIBSYNCML
+    return import_contacts_select_file (appGUI);
+#else
+    return FALSE;
+#endif
+}
+
+/*-------------------------------------------------------------------------------------*/
+
+void
+import_sel_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data) {
+
+    GUI *appGUI = (GUI *)user_data;
+
+    gdk_window_get_root_origin (GDK_WINDOW(appGUI->cnt->import_sel_window->window),
+                                &config.contacts_import_sel_win_x, &config.contacts_import_sel_win_y);
+
+    import_store_values (appGUI);
+
+    gtk_widget_destroy(appGUI->cnt->import_sel_window);
+}
+
+/*-------------------------------------------------------------------------------------*/
+
+gint
+import_sel_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data) {
+
+    GUI *appGUI = (GUI *)data;
+
+    switch(event->keyval) {
+        case GDK_Escape:
+            import_sel_window_close_cb (widget, NULL, appGUI);
+            return TRUE;
+    }
+
+    return FALSE;
 }
 
 /*------------------------------------------------------------------------------*/
 
-gchar *
-csv_get_line (guint line, GUI *appGUI) {
+void
+button_import_sel_window_close_cb (GtkWidget *widget, gpointer data) {
 
-gchar *line_buffer;
-gint c, i, n;
-gboolean line_found = FALSE, quotation_found;
+    GUI *appGUI = (GUI *)data;
 
-    line_buffer = NULL;
+    import_sel_window_close_cb (widget, NULL, appGUI);
 
-    i = 1;
-    n = 0;
-    quotation_found = FALSE;
+}
 
-    while (n != appGUI->cnt->file_length) {
-        c = appGUI->cnt->file_buffer[n];
-        if (i == line) {
-            line_found = TRUE;
+/*------------------------------------------------------------------------------*/
+
+void
+import_type_selected_cb (GtkComboBox *widget, gpointer user_data) {
+
+gint import_type;
+
+    GUI *appGUI = (GUI *)user_data;
+
+    import_type = gtk_combo_box_get_active (widget);
+
+    switch (import_type) {
+        case IMPORT_TYPE_FILE:
+            gtk_widget_set_sensitive(appGUI->cnt->file_import_vbox, TRUE);
+            gtk_widget_set_sensitive(appGUI->cnt->syncml_import_vbox, FALSE);
+            break;
+        case IMPORT_TYPE_SYNCML:
+            gtk_widget_set_sensitive(appGUI->cnt->syncml_import_vbox, TRUE);
+            gtk_widget_set_sensitive(appGUI->cnt->file_import_vbox, FALSE);
             break;
-        }
-        if (c == '"') {
-            quotation_found = !quotation_found;
-        }
-        if (c == '\n' && quotation_found == FALSE) i++;
-        n++;
     }
 
-    if (line_found == TRUE) {
-
-        line_buffer = g_malloc0 (MAX_LINE_LENGTH);
-        if (line_buffer != NULL) {
-
-            /* get single or multi line */
-
-            quotation_found = FALSE;
-            i = 0;
-            do {
-                c = appGUI->cnt->file_buffer[n];
-
-                if (c == '"') {
-                    quotation_found = !quotation_found;
-                }
-
-                if (c == '\n' && quotation_found == FALSE) break;
-
-                line_buffer[i++] = c;
-                n++;
-
-            } while (n != appGUI->cnt->file_length && i < MAX_LINE_LENGTH);
-
-            line_buffer[i] = 0;
-        }
-    }
-
-    return line_buffer;
 }
 
 /*------------------------------------------------------------------------------*/
 
-gchar *
-csv_get_field (gchar *line_buffer, guint field) {
-
-gchar *field_buffer;
-gint i, j, current_field;
-gboolean quotation_found;
-
-
-    field_buffer = g_malloc0 (MAX_FIELD_LENGTH);
-    if (field_buffer != NULL) {
-
-        quotation_found = FALSE;
-        i = j = 0;
-        current_field = 1;
-
-        while (line_buffer[i]) {
-
-            if (j >= MAX_FIELD_LENGTH-1) break;
-
-            if (line_buffer[i] == '"' && line_buffer[i+1] == '"') {
-                field_buffer[j++] = '"';
-                i++;
-            } else if (line_buffer[i] == '"' && line_buffer[i+1] != '"') {
-                quotation_found = !quotation_found;
-            } else if (line_buffer[i] == FIELD_SEPARATOR) {
-                if (quotation_found == FALSE) {
-                    if (current_field == field) break;
-                    current_field++;
-                    j = 0;
-                } else {
-                    /* ignore white chars */
-                    field_buffer[j++] = line_buffer[i];
-                    if (j == 1 && (line_buffer[i] == ' ' || line_buffer[i] == '\t')) --j;
-                    if (i > 0 && line_buffer[i] != 0) {
-                        if (line_buffer[i] == '"' && line_buffer[i-1] == FIELD_SEPARATOR) --j;
-                        if (line_buffer[i] == '"' && line_buffer[i+1] == 0) --j;
-                    }
-                }
-            } else {
-                /* ignore white chars */
-                field_buffer[j++] = line_buffer[i];
-                if (j == 1 && (line_buffer[i] == ' ' || line_buffer[i] == '\t')) --j;
-                if (i > 0 && line_buffer[i] != 0) {
-                    if (line_buffer[i] == '"' && line_buffer[i-1] == FIELD_SEPARATOR) --j;
-                    if (line_buffer[i] == '"' && line_buffer[i+1] == 0) --j;
-                }
-            }
-
-            i++;
-        }
-
-        field_buffer[j] = 0;
-
-        if (current_field != field) {
-            g_free(field_buffer);
-            field_buffer = NULL;
-        }
-    }
-
-    return field_buffer;
+gboolean
+import_sel_combo_box_focus_cb (GtkWidget *widget, GtkDirectionType *arg1, gpointer user_data) {
+    return TRUE;
 }
 
 /*------------------------------------------------------------------------------*/
 
-guint
-get_number_of_records (GUI *appGUI) {
+void
+import_sel_interface_changed_cb (GtkButton *button, gpointer user_data) {
 
-guint lines = 0, i;
-gboolean quotation_found = FALSE;
+    GUI *appGUI = (GUI *)user_data;
+
+    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->cnt->bluetooth_radiobutton)) == TRUE) {
+        gtk_widget_show (appGUI->cnt->bluetooth_params_hbox);
+        gtk_widget_hide (appGUI->cnt->usb_params_hbox);
+    } else {
+        gtk_widget_show (appGUI->cnt->usb_params_hbox);
+        gtk_widget_hide (appGUI->cnt->bluetooth_params_hbox);
+    }
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+import_sel_cb (GtkWidget *widget, gpointer user_data) {
+
+    GUI *appGUI = (GUI *)user_data;
+    gchar *text;
+    gchar tmpbuf[BUFFER_SIZE];
+
+    import_store_values (appGUI);
+
+    if (config.import_type == IMPORT_TYPE_FILE) {
+
+        /* FILE */
+
+        text = (gchar *)gtk_entry_get_text (GTK_ENTRY(appGUI->cnt->input_file_entry));
+
+        if (!strlen(text)) {
+            sprintf (tmpbuf, "%s", _("Please select file first."));
+            gui_create_dialog (GTK_MESSAGE_ERROR, tmpbuf, GTK_WINDOW(appGUI->cnt->import_sel_window));
+            return;
+        }
+        add_csv_records(text, appGUI);
+
+    } else {
+
+        /* SYNCML */
+
+#ifdef HAVE_LIBSYNCML
+        import_contacts_from_syncml (config.import_interface_type, appGUI);
+#endif
 
-    for (i=0; i != appGUI->cnt->file_length; i++) {
-       if (appGUI->cnt->file_buffer[i] == '"') {
-            quotation_found = !quotation_found;
-       }
-       if (appGUI->cnt->file_buffer[i] == '\n' && quotation_found == FALSE) {
-           lines++;
-       }
     }
 
-    return lines;
+    import_sel_window_close_cb (NULL, NULL, appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
 
+void
+import_contacts_show_dialog (GUI *appGUI) {
+
+GtkWidget *vbox1;
+GtkWidget *hseparator;
+GtkWidget *hbox1;
+GtkWidget *label;
+GtkWidget *frame;
+GtkWidget *alignment;
+GtkWidget *hbox4;
+GtkWidget *vbox4;
+GtkWidget *hbox6;
+GSList *radiobutton_group = NULL;
+GtkWidget *hbox7;
+GtkObject *bluetooth_channel_spinbutton_adj;
+GtkObject *usb_interface_spinbutton_adj;
+GtkWidget *cancel_button;
+GtkWidget *hbuttonbox;
+gchar tmpbuf[BUFFER_SIZE];
+
+
+    appGUI->cnt->import_sel_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+    gtk_container_set_border_width (GTK_CONTAINER (appGUI->cnt->import_sel_window), 6);
+    gtk_window_set_title (GTK_WINDOW (appGUI->cnt->import_sel_window), _("Import contacts"));
+
+    gtk_window_move (GTK_WINDOW (appGUI->cnt->import_sel_window), 
+                     config.contacts_import_sel_win_x, config.contacts_import_sel_win_y);
+    gtk_window_set_default_size (GTK_WINDOW(appGUI->cnt->import_sel_window), 450, -1);
+
+    gtk_window_set_transient_for(GTK_WINDOW(appGUI->cnt->import_sel_window), GTK_WINDOW(appGUI->main_window));
+    gtk_window_set_modal(GTK_WINDOW(appGUI->cnt->import_sel_window), TRUE);
+
+    g_signal_connect (G_OBJECT (appGUI->cnt->import_sel_window), "key_press_event", 
+                      G_CALLBACK (import_sel_key_press_cb), appGUI);
+
+    g_signal_connect (G_OBJECT (appGUI->cnt->import_sel_window), "delete_event", 
+                      G_CALLBACK(import_sel_window_close_cb), appGUI);
+
+    vbox1 = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (vbox1);
+    gtk_container_add (GTK_CONTAINER (appGUI->cnt->import_sel_window), vbox1);
+
+    hseparator = gtk_hseparator_new ();
+    gtk_widget_show (hseparator);
+    gtk_box_pack_start (GTK_BOX (vbox1), hseparator, FALSE, FALSE, 4);
+
+    hbox1 = gtk_hbox_new (FALSE, 0);
+    gtk_widget_show (hbox1);
+    gtk_box_pack_start (GTK_BOX (vbox1), hbox1, FALSE, FALSE, 0);
+
+    sprintf (tmpbuf, "%s:", _("Import type"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_box_pack_start (GTK_BOX (hbox1), label, FALSE, FALSE, 5);
+
+    appGUI->cnt->import_type_combobox = gtk_combo_box_new_text ();
+    gtk_widget_show (appGUI->cnt->import_type_combobox);
+    gtk_box_pack_start (GTK_BOX (hbox1), appGUI->cnt->import_type_combobox, FALSE, FALSE, 8);
+    gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->cnt->import_type_combobox), _("File"));
+    gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->cnt->import_type_combobox), "SyncML");
+    g_signal_connect (G_OBJECT (appGUI->cnt->import_type_combobox), "changed",
+                      G_CALLBACK (import_type_selected_cb), appGUI);
+    g_signal_connect(G_OBJECT(appGUI->cnt->import_type_combobox), "focus",
+                     G_CALLBACK(import_sel_combo_box_focus_cb), appGUI);
+
+    hseparator = gtk_hseparator_new ();
+    gtk_widget_show (hseparator);
+    gtk_box_pack_start (GTK_BOX (vbox1), hseparator, FALSE, TRUE, 4);
+
+    appGUI->cnt->file_import_vbox = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (appGUI->cnt->file_import_vbox);
+    gtk_box_pack_start (GTK_BOX (vbox1), appGUI->cnt->file_import_vbox, FALSE, FALSE, 0);
+
+    frame = gtk_frame_new (NULL);
+    gtk_widget_show (frame);
+    gtk_box_pack_start (GTK_BOX (appGUI->cnt->file_import_vbox), frame, FALSE, FALSE, 0);
+    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
+
+    alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
+    gtk_widget_show (alignment);
+    gtk_container_add (GTK_CONTAINER (frame), alignment);
+    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
+
+    hbox4 = gtk_hbox_new (FALSE, 0);
+    gtk_widget_show (hbox4);
+    gtk_container_add (GTK_CONTAINER (alignment), hbox4);
+
+    appGUI->cnt->input_file_entry = gtk_entry_new ();
+    gtk_widget_show (appGUI->cnt->input_file_entry);
+    gtk_box_pack_start (GTK_BOX (hbox4), appGUI->cnt->input_file_entry, TRUE, TRUE, 0);
+    GTK_WIDGET_UNSET_FLAGS(appGUI->cnt->input_file_entry, GTK_CAN_FOCUS);
+    gtk_editable_set_editable (GTK_EDITABLE(appGUI->cnt->input_file_entry), FALSE);
+
+    if (config.default_stock_icons) {
+        appGUI->cnt->contacts_browse_button = gui_stock_button (GTK_STOCK_DIRECTORY, FALSE);
+    } else {
+        appGUI->cnt->contacts_browse_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_OPEN);
+    }
+
+    GTK_WIDGET_UNSET_FLAGS(appGUI->cnt->contacts_browse_button, GTK_CAN_FOCUS);
+    gtk_widget_show (appGUI->cnt->contacts_browse_button);
+    gtk_box_pack_start (GTK_BOX (hbox4), appGUI->cnt->contacts_browse_button, FALSE, TRUE, 4);
+#ifdef HAVE_LIBSYNCML
+    g_signal_connect(appGUI->cnt->contacts_browse_button, "clicked", 
+                     G_CALLBACK(import_contacts_select_file_cb), appGUI);
+#endif
+
+    sprintf (tmpbuf, "<b>%s:</b>", _("Input filename"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_frame_set_label_widget (GTK_FRAME (frame), label);
+    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+
+    appGUI->cnt->syncml_import_vbox = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (appGUI->cnt->syncml_import_vbox);
+    gtk_box_pack_start (GTK_BOX (vbox1), appGUI->cnt->syncml_import_vbox, FALSE, FALSE, 0);
+
+    frame = gtk_frame_new (NULL);
+    gtk_widget_show (frame);
+    gtk_box_pack_start (GTK_BOX (appGUI->cnt->syncml_import_vbox), frame, TRUE, TRUE, 0);
+    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
+
+    alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
+    gtk_widget_show (alignment);
+    gtk_container_add (GTK_CONTAINER (frame), alignment);
+    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
+
+    vbox4 = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (vbox4);
+    gtk_container_add (GTK_CONTAINER (alignment), vbox4);
+
+    hbox6 = gtk_hbox_new (FALSE, 8);
+    gtk_widget_show (hbox6);
+    gtk_box_pack_start (GTK_BOX (vbox4), hbox6, TRUE, TRUE, 2);
+
+    appGUI->cnt->bluetooth_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, "Bluetooth");
+    gtk_widget_show (appGUI->cnt->bluetooth_radiobutton);
+    gtk_box_pack_start (GTK_BOX (hbox6), appGUI->cnt->bluetooth_radiobutton, FALSE, FALSE, 0);
+    gtk_radio_button_set_group (GTK_RADIO_BUTTON (appGUI->cnt->bluetooth_radiobutton), radiobutton_group);
+    g_signal_connect (G_OBJECT (appGUI->cnt->bluetooth_radiobutton), "clicked",
+                      G_CALLBACK(import_sel_interface_changed_cb), appGUI);
+    radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (appGUI->cnt->bluetooth_radiobutton));
+
+    appGUI->cnt->usb_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, "USB");
+    gtk_widget_show (appGUI->cnt->usb_radiobutton);
+    gtk_box_pack_start (GTK_BOX (hbox6), appGUI->cnt->usb_radiobutton, FALSE, FALSE, 0);
+    gtk_radio_button_set_group (GTK_RADIO_BUTTON (appGUI->cnt->usb_radiobutton), radiobutton_group);
+    radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (appGUI->cnt->usb_radiobutton));
+
+    hbox7 = gtk_hbox_new (FALSE, 8);
+    gtk_widget_show (hbox7);
+    gtk_box_pack_start (GTK_BOX (vbox4), hbox7, TRUE, TRUE, 2);
+
+    appGUI->cnt->bluetooth_params_hbox = gtk_hbox_new (FALSE, 4);
+    gtk_widget_show (appGUI->cnt->bluetooth_params_hbox);
+    gtk_box_pack_start (GTK_BOX (hbox7), appGUI->cnt->bluetooth_params_hbox, TRUE, TRUE, 0);
+
+    sprintf (tmpbuf, "%s:", _("Address"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_box_pack_start (GTK_BOX (appGUI->cnt->bluetooth_params_hbox), label, FALSE, FALSE, 0);
+
+    appGUI->cnt->bluetooth_address_entry = gtk_entry_new ();
+    gtk_widget_show (appGUI->cnt->bluetooth_address_entry);
+    gtk_box_pack_start (GTK_BOX (appGUI->cnt->bluetooth_params_hbox), appGUI->cnt->bluetooth_address_entry, TRUE, TRUE, 0);
+    gtk_entry_set_max_length (GTK_ENTRY(appGUI->cnt->bluetooth_address_entry), 17);    /* 00:00:00:00:00:00 */
+
+    sprintf (tmpbuf, "%s:", _("Channel"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_box_pack_start (GTK_BOX (appGUI->cnt->bluetooth_params_hbox), label, FALSE, FALSE, 0);
+
+    bluetooth_channel_spinbutton_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
+    appGUI->cnt->bluetooth_channel_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (bluetooth_channel_spinbutton_adj), 1, 0);
+    gtk_widget_show (appGUI->cnt->bluetooth_channel_spinbutton);
+    gtk_box_pack_start (GTK_BOX (appGUI->cnt->bluetooth_params_hbox), appGUI->cnt->bluetooth_channel_spinbutton, FALSE, FALSE, 0);
+
+    appGUI->cnt->usb_params_hbox = gtk_hbox_new (FALSE, 4);
+    gtk_widget_show (appGUI->cnt->usb_params_hbox);
+    gtk_box_pack_start (GTK_BOX (hbox7), appGUI->cnt->usb_params_hbox, TRUE, TRUE, 0);
+
+    sprintf (tmpbuf, "%s:", _("Interface"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_box_pack_start (GTK_BOX (appGUI->cnt->usb_params_hbox), label, FALSE, FALSE, 0);
+
+    usb_interface_spinbutton_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
+    appGUI->cnt->usb_interface_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (usb_interface_spinbutton_adj), 1, 0);
+    gtk_widget_show (appGUI->cnt->usb_interface_spinbutton);
+    gtk_box_pack_start (GTK_BOX (appGUI->cnt->usb_params_hbox), appGUI->cnt->usb_interface_spinbutton, FALSE, FALSE, 0);
+
+    sprintf (tmpbuf, "<b>%s</b>", _("Interface"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_frame_set_label_widget (GTK_FRAME (frame), label);
+    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+
+    frame = gtk_frame_new (NULL);
+    gtk_widget_show (frame);
+    gtk_box_pack_start (GTK_BOX (appGUI->cnt->syncml_import_vbox), frame, TRUE, TRUE, 0);
+    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
+
+    alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
+    gtk_widget_show (alignment);
+    gtk_container_add (GTK_CONTAINER (frame), alignment);
+    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 2, 2, 12, 0);
+
+    appGUI->cnt->use_wbxml_checkbutton = gtk_check_button_new_with_mnemonic (_("Use binary XML (WBXML)"));
+    gtk_widget_show (appGUI->cnt->use_wbxml_checkbutton);
+    gtk_container_add (GTK_CONTAINER (alignment), appGUI->cnt->use_wbxml_checkbutton);
+
+    sprintf (tmpbuf, "<b>%s</b>", _("Options"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_frame_set_label_widget (GTK_FRAME (frame), label);
+    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+
+    hseparator = gtk_hseparator_new ();
+    gtk_widget_show (hseparator);
+    gtk_box_pack_start (GTK_BOX (vbox1), hseparator, FALSE, TRUE, 4);
+
+    hbuttonbox = gtk_hbutton_box_new ();
+    gtk_widget_show (hbuttonbox);
+    gtk_box_pack_start (GTK_BOX (vbox1), hbuttonbox, FALSE, TRUE, 0);
+    gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
+    gtk_box_set_spacing (GTK_BOX (hbuttonbox), 8);
+
+    if (config.default_stock_icons) {
+        cancel_button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
+    } else {
+        cancel_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_CANCEL);
+    }
+    gtk_widget_show (cancel_button);
+    gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
+    g_signal_connect(cancel_button, "clicked", 
+                     G_CALLBACK(button_import_sel_window_close_cb), appGUI);
+
+    appGUI->cnt->import_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_CONTACTS_IMPORT);
+    gtk_widget_show (appGUI->cnt->import_button);
+    gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->cnt->import_button);
+    g_signal_connect(appGUI->cnt->import_button, "clicked",
+                     G_CALLBACK(import_sel_cb), appGUI);
+
+    /* setup fields */
+
+    gtk_combo_box_set_active (GTK_COMBO_BOX (appGUI->cnt->import_type_combobox), config.import_type);
+
+    if (config.import_interface_type == 0) {    /* bluetooth */
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->cnt->bluetooth_radiobutton), TRUE);
+    } else {
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->cnt->usb_radiobutton), TRUE);
+    }
+    import_sel_interface_changed_cb (GTK_BUTTON(appGUI->cnt->bluetooth_radiobutton), appGUI);
+
+    gtk_entry_set_text (GTK_ENTRY(appGUI->cnt->bluetooth_address_entry), 
+                        config.import_bluetooth_address);
+
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->cnt->use_wbxml_checkbutton), config.import_binary_xml);
+
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->cnt->bluetooth_channel_spinbutton), config.import_bluetooth_channel);
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->cnt->usb_interface_spinbutton), config.import_usb_interface);
+
+    gtk_widget_show (appGUI->cnt->import_sel_window);
+
+}
+
+/*-------------------------------------------------------------------------------------*/
+
+/*gboolean*/
+/*import_contacts_from_csv_file (GUI *appGUI) {*/
+
+/*GtkWidget *dialog;*/
+/*gboolean ret = FALSE;*/
+/*GtkFileFilter *filter_1, *filter_2;*/
+
+    /*dialog = gtk_file_chooser_dialog_new(_("Select CSV file"),*/
+                                         /*GTK_WINDOW(appGUI->main_window),*/
+                                         /*GTK_FILE_CHOOSER_ACTION_OPEN,*/
+                                         /*GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,*/
+                                         /*GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,*/
+                                         /*NULL);*/
+
+    /*gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);*/
+    /*gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(dialog), FALSE);*/
+    /*gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_ACCEPT);*/
+
+    /*filter_1 = gtk_file_filter_new();*/
+    /*gtk_file_filter_add_pattern(filter_1, "*");*/
+    /*gtk_file_filter_set_name(GTK_FILE_FILTER(filter_1), _("All Files"));*/
+    /*gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(dialog), filter_1);*/
+
+    /*filter_2 = gtk_file_filter_new();*/
+    /*gtk_file_filter_add_pattern(filter_2, "*.[cC][sS][vV]");*/
+    /*gtk_file_filter_set_name(GTK_FILE_FILTER(filter_2), _("CSV (comma-separated values) files (*.csv)"));*/
+    /*gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(dialog), filter_2);*/
+
+    /*gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(dialog), filter_2);*/
+
+
+    /*if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT) {*/
+
+        /*gtk_widget_hide(dialog);*/
+        /*while (g_main_context_iteration(NULL, FALSE));*/
+
+        /*ret = add_csv_records(gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog)), appGUI);*/
+
+    /*}*/
+
+    /*gtk_widget_destroy(dialog);*/
+
+    /*return ret;*/
+/*}*/
+
+/*------------------------------------------------------------------------------*/
+
 void
 import_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data) {
  
