@@ -19,26 +19,15 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-
-#include <stdio.h>
-#include <string.h>
-#include <glib.h>
-#include <time.h>
-#include <ctype.h>
-#include <libxml/xmlmemory.h>
-#include <libxml/parser.h>
-
+#include "contacts_items.h"
 #include "i18n.h"
 #include "contacts.h"
-#include "contacts_items.h"
 #include "tasks.h"
-#include "gui.h"
 #include "gui_utils.h"
 #include "calendar.h"
 #include "calendar_notes.h"
 #include "calendar_widget.h"
-#include "time_utils.h"
-#include "date_utils.h"
+#include "calendar_utils.h"
 #include "options_prefs.h"
 #include "stock_icons.h"
 
@@ -59,6 +48,20 @@ gint i;
 
 /*------------------------------------------------------------------------------*/
 
+void
+contacts_add_edit_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data) {
+
+    GUI *appGUI = (GUI *)user_data;
+
+    gtk_window_get_size (GTK_WINDOW(appGUI->cnt->contacts_add_window),
+                        &config.contacts_addedit_win_w, &config.contacts_addedit_win_h);
+    gdk_window_get_root_origin (appGUI->cnt->contacts_add_window->window,
+                        &config.contacts_addedit_win_x, &config.contacts_addedit_win_y);
+    gtk_widget_destroy(appGUI->cnt->contacts_add_window);
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 contacts_item_entered_cb (GtkWidget *widget, gpointer data) {
 
@@ -144,7 +147,9 @@ const gchar *text;
         }
     }
 
-    gtk_widget_destroy(appGUI->cnt->contacts_add_window);
+    contacts_add_edit_window_close_cb (NULL, NULL, appGUI);
+   
+    pango_font_description_free(appGUI->cnt->fd_ai_font);
 
     path = gtk_tree_model_get_path (GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter);
     if (path != NULL) {
@@ -162,6 +167,8 @@ const gchar *text;
     set_export_active(appGUI);
     gui_systray_tooltip_update(appGUI);
     contacts_fill_ids (appGUI);
+    calendar_refresh_marks (appGUI);
+    update_aux_calendars (appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -213,24 +220,12 @@ gchar tmpbuf[BUFFER_SIZE];
 /*------------------------------------------------------------------------------*/
 
 void
-contacts_add_edit_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data) {
+button_contacts_add_edit_window_close_cb (GtkWidget *widget, gpointer user_data) {
 
     GUI *appGUI = (GUI *)user_data;
 
-    gtk_window_get_size (GTK_WINDOW(appGUI->cnt->contacts_add_window),
-                        &config.contacts_addedit_win_w, &config.contacts_addedit_win_h);
-    gdk_window_get_root_origin (appGUI->cnt->contacts_add_window->window,
-                        &config.contacts_addedit_win_x, &config.contacts_addedit_win_y);
-    gtk_widget_destroy(appGUI->cnt->contacts_add_window);
-}
-
-/*------------------------------------------------------------------------------*/
-
-void
-button_contacts_add_edit_window_close_cb (GtkWidget *widget, gpointer data) {
-
-    contacts_add_edit_window_close_cb (widget, NULL, data);
-
+    contacts_add_edit_window_close_cb (widget, NULL, appGUI);
+    pango_font_description_free(appGUI->cnt->fd_ai_font);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -373,6 +368,35 @@ select_date_nodate_cb (GuiCalendar *s_calendar, gpointer user_data) {
 
 /*------------------------------------------------------------------------------*/
 
+void
+next_field_button_clicked_cb (GtkWidget *widget, gpointer user_data) {
+
+const gchar *text;
+
+    MESSAGE *msg = (MESSAGE *)user_data;
+    gint i = (gint) msg->data;
+
+    text = gtk_entry_get_text (GTK_ENTRY(msg->appGUI->cnt->contact_entries[i]));
+
+    if(strlen(text) && i != COLUMN_HOME_PHONE_4 && i != COLUMN_WORK_PHONE_4 &&
+       i != COLUMN_CELL_PHONE_4 && i != COLUMN_EMAIL_4 && i != COLUMN_WWW_4) {
+        gtk_widget_set_sensitive (msg->appGUI->cnt->next_field_button[i], FALSE);
+        gtk_widget_show (msg->appGUI->cnt->contact_entries[i+1]);
+
+        if (msg->appGUI->cnt->next_field_button[i+1] != NULL) {
+            gtk_widget_show (msg->appGUI->cnt->next_field_button[i+1]);
+        }
+
+        gtk_widget_grab_focus (msg->appGUI->cnt->contact_entries[i+1]);
+
+        if (i+1 == COLUMN_SECOND_NAME) {
+            gtk_widget_show (msg->appGUI->cnt->second_name_label);
+        }
+    }
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 date_select_cb (GtkWidget *widget, gpointer user_data) {
 
@@ -404,13 +428,25 @@ static MESSAGE msg_selected;
     gtk_container_set_border_width (GTK_CONTAINER (alignment), 4);
 
     msg->appGUI->cnt->select_date_calendar = gui_calendar_new();
-    gui_calendar_set_cursor_type(GUI_CALENDAR(msg->appGUI->cnt->select_date_calendar), CURSOR_BLOCK);
+    gui_calendar_set_cursor_type (GUI_CALENDAR(msg->appGUI->cnt->select_date_calendar), CURSOR_BLOCK);
+    gui_calendar_set_selector_alpha (GUI_CALENDAR (msg->appGUI->cnt->select_date_calendar), 
+                                             config.selector_alpha);
+    gui_calendar_set_today_marker_type (GUI_CALENDAR (msg->appGUI->cnt->select_date_calendar), 
+                                             config.today_marker_type);
+    gui_calendar_set_today_marker_color (GUI_CALENDAR (msg->appGUI->cnt->select_date_calendar), 
+                                             config.mark_current_day_color);
+    gui_calendar_set_today_marker_alpha (GUI_CALENDAR (msg->appGUI->cnt->select_date_calendar), 
+                                             config.mark_current_day_alpha);
     gtk_widget_show(msg->appGUI->cnt->select_date_calendar);
     msg_selected.data = msg->data;
     msg_selected.appGUI = msg->appGUI;
     g_signal_connect (GTK_OBJECT (msg->appGUI->cnt->select_date_calendar), "day_selected_double_click",
                       G_CALLBACK (select_date_selected_cb), &msg_selected);
     gtk_container_add (GTK_CONTAINER (alignment), msg->appGUI->cnt->select_date_calendar);
+    gui_calendar_set_display_options (GUI_CALENDAR (msg->appGUI->cnt->select_date_calendar), 
+                                      (config.display_options & !GUI_CALENDAR_NO_MONTH_CHANGE) | 
+                                      GUI_CALENDAR_SHOW_HEADING | GUI_CALENDAR_SHOW_DAY_NAMES | 
+                                      (config.display_options & GUI_CALENDAR_WEEK_START_MONDAY));
 
     alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
     gtk_widget_show (alignment);
@@ -440,9 +476,9 @@ static MESSAGE msg_selected;
                         G_CALLBACK (select_date_ok_cb), &msg_selected);
 
     if (config.default_stock_icons) {
-        close_button = gui_stock_button(GTK_STOCK_CLOSE, FALSE);
+        close_button = gui_stock_button(GTK_STOCK_CANCEL, FALSE);
     } else {
-        close_button = gui_stock_button(OSMO_STOCK_BUTTON_CLOSE, FALSE);
+        close_button = gui_stock_button(OSMO_STOCK_BUTTON_CANCEL, FALSE);
     }
     GTK_WIDGET_UNSET_FLAGS(close_button, GTK_CAN_FOCUS);
     gtk_button_set_relief (GTK_BUTTON(close_button), GTK_RELIEF_NONE);
@@ -453,9 +489,6 @@ static MESSAGE msg_selected;
 
     gtk_widget_show (msg->appGUI->cnt->select_date_window);
 
-    gui_calendar_set_display_options (GUI_CALENDAR (msg->appGUI->cnt->select_date_calendar), 
-                                      (config.display_options & !GUI_CALENDAR_NO_MONTH_CHANGE) | GUI_CALENDAR_SHOW_HEADING | GUI_CALENDAR_SHOW_DAY_NAMES);
-
     if (msg->data == (gpointer)COLUMN_BIRTH_DAY_DATE) {
         if (g_date_valid_julian(msg->appGUI->cnt->birthday_date)) {
             cdate = g_date_new_julian (msg->appGUI->cnt->birthday_date);
@@ -632,7 +665,7 @@ gchar *contact_replace_tags[] = {
                       (GtkAttachOptions) (GTK_FILL), 0, 0);
     gtk_widget_set_size_request (hseparator, 20, -1);
 
-    sprintf(tmpbuf, "<b>%s</b>", _("Personal"));
+    sprintf(tmpbuf, "<b><big>%s</big></b>", _("Personal"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_table_attach (GTK_TABLE (table), label, 1, 2, pos, pos+1,
@@ -687,18 +720,39 @@ gchar *contact_replace_tags[] = {
         gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
         appGUI->cnt->contact_entries[i] = gtk_entry_new ();
+
+        if (i == COLUMN_FIRST_NAME) {
+            appGUI->cnt->next_field_button[i] = gui_stock_button (GTK_STOCK_GO_DOWN, FALSE);
+            gtk_widget_show (appGUI->cnt->next_field_button[i]);
+            GTK_WIDGET_UNSET_FLAGS(appGUI->cnt->next_field_button[i], GTK_CAN_FOCUS);
+        }
+
         if (i != COLUMN_SECOND_NAME) {
             gtk_widget_show (appGUI->cnt->contact_entries[i]);
         }
+
         if (i == COLUMN_FIRST_NAME) {
             msg_index[i].appGUI = appGUI;
             msg_index[i].data = GINT_TO_POINTER(i);
             g_signal_connect (G_OBJECT (appGUI->cnt->contact_entries[i]), "key_press_event",
                               G_CALLBACK (show_hide_fields_key_press_cb), &msg_index[i]);
+
+            gtk_table_attach (GTK_TABLE (table), appGUI->cnt->contact_entries[i], 2, 3, pos, pos+1,
+                              (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+                              (GtkAttachOptions) (0), 0, 0);
+
+            g_signal_connect (G_OBJECT (appGUI->cnt->next_field_button[i]), "clicked",
+                              G_CALLBACK (next_field_button_clicked_cb), &msg_index[i]);
+            gtk_table_attach (GTK_TABLE (table), appGUI->cnt->next_field_button[i], 3, 4, pos, pos+1,
+                              (GtkAttachOptions) (GTK_FILL),
+                              (GtkAttachOptions) (0), 0, 0);
+        } else {
+
+            gtk_table_attach (GTK_TABLE (table), appGUI->cnt->contact_entries[i], 2, 4, pos, pos+1,
+                              (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+                              (GtkAttachOptions) (0), 0, 0);
         }
-        gtk_table_attach (GTK_TABLE (table), appGUI->cnt->contact_entries[i], 2, 4, pos, pos+1,
-                          (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-                          (GtkAttachOptions) (0), 0, 0);
+
         pos++;
     }
 
@@ -806,7 +860,7 @@ gchar *contact_replace_tags[] = {
                       (GtkAttachOptions) (GTK_FILL), 0, 0);
     gtk_widget_set_size_request (hseparator, 20, -1);
 
-    sprintf(tmpbuf, "<b>%s</b>", _("Home"));
+    sprintf(tmpbuf, "<b><big>%s</big></b>", _("Home"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_table_attach (GTK_TABLE (table), label, 1, 2, pos, pos+1,
@@ -851,7 +905,7 @@ gchar *contact_replace_tags[] = {
                       (GtkAttachOptions) (GTK_FILL), 0, 0);
     gtk_widget_set_size_request (hseparator, 20, -1);
 
-    sprintf(tmpbuf, "<b>%s</b>", _("Work"));
+    sprintf(tmpbuf, "<b><big>%s</big></b>", _("Work"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_table_attach (GTK_TABLE (table), label, 1, 2, pos, pos+1,
@@ -900,7 +954,7 @@ gchar *contact_replace_tags[] = {
                       (GtkAttachOptions) (GTK_FILL), 0, 0);
     gtk_widget_set_size_request (hseparator, 20, -1);
 
-    sprintf(tmpbuf, "<b>%s</b>", _("Phones"));
+    sprintf(tmpbuf, "<b><big>%s</big></b>", _("Phones"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_table_attach (GTK_TABLE (table), label, 1, 2, pos, pos+1,
@@ -928,7 +982,7 @@ gchar *contact_replace_tags[] = {
         gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
         appGUI->cnt->contact_entries[i] = gtk_entry_new ();
-        gtk_table_attach (GTK_TABLE (table), appGUI->cnt->contact_entries[i], 2, 4, pos, pos+1,
+        gtk_table_attach (GTK_TABLE (table), appGUI->cnt->contact_entries[i], 2, 3, pos, pos+1,
                           (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                           (GtkAttachOptions) (0), 0, 0);
         msg_index[i].appGUI = appGUI;
@@ -936,9 +990,25 @@ gchar *contact_replace_tags[] = {
         g_signal_connect (G_OBJECT (appGUI->cnt->contact_entries[i]), "key_press_event",
                           G_CALLBACK (show_hide_fields_key_press_cb), &msg_index[i]);
 
+        if (i != COLUMN_HOME_PHONE_4 && i != COLUMN_WORK_PHONE_4 && i != COLUMN_CELL_PHONE_4) {
+
+            appGUI->cnt->next_field_button[i] = gui_stock_button (GTK_STOCK_GO_DOWN, FALSE);
+            gtk_widget_hide (appGUI->cnt->next_field_button[i]);
+            GTK_WIDGET_UNSET_FLAGS(appGUI->cnt->next_field_button[i], GTK_CAN_FOCUS);
+
+            g_signal_connect (G_OBJECT (appGUI->cnt->next_field_button[i]), "clicked",
+                              G_CALLBACK (next_field_button_clicked_cb), &msg_index[i]);
+            gtk_table_attach (GTK_TABLE (table), appGUI->cnt->next_field_button[i], 3, 4, pos, pos+1,
+                              (GtkAttachOptions) (GTK_FILL),
+                              (GtkAttachOptions) (0), 0, 0);
+        } else {
+            appGUI->cnt->next_field_button[i] = NULL;
+        }
+
         if(i == COLUMN_HOME_PHONE_1 || i == COLUMN_WORK_PHONE_1 || i == COLUMN_CELL_PHONE_1) {
             gtk_widget_show (label);
             gtk_widget_show (appGUI->cnt->contact_entries[i]);
+            gtk_widget_show (appGUI->cnt->next_field_button[i]);
         }
 
         pos++;
@@ -953,7 +1023,7 @@ gchar *contact_replace_tags[] = {
                       (GtkAttachOptions) (GTK_FILL), 0, 0);
     gtk_widget_set_size_request (hseparator, 20, -1);
 
-    sprintf(tmpbuf, "<b>%s</b>", _("Internet"));
+    sprintf(tmpbuf, "<b><big>%s</big></b>", _("Internet"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_table_attach (GTK_TABLE (table), label, 1, 2, pos, pos+1,
@@ -983,7 +1053,7 @@ gchar *contact_replace_tags[] = {
 
         appGUI->cnt->contact_entries[i] = gtk_entry_new ();
         gtk_widget_show (appGUI->cnt->contact_entries[i]);
-        gtk_table_attach (GTK_TABLE (table), appGUI->cnt->contact_entries[i], 2, 4, pos, pos+1,
+        gtk_table_attach (GTK_TABLE (table), appGUI->cnt->contact_entries[i], 2, 3, pos, pos+1,
                           (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                           (GtkAttachOptions) (0), 0, 0);
         msg_index[i].appGUI = appGUI;
@@ -991,6 +1061,27 @@ gchar *contact_replace_tags[] = {
         g_signal_connect (G_OBJECT (appGUI->cnt->contact_entries[i]), "key_press_event",
                           G_CALLBACK (show_hide_fields_key_press_cb), &msg_index[i]);
 
+        if (i == COLUMN_EMAIL_1 || i == COLUMN_EMAIL_2 || i == COLUMN_EMAIL_3 || 
+            i == COLUMN_WWW_1 || i == COLUMN_WWW_2 || i == COLUMN_WWW_3) {
+
+            appGUI->cnt->next_field_button[i] = gui_stock_button (GTK_STOCK_GO_DOWN, FALSE);
+            gtk_widget_hide (appGUI->cnt->next_field_button[i]);
+            GTK_WIDGET_UNSET_FLAGS(appGUI->cnt->next_field_button[i], GTK_CAN_FOCUS);
+
+            g_signal_connect (G_OBJECT (appGUI->cnt->next_field_button[i]), "clicked",
+                              G_CALLBACK (next_field_button_clicked_cb), &msg_index[i]);
+            gtk_table_attach (GTK_TABLE (table), appGUI->cnt->next_field_button[i], 3, 4, pos, pos+1,
+                              (GtkAttachOptions) (GTK_FILL),
+                              (GtkAttachOptions) (0), 0, 0);
+        } else {
+            appGUI->cnt->next_field_button[i] = NULL;
+        }
+
+
+        if(i == COLUMN_EMAIL_1 || i == COLUMN_WWW_1) {
+            gtk_widget_show (appGUI->cnt->next_field_button[i]);
+        }
+
         if((i > COLUMN_EMAIL_1  && i < COLUMN_WWW_1) || (i > COLUMN_WWW_1  && i < COLUMN_IM_GG)) {
             gtk_widget_hide (label);
             gtk_widget_hide (appGUI->cnt->contact_entries[i]);
@@ -1008,7 +1099,7 @@ gchar *contact_replace_tags[] = {
                       (GtkAttachOptions) (GTK_FILL), 0, 0);
     gtk_widget_set_size_request (hseparator, 20, -1);
 
-    sprintf(tmpbuf, "<b>%s</b>", _("Additional info"));
+    sprintf(tmpbuf, "<b><big>%s</big></b>", _("Additional info"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_table_attach (GTK_TABLE (table), label, 1, 2, pos, pos+1,
@@ -1043,6 +1134,9 @@ gchar *contact_replace_tags[] = {
     gtk_widget_set_size_request (appGUI->cnt->add_info_textview, -1, 350);
     gtk_widget_show (appGUI->cnt->add_info_textview);
 
+    appGUI->cnt->fd_ai_font = pango_font_description_from_string(config.contact_item_font);
+    gtk_widget_modify_font (GTK_WIDGET(appGUI->cnt->add_info_textview), appGUI->cnt->fd_ai_font);
+
     /*-------------------------------------------------------------------------*/
 
     hseparator = gtk_hseparator_new ();
@@ -1118,6 +1212,9 @@ gchar *contact_replace_tags[] = {
                             gtk_text_view_set_buffer(GTK_TEXT_VIEW(appGUI->cnt->add_info_textview), text_buffer);
                         } else {
                             gtk_entry_set_text (GTK_ENTRY(appGUI->cnt->contact_entries[i]), text);
+                            if (appGUI->cnt->next_field_button[i] != NULL) {
+                                gtk_widget_show (appGUI->cnt->next_field_button[i]);
+                            }
                         }
                         g_free(text);
                     }
@@ -1151,10 +1248,10 @@ gint j;
 guint32 date;
 gchar tmpbuf[BUFFER_SIZE];
 
-    if (g_file_test (prefs_get_config_filename(CONTACTS_ENTRIES_FILENAME), G_FILE_TEST_IS_REGULAR) == FALSE) 
+    if (g_file_test (prefs_get_config_filename(CONTACTS_ENTRIES_FILENAME, appGUI), G_FILE_TEST_IS_REGULAR) == FALSE) 
         return;
 
-    if((doc = xmlParseFile(prefs_get_config_filename(CONTACTS_ENTRIES_FILENAME)))) {
+    if((doc = xmlParseFile(prefs_get_config_filename(CONTACTS_ENTRIES_FILENAME, appGUI)))) {
 
         if(!(node = xmlDocGetRootElement(doc))) {
             xmlFreeDoc(doc);
@@ -1203,8 +1300,8 @@ gchar tmpbuf[BUFFER_SIZE];
                         cnode = node->xmlChildrenNode;
 
                         gtk_list_store_append(appGUI->cnt->contacts_list_store, &iter);
-                        gtk_list_store_set(appGUI->cnt->contacts_list_store, &iter, COLUMN_GROUP, _("None"), -1);
                         sprintf(tmpbuf, "(%s)", _("None"));
+                        gtk_list_store_set(appGUI->cnt->contacts_list_store, &iter, COLUMN_GROUP, tmpbuf, -1);
                         gtk_list_store_set(appGUI->cnt->contacts_list_store, &iter, COLUMN_FIRST_NAME, tmpbuf, -1);
                         gtk_list_store_set(appGUI->cnt->contacts_list_store, &iter, COLUMN_LAST_NAME, tmpbuf, -1);
 
@@ -1268,6 +1365,7 @@ GtkTreeIter iter;
 gchar *item;
 guint32 date;
 gchar temp[BUFFER_SIZE];
+xmlChar *escaped;
 
     doc = xmlNewDoc((const xmlChar *) "1.0");
     attr = xmlNewDocProp (doc, (const xmlChar *) "encoding", (const xmlChar *) "utf-8");
@@ -1309,8 +1407,11 @@ gchar temp[BUFFER_SIZE];
 
                     if (item != NULL) {
                         if (strlen(item)) {
-                            xmlNewChild(note_node, NULL, (const xmlChar *) appGUI->cnt->contact_fields_tags_name[j*2+1], 
-                                        (xmlChar *) item);
+							escaped = xmlEncodeEntitiesReentrant(doc,
+								(const xmlChar *) item);
+                            xmlNewChild(note_node, NULL, (const xmlChar *) appGUI->cnt->contact_fields_tags_name[j*2+1],
+                                        escaped);
+							xmlFree(escaped);
                         }
                     }
 
@@ -1320,7 +1421,7 @@ gchar temp[BUFFER_SIZE];
         }
     }
 
-    xmlSaveFormatFileEnc(prefs_get_config_filename(CONTACTS_ENTRIES_FILENAME), doc, "utf-8", 1);
+    xmlSaveFormatFileEnc(prefs_get_config_filename(CONTACTS_ENTRIES_FILENAME, appGUI), doc, "utf-8", 1);
     xmlFreeDoc(doc);
 }
 
