@@ -19,18 +19,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include <stdio.h>
-#include <string.h>
-#include <ctype.h>
-#include <time.h>
-#include <gtk/gtk.h>
-#include <glib.h>
-#include <glib/gprintf.h>
-#include <gdk/gdkkeysyms.h>
-#include <config.h>
-
-#include "i18n.h"
 #include "gui.h"
+#include "i18n.h"
 #include "gui_utils.h"
 #include "calendar.h"
 #include "calendar_notes.h"
@@ -41,8 +31,7 @@
 #ifdef HAVE_LIBICAL
 #include "calendar_ical.h"
 #endif  /* HAVE_LIBICAL */
-#include "time_utils.h"
-#include "date_utils.h"
+#include "calendar_utils.h"
 #include "notes.h"
 #include "notes_items.h"
 #include "tasks.h"
@@ -53,11 +42,40 @@
 #include "options_gui.h"
 #include "options_prefs.h"
 #include "options_gui_general.h"
+#include "check_events.h"
 #include "stock_icons.h"
 #include "config.h"
 
 #include "gui_logo.h"
 #include "gui_icon.h"
+#include "credits.h"
+
+/*------------------------------------------------------------------------------*/
+
+void
+gui_save_data_and_run_command (gchar *command, GUI *appGUI) {
+    gui_save_all_data (appGUI);
+    gui_run_command (command);
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+gui_save_all_data (GUI *appGUI) {
+
+    write_notes (appGUI);
+    write_tasks_entries(appGUI);
+#ifdef HAVE_LIBICAL
+    write_ical_entries(appGUI);
+    ics_calendar_refresh (appGUI);
+#endif  /* HAVE_LIBICAL */
+    write_contacts_entries(appGUI);
+#ifdef HAVE_LIBGRINGOTTS
+    write_notes_entries (appGUI);
+#endif  /* HAVE_LIBGRINGOTTS */
+    prefs_write_config (appGUI);
+
+}
 
 /*------------------------------------------------------------------------------*/
 
@@ -74,19 +92,7 @@ gui_toggle_window_visibility (GUI *appGUI) {
             gtk_widget_show (appGUI->main_window);
         } else {
             if (appGUI->calendar_only == FALSE) {
-                config.lastrun_date = get_julian_for_today();
-                config.lastrun_time = get_seconds_for_today();
-                write_notes (appGUI);
-                write_tasks_entries(appGUI);
-#ifdef HAVE_LIBICAL
-                write_ical_entries(appGUI);
-                ics_calendar_refresh (appGUI);
-#endif  /* HAVE_LIBICAL */
-                write_contacts_entries(appGUI);
-#ifdef HAVE_LIBGRINGOTTS
-                write_notes_entries (appGUI);
-#endif  /* HAVE_LIBGRINGOTTS */
-                prefs_write_config ();
+                gui_save_all_data (appGUI);
             }
             gtk_widget_hide (appGUI->main_window);
         }
@@ -96,7 +102,7 @@ gui_toggle_window_visibility (GUI *appGUI) {
 /*------------------------------------------------------------------------------*/
 
 void
-gui_quit_osmo (GUI *appGUI) {
+gui_quit_osmo (gboolean ignore_geometry, GUI *appGUI) {
 
 #ifdef HAVE_LIBGRINGOTTS
     if (appGUI->nte->editor_active == TRUE) {
@@ -122,30 +128,29 @@ gui_quit_osmo (GUI *appGUI) {
 
         gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON(appGUI->cal->notes_button), FALSE);
 
-        gtk_window_get_size (GTK_WINDOW(appGUI->main_window),
-                            &config.window_size_x, &config.window_size_y);
+        if (ignore_geometry == FALSE) {
+            gtk_window_get_size (GTK_WINDOW(appGUI->main_window),
+                                &config.window_size_x, &config.window_size_y);
+        }
+    } 
+
+    if (ignore_geometry == FALSE) {
+        gdk_window_get_root_origin (GDK_WINDOW(appGUI->main_window->window),
+                            &config.window_x, &config.window_y);
     }
 
-    gdk_window_get_root_origin (GDK_WINDOW(appGUI->main_window->window),
-                        &config.window_x, &config.window_y);
+    pango_font_description_free(appGUI->cal->fd_day_name_font);
+    pango_font_description_free(appGUI->cal->fd_cal_font);
+    pango_font_description_free(appGUI->cal->fd_notes_font);
 
-    pango_font_description_free(appGUI->fd_calendar_day_name);
-    pango_font_description_free(appGUI->fd_calendar_cal);
-    pango_font_description_free(appGUI->fd_calendar_notes);
-
-    pango_font_description_free(appGUI->fd_notes_editor);
+    pango_font_description_free(appGUI->nte->fd_notes_font);
 
     if (appGUI->calendar_only == FALSE) {
-        write_notes (appGUI);
-        free_notes_list(appGUI);
-        write_tasks_entries(appGUI);
-#ifdef HAVE_LIBICAL
-        write_ical_entries(appGUI);
-#endif  /* HAVE_LIBICAL */
-        write_contacts_entries(appGUI);
-#ifdef HAVE_LIBGRINGOTTS
-        write_notes_entries (appGUI);
-#endif  /* HAVE_LIBGRINGOTTS */
+        config.lastrun_date = get_julian_for_today();
+        config.lastrun_time = get_seconds_for_today();
+        gui_save_all_data (appGUI);
+        free_notifications_list (appGUI);
+        free_notes_list (appGUI);
     }
 
     gui_url_remove_links (&appGUI->about_links_list, &appGUI->about_link_index);
@@ -164,7 +169,7 @@ gui_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data) {
     if (config.enable_systray == TRUE && appGUI->no_tray == FALSE && appGUI->calendar_only == FALSE) {
         gui_toggle_window_visibility (appGUI);
     } else {
-        gui_quit_osmo(appGUI);
+        gui_quit_osmo(FALSE, appGUI);
     }
 }
 
@@ -273,6 +278,13 @@ gint i, n;
 
 /*------------------------------------------------------------------------------*/
 
+void
+key_counter_add (gint value, GUI *appGUI) {
+    appGUI->key_counter += value;
+}
+
+/*------------------------------------------------------------------------------*/
+
 gint 
 key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data) {
 
@@ -328,8 +340,16 @@ gint page;
                     }
                     return TRUE;
                 case GDK_space:
-                    set_today (TRUE, appGUI);
-                    return TRUE;
+                    if (event->state & GDK_CONTROL_MASK) {  /* CTRL + Space */
+                        config.enable_day_mark = !config.enable_day_mark;
+                        calendar_refresh_marks(appGUI);
+                        set_day_info (appGUI->cal->day, appGUI->cal->month, appGUI->cal->year, appGUI);
+                        update_aux_calendars (appGUI);
+                        return TRUE;
+                    } else {
+                        calendar_set_today (appGUI);
+                        return TRUE;
+                    }
                 case GDK_Delete:
                     if (appGUI->calendar_only == FALSE) {
                         calendar_clear_text_cb (NULL, appGUI);
@@ -343,13 +363,20 @@ gint page;
                     return TRUE;
                 case GDK_c:
                     calendar_create_color_selector_window (TRUE, appGUI);
+                    key_counter_add (13, appGUI);
                     return TRUE;
                 case GDK_d:
-                    calendar_create_calc_window  (appGUI);
+                    calendar_create_calc_window (appGUI);
                     return TRUE;
                 case GDK_a:
                     gtk_expander_set_expanded (GTK_EXPANDER (appGUI->cal->aux_cal_expander),
                                                !gtk_expander_get_expanded (GTK_EXPANDER (appGUI->cal->aux_cal_expander)));
+                    key_counter_add (5, appGUI);
+                    return TRUE;
+                case GDK_b:
+                    if (appGUI->calendar_only == FALSE) {
+                        calendar_notes_browser (appGUI);
+                    }
                     return TRUE;
             }
 
@@ -406,7 +433,7 @@ gint page;
                 case GDK_Return:
                     if (event->state & GDK_CONTROL_MASK) {  /* CTRL + Enter */
                         if (gtk_tree_selection_get_selected (appGUI->tsk->tasks_list_selection, NULL, NULL)) {
-                            tasks_add_edit_dialog_show (TRUE, appGUI);
+                            tasks_add_edit_dialog_show (TRUE, 0, get_seconds_for_today(), appGUI);
                             return TRUE;
                         }
                     }
@@ -429,7 +456,7 @@ gint page;
                     tasks_remove_dialog_show(appGUI->tsk->tasks_list, appGUI->tsk->tasks_list_store, appGUI);
                     return TRUE;
                 case GDK_Insert:
-                    tasks_add_edit_dialog_show (FALSE, appGUI);
+                    tasks_add_edit_dialog_show (FALSE, 0, get_seconds_for_today(), appGUI);
                     return TRUE;
                 case GDK_Left:
                     if (appGUI->tsk->filter_index > 0) {
@@ -443,6 +470,9 @@ gint page;
                         gtk_combo_box_set_active(GTK_COMBO_BOX(appGUI->tsk->cf_combobox), appGUI->tsk->filter_index);
                     }
                     return TRUE;
+                case GDK_y:
+                    key_counter_add (26, appGUI);
+                    return TRUE;
             }
     }
 
@@ -498,15 +528,24 @@ gint page;
                         return TRUE;
                     }
                     return FALSE;
-                case GDK_F1:
-                    gtk_combo_box_set_active(GTK_COMBO_BOX(appGUI->cnt->contacts_find_combobox), CONTACTS_FF_FIRST_NAME);
-                    return TRUE;
-                case GDK_F2:
-                    gtk_combo_box_set_active(GTK_COMBO_BOX(appGUI->cnt->contacts_find_combobox), CONTACTS_FF_LAST_NAME);
-                    return TRUE;
-                case GDK_F3:
-                    gtk_combo_box_set_active(GTK_COMBO_BOX(appGUI->cnt->contacts_find_combobox), CONTACTS_FF_ALL_FIELDS);
-                    return TRUE;
+                case GDK_Down:
+                    if (event->state & GDK_CONTROL_MASK) {  /* CTRL + Down */
+                        if (config.find_mode < CONTACTS_FF_ALL_FIELDS) {
+                            config.find_mode++;
+                        }
+                        gtk_combo_box_set_active (GTK_COMBO_BOX (appGUI->cnt->contacts_find_combobox), config.find_mode);
+                        return TRUE;
+                    }
+                    return FALSE;
+                case GDK_Up:
+                    if (event->state & GDK_CONTROL_MASK) {  /* CTRL + Up */
+                        if (config.find_mode > CONTACTS_FF_FIRST_NAME) {
+                            config.find_mode--;
+                        }
+                        gtk_combo_box_set_active (GTK_COMBO_BOX (appGUI->cnt->contacts_find_combobox), config.find_mode);
+                        return TRUE;
+                    }
+                    return FALSE;
                 case GDK_l:
                     if (event->state & GDK_CONTROL_MASK) {  /* CTRL + l */
                         gtk_widget_grab_focus(GTK_WIDGET(appGUI->cnt->contacts_find_entry));
@@ -677,7 +716,7 @@ gint page;
 
         case GDK_q:
             if (event->state & GDK_CONTROL_MASK) {  /* CTRL + Q */
-                gui_quit_osmo(appGUI);
+                gui_quit_osmo(FALSE, appGUI);
             }
             return FALSE;
 
@@ -726,6 +765,9 @@ gint page;
             }
 #endif  /* HAVE_LIBGRINGOTTS */
             return FALSE;
+        case GDK_F1:
+            select_tab (0, appGUI);
+            return TRUE;
         case GDK_1:
             if ((event->state & GDK_MOD1_MASK)) {  /* ALT + 1 */
                 if (event->state & GDK_CONTROL_MASK) {  /* CTRL + ALT + 1 */
@@ -737,6 +779,9 @@ gint page;
                 return TRUE;
             }
             return FALSE;
+        case GDK_F2:
+            select_tab (1, appGUI);
+            return TRUE;
         case GDK_2:
             if ((event->state & GDK_MOD1_MASK)) {  /* ALT + 2 */
                 if (event->state & GDK_CONTROL_MASK) {  /* CTRL + ALT + 2 */
@@ -748,6 +793,9 @@ gint page;
                 return TRUE;
             }
             return FALSE;
+        case GDK_F3:
+            select_tab (2, appGUI);
+            return TRUE;
         case GDK_3:
             if ((event->state & GDK_MOD1_MASK)) {  /* ALT + 3 */
                 if (event->state & GDK_CONTROL_MASK) {  /* CTRL + ALT + 3 */
@@ -759,6 +807,9 @@ gint page;
                 return TRUE;
             }
             return FALSE;
+        case GDK_F4:
+            select_tab (3, appGUI);
+            return TRUE;
         case GDK_4:
             if ((event->state & GDK_MOD1_MASK)) {  /* ALT + 4 */
 #ifdef HAVE_LIBGRINGOTTS
@@ -774,12 +825,18 @@ gint page;
                 return TRUE;
             }
             return FALSE;
+        case GDK_F5:
+            select_tab (4, appGUI);
+            return TRUE;
         case GDK_5:
             if (event->state & GDK_MOD1_MASK) {  /* ALT + 5 */
                 select_tab (4, appGUI);
                 return TRUE;
             }
             return FALSE;
+        case GDK_F6:
+            select_tab (5, appGUI);
+            return TRUE;
         case GDK_6:
             if (event->state & GDK_MOD1_MASK) {  /* ALT + 6 */
                 select_tab (5, appGUI);
@@ -862,7 +919,7 @@ systray_popup_menu_quit_selected_cb (gpointer user_data) {
         gtk_widget_show (appGUI->main_window);
         appGUI->window_visible = TRUE;
     }
-    gui_quit_osmo(appGUI);
+    gui_quit_osmo(FALSE, appGUI);
 }
 
 void
@@ -934,19 +991,22 @@ gui_systray_tooltip_update (GUI *appGUI) {
 
 gchar       desc[BUFFER_SIZE], tmpbuf[BUFFER_SIZE];
 gboolean    flag = FALSE;
+guint32     julian_day;
 
     sprintf(tmpbuf, "%s", julian_to_str(get_julian_for_today(), DATE_FULL));
     desc[0] = '\0';
     strcat(desc, tmpbuf);
 
-    if (check_contacts(get_current_day(), get_current_month(), get_current_year(), appGUI) == TRUE) {
+    julian_day = get_julian_for_today();
+
+    if (check_contacts(julian_day, appGUI) == TRUE) {
         strcat(desc, "\n");
         flag = TRUE;
         sprintf(tmpbuf, "\n%s", _("Birthday found"));
         strcat(desc, tmpbuf);
     }
 
-    if (check_tasks(get_current_day(), get_current_month(), get_current_year(), appGUI) == TRUE) {
+    if (check_tasks(julian_day, FALSE, appGUI) == TRUE) {
         if (flag == FALSE) {
             strcat(desc, "\n");
             flag = TRUE;
@@ -974,6 +1034,7 @@ gui_systray_initialize (GUI *appGUI) {
 
 GtkWidget   *menu_entry;
 GtkWidget   *systray_menu_separator;
+guint32     julian_day;
 
     if (appGUI->calendar_only == TRUE) {
         return;
@@ -1039,11 +1100,12 @@ GtkWidget   *systray_menu_separator;
     g_signal_connect(G_OBJECT(appGUI->osmo_trayicon), "popup-menu",
                      G_CALLBACK(trayicon_popup_cb), appGUI);
 
-    if (check_contacts(get_current_day(), get_current_month(), get_current_year(), appGUI) == TRUE) {
+    julian_day = get_julian_for_today();
+    if (check_contacts(julian_day, appGUI) == TRUE) {
         gtk_status_icon_set_from_stock (appGUI->osmo_trayicon, OSMO_STOCK_SYSTRAY_BIRTHDAY);
     }
 
-    if (check_tasks(get_current_day(), get_current_month(), get_current_year(), appGUI) == TRUE) {
+    if (check_tasks(julian_day, FALSE, appGUI) == TRUE) {
         gtk_status_icon_set_from_stock (appGUI->osmo_trayicon, OSMO_STOCK_SYSTRAY_TASK);
     }
 
@@ -1076,7 +1138,7 @@ GtkWidget   *systray_menu_separator;
 
 /*------------------------------------------------------------------------------*/
 
-void 
+gboolean
 gui_create_window (GUI *appGUI) {
 
 GdkPixbuf   *icon;
@@ -1085,11 +1147,11 @@ gchar tmpbuf[BUFFER_SIZE];
     appGUI->cnt->contacts_filter_disabled = TRUE;
     appGUI->all_pages_added = FALSE;
 
-    appGUI->fd_calendar_day_name = pango_font_description_from_string(config.day_name_font);
-    appGUI->fd_calendar_cal = pango_font_description_from_string(config.calendar_font);
-    appGUI->fd_calendar_notes = pango_font_description_from_string(config.notes_font);
+    appGUI->cal->fd_day_name_font = pango_font_description_from_string(config.day_name_font);
+    appGUI->cal->fd_cal_font = pango_font_description_from_string(config.calendar_font);
+    appGUI->cal->fd_notes_font = pango_font_description_from_string(config.notes_font);
 
-    appGUI->fd_notes_editor = pango_font_description_from_string(config.notes_editor_font);
+    appGUI->nte->fd_notes_font = pango_font_description_from_string(config.notes_editor_font);
 
     appGUI->main_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
     sprintf(tmpbuf, "OSMO - %s", _("a handy personal organizer"));
@@ -1102,6 +1164,9 @@ gchar tmpbuf[BUFFER_SIZE];
     g_object_unref(icon);
 
     gtk_window_move (GTK_WINDOW (appGUI->main_window), config.window_x, config.window_y);
+
+    gtk_widget_realize (appGUI->main_window);
+
     if (appGUI->calendar_only == FALSE) {
         gtk_window_set_default_size (GTK_WINDOW(appGUI->main_window), config.window_size_x, config.window_size_y);
     } else {
@@ -1146,9 +1211,7 @@ gchar tmpbuf[BUFFER_SIZE];
         read_notes (appGUI);
 
 #ifdef HAVE_LIBICAL
-        if (ics_initialize_timezone () == FALSE) {
-            fprintf(stderr, "ERROR: Cannot initialize timezone info. iCal support disabled.\n");
-        }
+        ics_initialize_timezone ();
         read_ical_entries (appGUI);
 #endif  /* HAVE_LIBICAL */
 
@@ -1165,8 +1228,7 @@ gchar tmpbuf[BUFFER_SIZE];
         gtk_combo_box_set_active (GTK_COMBO_BOX(appGUI->nte->cf_combobox), 0);
 #endif  /* HAVE_LIBGRINGOTTS */
 
-        gui_create_category_combobox (GTK_COMBO_BOX (appGUI->tsk->cf_combobox), appGUI->opt->tasks_category_store, FALSE);
-        gtk_combo_box_set_active (GTK_COMBO_BOX(appGUI->tsk->cf_combobox), 0);
+        refresh_tasks (appGUI);
 
         appGUI->cnt->contacts_filter_disabled = FALSE;
 
@@ -1184,17 +1246,24 @@ gchar tmpbuf[BUFFER_SIZE];
 
     gui_url_initialize(appGUI);
 
-    gtk_notebook_set_current_page(GTK_NOTEBOOK(appGUI->notebook), appGUI->current_tab);
-
     appGUI->all_pages_added = TRUE;
-    set_today (TRUE, appGUI);
+    calendar_set_today (appGUI);
 
     update_aux_calendars (appGUI);
-    gui_systray_initialize (appGUI);
+
+    if (appGUI->check_events == TRUE) {
+        return create_event_checker_window (appGUI);
+    } else {
+        gui_systray_initialize (appGUI);
+    }
  
     if (appGUI->calendar_only == TRUE) {
         gtk_widget_show (appGUI->main_window);
     }
+
+    gtk_notebook_set_current_page(GTK_NOTEBOOK(appGUI->notebook), appGUI->current_tab);
+
+    return TRUE;
 }
 
 /*------------------------------------------------------------------------------*/
@@ -1231,22 +1300,25 @@ display_help(GUI *appGUI) {
 const gchar *general_keys_text[] = {
     "<Ctrl+PageUp>",            N_("switch to previous tab"),
     "<Ctrl+PageDn>",            N_("switch to next tab"),
+    "<Alt+1...6>, F1-F6",       N_("switch to selected page"),
     "<PageUp/PageDn>",          N_("switch page in options and about tab"),
     "<Ctrl+q>",                 N_("exit")
 };
 
 const gchar *calendar_keys_text[] = {
     "<Space>",                  N_("select current date"),
+    "<Ctrl+Space>",             N_("toggle personal data visibility"),
     "<Arrows>",                 N_("change day"),
     "<Alt+Arrows>",             N_("change day while note editing"),
     "<Ctrl+Up/Down>",           N_("scroll the contents in the day info panel"),
     "<PageUp/PageDn>",          N_("change month"),
     "<Home/End>",               N_("change year"),
+    "<a>",                      N_("toggle calendars for the previous and next month"),
+    "<b>",                      N_("day notes browser"),
     "<c>",                      N_("assign background color to day note"),
     "<d>",                      N_("date calculator"),
-    "<g>",                      N_("jump to date"),
     "<f>",                      N_("show full-year calendar"),
-    "<a>",                      N_("toggle calendars for the previous and next month"),
+    "<g>",                      N_("jump to date"),
     "<Delete>",                 N_("remove day note"),
     "<Esc>",                    N_("close day note panel")
 };
@@ -1265,7 +1337,7 @@ const gchar *contacts_keys_text[] = {
     "<Ctrl+Enter>",             N_("edit contact"),
     "<Delete>",                 N_("remove contact"),
     "<Ctrl+l>",                 N_("activate search field"),
-    "<F1/F2/F3>",               N_("change search mode"),
+    "<Ctrl+Up/Down>",           N_("change search mode"),
     "<Esc>",                    N_("close contact details panel")
 };
 
@@ -1364,9 +1436,50 @@ gint i;
 
 /*------------------------------------------------------------------------------*/
 
+static void add_credits_section(GUI *appGUI, const gchar *section_title,
+	OsmoCreditEntry *credits, guint32 n_credits)
+{
+	gint32 i;
+	gchar *s;
+	static gboolean init = TRUE;
+
+	if(init) {
+		init = FALSE;
+		gtk_text_buffer_create_tag(appGUI->about_entry_buffer, "fixed",
+			"family", "monospace", NULL);
+	}
+
+	s = g_strdup_printf("\n %s:\n", section_title);
+	gtk_text_buffer_insert_with_tags_by_name(appGUI->about_entry_buffer,
+		&appGUI->about_entry_iter, s, -1, "bold", NULL);
+	g_free(s);
+
+	for(i = 0; i < n_credits; i ++) {
+		if(credits[i].tag)
+			s = g_strdup_printf("  [%s]", credits[i].tag);
+		else
+			s = g_strdup("      ");
+		gtk_text_buffer_insert_with_tags_by_name(appGUI->about_entry_buffer,
+			&appGUI->about_entry_iter, s, -1, "fixed", NULL);
+		g_free(s);
+
+		s = g_strdup_printf("\t%s <", credits[i].name);
+		gtk_text_buffer_insert(appGUI->about_entry_buffer,
+			&appGUI->about_entry_iter, s, -1);
+		g_free(s);
+
+		gui_url_insert_link(&appGUI->about_links_list,
+			&appGUI->about_link_index, appGUI->about_textview,
+			&appGUI->about_entry_iter, NULL, NULL, credits[i].email, FALSE,
+			appGUI);
+
+		gtk_text_buffer_insert(appGUI->about_entry_buffer,
+			&appGUI->about_entry_iter, ">\n", -1);
+	}
+}
+
 void
 display_about(GUI *appGUI) {
-
 gchar tmpbuf[BUFFER_SIZE];
 
     gui_url_remove_links (&appGUI->about_links_list, &appGUI->about_link_index);
@@ -1381,102 +1494,21 @@ gchar tmpbuf[BUFFER_SIZE];
 
     gui_url_insert_link(&appGUI->about_links_list, &appGUI->about_link_index, 
                         appGUI->about_textview, &appGUI->about_entry_iter, NULL, 
-                        0, "http://clay.ll.pl/osmo", TRUE, appGUI);
+                        NULL, "http://clay.ll.pl/osmo", TRUE, appGUI);
     gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, "\n", -1);
 
     sprintf(tmpbuf, "\n(%s %s, %s)\n\n", _("compiled on"), __DATE__, __TIME__);
     gtk_text_buffer_insert_with_tags_by_name (appGUI->about_entry_buffer, 
                                               &appGUI->about_entry_iter, tmpbuf, -1, "center", "italic", NULL);
 
-    sprintf(tmpbuf, "\n %s:\n", _("Programming"));
-    gtk_text_buffer_insert_with_tags_by_name (appGUI->about_entry_buffer, 
-                                              &appGUI->about_entry_iter, tmpbuf, -1, "bold", NULL);
-    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, 
-                            "     Tomasz Mąka <", -1);
-    gui_url_insert_link(&appGUI->about_links_list, &appGUI->about_link_index, 
-                        appGUI->about_textview, &appGUI->about_entry_iter, NULL, 
-                        0, "pasp@users.sourceforge.net", FALSE, appGUI);
-    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, ">\n", -1);
-
-    sprintf(tmpbuf, "\n %s:\n", _("Graphics"));
-    gtk_text_buffer_insert_with_tags_by_name (appGUI->about_entry_buffer, 
-                                              &appGUI->about_entry_iter, tmpbuf, -1, "bold", NULL);
-    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, 
-                            "     Maja Kocoń (", -1);
-    gui_url_insert_link(&appGUI->about_links_list, &appGUI->about_link_index, 
-                        appGUI->about_textview, &appGUI->about_entry_iter, NULL, 
-                        0, "http://ironya.ll.pl", FALSE, appGUI);
-    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, ")\n", -1);
-
-    sprintf(tmpbuf, "\n %s:\n", _("Contributors"));
-    gtk_text_buffer_insert_with_tags_by_name (appGUI->about_entry_buffer, 
-                                              &appGUI->about_entry_iter, tmpbuf, -1, "bold", NULL);
-    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, 
-                            "     Piotr Mąka <", -1);
-    gui_url_insert_link(&appGUI->about_links_list, &appGUI->about_link_index, 
-                        appGUI->about_textview, &appGUI->about_entry_iter, NULL, 
-                        0, "silloz@users.sourceforge.net", FALSE, appGUI);
-    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, ">\n", -1);
-
-    sprintf(tmpbuf, "\n %s:\n", _("Translators"));
-    gtk_text_buffer_insert_with_tags_by_name (appGUI->about_entry_buffer, 
-                                              &appGUI->about_entry_iter, tmpbuf, -1, "bold", NULL);
-
-    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, 
-                            "     [cs]\tDragonlord <", -1);
-    gui_url_insert_link(&appGUI->about_links_list, &appGUI->about_link_index, 
-                        appGUI->about_textview, &appGUI->about_entry_iter, NULL, 
-                        0, "dragonlord@seznam.cz", FALSE, appGUI);
-    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, ">\n", -1);
-
-    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, 
-                            "     [de]\tMarkus Dahms <", -1);
-    gui_url_insert_link(&appGUI->about_links_list, &appGUI->about_link_index, 
-                        appGUI->about_textview, &appGUI->about_entry_iter, NULL, 
-                        0, "mad@automagically.de", FALSE, appGUI);
-    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, ">\n", -1);
-
-    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, 
-                            "     [es]\tNacho Alonso González <", -1);
-    gui_url_insert_link(&appGUI->about_links_list, &appGUI->about_link_index, 
-                        appGUI->about_textview, &appGUI->about_entry_iter, NULL, 
-                        0, "nacho.alonso.gonzalez@gmail.com", FALSE, appGUI);
-    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, ">\n", -1);
-
-    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, 
-                            "     [fr]\tJean-Jacques Moulinier <", -1);
-    gui_url_insert_link(&appGUI->about_links_list, &appGUI->about_link_index, 
-                        appGUI->about_textview, &appGUI->about_entry_iter, NULL, 
-                        0, "postmaster@moulinier.net", FALSE, appGUI);
-    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, ">\n", -1);
-
-    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, 
-                            "     [lt]\tVaidotas Kazla <", -1);
-    gui_url_insert_link(&appGUI->about_links_list, &appGUI->about_link_index, 
-                        appGUI->about_textview, &appGUI->about_entry_iter, NULL, 
-                        0, "joshas@gmail.com", FALSE, appGUI);
-    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, ">\n", -1);
-
-    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, 
-                            "     [nl]\tTiger!P <", -1);
-    gui_url_insert_link(&appGUI->about_links_list, &appGUI->about_link_index, 
-                        appGUI->about_textview, &appGUI->about_entry_iter, NULL, 
-                        0, "tigerp@tigerp.net", FALSE, appGUI);
-    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, ">\n", -1);
-
-    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, 
-                            "     [pl]\tPiotr Mąka <", -1);
-    gui_url_insert_link(&appGUI->about_links_list, &appGUI->about_link_index, 
-                        appGUI->about_textview, &appGUI->about_entry_iter, NULL, 
-                        0, "silloz@users.sourceforge.net", FALSE, appGUI);
-    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, ">\n", -1);
-
-    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, 
-                            "     [pt]\tBruno Miguel <", -1);
-    gui_url_insert_link(&appGUI->about_links_list, &appGUI->about_link_index, 
-                        appGUI->about_textview, &appGUI->about_entry_iter, NULL, 
-                        0, "brunoalexandremiguel@gmail.com", FALSE, appGUI);
-    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, ">\n", -1);
+	add_credits_section(appGUI, _("Programming"), credits_programming,
+		G_N_ELEMENTS(credits_programming));
+	add_credits_section(appGUI, _("Graphics"), credits_graphics,
+		G_N_ELEMENTS(credits_graphics));
+	add_credits_section(appGUI, _("Contributors"), credits_contributors,
+		G_N_ELEMENTS(credits_contributors));
+	add_credits_section(appGUI, _("Translators"), credits_translators,
+		G_N_ELEMENTS(credits_translators));
 
     sprintf(tmpbuf, "\n %s:\n", _("Compiled-in features"));
     gtk_text_buffer_insert_with_tags_by_name (appGUI->about_entry_buffer, 
@@ -1496,6 +1528,13 @@ gchar tmpbuf[BUFFER_SIZE];
 #endif  /* HAVE_LIBGRINGOTTS */
     gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, tmpbuf, -1);
 
+#ifdef HAVE_LIBSYNCML
+    sprintf(tmpbuf, "     [+]\t%s (libsyncml)\n", _("SyncML enabled device support"));
+#else
+    sprintf(tmpbuf, "     [-]\t%s (libsyncml)\n", _("SyncML enabled device support"));
+#endif  /* HAVE_LIBSYNCML */
+    gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, tmpbuf, -1);
+
     gtk_widget_grab_focus(GTK_WIDGET(appGUI->scrolled_window));
 }
 
