@@ -24,24 +24,37 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
+#include <unistd.h>
+#include <fcntl.h>
+#include <ctype.h>
 
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
 #include <gdk/gdkkeysyms.h>
+#include <glib/gstdio.h>
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk-pixbuf/gdk-pixdata.h>
 
+#include <libxml/parser.h>
+#include <libxml/xmlmemory.h>
+
+#include <libnotify/notify.h>
+
 #include <config.h>
 
 #ifdef HAVE_LIBGRINGOTTS
 #include <libgringotts.h>
 #endif  /* HAVE_LIBGRINGOTTS */
 
-#define     MAX_MONTHS      12
-#define     MAX_WEEKS       6
-#define     DAYS_PER_WEEK   7
-#define     BUFFER_SIZE     2048
+#define     TRANSLATION_DOMAIN      "osmo"
+
+#define     MAX_MONTHS              12
+#define     MAX_WEEKS               6
+#define     DAYS_PER_WEEK           7
+#define     FULL_YEAR_COLS          37
+#define     BUFFER_SIZE             2048
 
 enum notebook_page {
     PAGE_CALENDAR = 0,
@@ -57,8 +70,10 @@ enum notebook_page {
 
 enum {                  /* tasks columns */
     TA_COLUMN_DONE = 0,
+    TA_COLUMN_TYPE,
     TA_COLUMN_DUE_DATE,
     TA_COLUMN_DUE_DATE_JULIAN,
+    TA_COLUMN_DUE_TIME,
     TA_COLUMN_START_DATE_JULIAN,
     TA_COLUMN_PRIORITY,
     TA_COLUMN_CATEGORY,
@@ -66,6 +81,22 @@ enum {                  /* tasks columns */
     TA_COLUMN_DESCRIPTION,
     TA_COLUMN_COLOR,
     TA_COLUMN_BOLD,
+	TA_COLUMN_ACTIVE,
+	TA_COLUMN_ACTIVE_WARNING,
+	TA_COLUMN_OFFLINE_IGNORE,
+	TA_COLUMN_REPEAT,
+	TA_COLUMN_REPEAT_DAY,
+	TA_COLUMN_REPEAT_MONTH_INTERVAL,
+	TA_COLUMN_REPEAT_DAY_INTERVAL,
+	TA_COLUMN_REPEAT_START_DAY,
+	TA_COLUMN_REPEAT_TIME_START,
+	TA_COLUMN_REPEAT_TIME_END,
+	TA_COLUMN_REPEAT_TIME_INTERVAL,
+	TA_COLUMN_REPEAT_COUNTER,
+	TA_COLUMN_ALARM_COMMAND,
+	TA_COLUMN_WARNING_DAYS,
+	TA_COLUMN_WARNING_TIME,
+	TA_COLUMN_ID,
     TASKS_NUM_COLUMNS
 };
 
@@ -103,19 +134,17 @@ typedef struct {
     /* calendar toolbar */
     GtkToolbar *calendar_toolbar;
     GtkBox  *vbox;      
+    PangoFontDescription *fd_cal_font;
 
     /* date label */
     GtkWidget *date_label;
+    PangoFontDescription *fd_day_name_font;
 
-    /* current date */
+    /* current selected date */
     guint day;
     guint month;
     guint year;
-    
-    /* previously selected date */
-    guint prev_day;
-    guint prev_month;
-    guint prev_year;
+    GDate *date;
 
     /* used for 'jump to' button in date calculator */
     guint julian_jumpto;
@@ -136,9 +165,15 @@ typedef struct {
     GtkWidget *moon_phase_label;
     GtkWidget *marked_days_label;
     GtkWidget *weekend_days_label;
+    GtkWidget *day_category_label;
     GtkWidget *day_desc_textview;
     GtkTextBuffer *day_desc_text_buffer;
     GtkTextIter day_desc_iter;
+    PangoFontDescription *fd_notes_font;
+
+    /* calendar popup menu */
+    GtkWidget *popup_menu;
+    GtkWidget *popup_menu_select_day_color_entry;
 
     /* month selector popup menu */
     GtkWidget *month_selector_menu;
@@ -170,9 +205,11 @@ typedef struct {
 
     /* full year calendar */
     GtkWidget *fullyear_window;
-    GtkWidget *fycal_table;
+    GtkWidget *fycal_table_1;
+    GtkWidget *fycal_table_2;
     GtkWidget *fy_spinbutton;
     GtkWidget *cyear_button;
+    GtkWidget *fy_calendars[MAX_MONTHS];
     GtkWidget *calendar_buttons[MAX_MONTHS*(MAX_WEEKS*DAYS_PER_WEEK-(MAX_WEEKS-1))];
 
     /* jump to date */
@@ -237,6 +274,18 @@ typedef struct {
     GtkTreeSelection *ical_events_list_selection;
     GtkListStore *ical_events_list_store;
 
+    /* notes browser */
+    GtkWidget *day_notes_window;
+    GtkWidget *day_notes_list;
+    GtkTreeSelection *day_notes_list_selection;
+    GtkListStore *day_notes_list_store;
+    GtkWidget *past_notes_checkbutton;
+    GtkWidget *notes_month_spinbutton;
+    GtkWidget *notes_year_spinbutton;
+    GtkWidget *notes_filter_combobox;
+    GtkWidget *notes_search_entry;
+    GtkWidget *notes_search_checkbutton;
+
 } CALENDAR;
 
 
@@ -270,9 +319,11 @@ typedef struct {
     gint filter_index;
     gboolean tasks_filter_disabled;
     GtkUIManager *tasks_uim_widget;
+    guint id_counter;
 
     /* tasks items */
     GtkWidget *td_calendar;
+    GtkWidget *time_expander;
     GtkWidget *due_date_entry;
     GtkWidget *tasks_add_window;
     GtkWidget *td_calendar_window;
@@ -280,6 +331,33 @@ typedef struct {
     GtkWidget *tasks_ok_button;
     GtkWidget *summary_entry;
     guint32 tasks_due_julian_day;
+    gint tasks_due_time;
+    GtkWidget *aw_days_spinbutton;
+    GtkWidget *aw_hours_spinbutton;
+    GtkWidget *aw_minutes_spinbutton;
+    GtkWidget *alarm_cmd_entry;
+    GtkWidget *alarm_cmd_valid_image;
+    GtkWidget *recurrent_task_vbox;
+    GtkWidget *rt_expander;
+    GtkWidget *rt_enable_checkbutton;
+    GtkWidget *ignore_alarm_checkbutton;
+    GtkWidget *rt_start_hour_spinbutton;
+    GtkWidget *rt_start_minute_spinbutton;
+    GtkWidget *rt_end_hour_spinbutton;
+    GtkWidget *rt_end_minute_spinbutton;
+    GtkWidget *rt_interval_hour_spinbutton;
+    GtkWidget *rt_interval_minute_spinbutton;
+    GtkWidget *dp_1_checkbutton;
+    GtkWidget *dp_2_checkbutton;
+    GtkWidget *dp_3_checkbutton;
+    GtkWidget *dp_4_checkbutton;
+    GtkWidget *dp_5_checkbutton;
+    GtkWidget *dp_6_checkbutton;
+    GtkWidget *dp_7_checkbutton;
+    GtkWidget *rt_dp_day_spinbutton;
+    GtkWidget *rt_dp_month_spinbutton;
+    GtkWidget *repeat_counter_spinbutton;
+    GSList *notifications;
 
 } TASKS;
 
@@ -308,22 +386,31 @@ typedef struct {
 
     GtkWidget *contacts_panel_scrolledwindow;
     GtkWidget *contacts_desc_textview;
+    GtkWidget *contacts_www_textview;
+    GtkWidget *contacts_email_textview;
+    GtkWidget *contacts_blog_textview;
     GtkWidget *photo_image;
-    GtkTextTag *contact_color_tag_object;
     GtkTextTag *contact_name_tag_object;
     GtkTextTag *contact_tags_value_tag_object;
     GtkUIManager *contacts_uim_widget;
     GSList contacts_links_list;
+    GSList contacts_www_links_list;
+    GSList contacts_email_links_list;
+    GSList contacts_blog_links_list;
     gint contacts_link_index;
+    gint contacts_www_link_index;
+    gint contacts_email_link_index;
+    gint contacts_blog_link_index;
     gboolean contacts_panel_status;
     gboolean contacts_filter_disabled;
-    gint longest_tag_name;
+    GtkWidget *next_field_button[CONTACTS_NUM_COLUMNS];
     GtkTreeViewColumn *contacts_columns[CONTACTS_NUM_COLUMNS];
 
     gchar **contact_fields_tags_name;
 
     GtkWidget *contacts_add_window;
     GtkWidget *contacts_ok_button;
+    GtkWidget *contacts_browse_button;
     GtkWidget *add_info_textview;
     GtkWidget *photo_browse_button;
     GtkWidget *birth_day_date_button;
@@ -354,6 +441,8 @@ typedef struct {
 
     /* import contacts */
     GtkWidget *import_window;
+    GtkWidget *import_sel_window;
+    GtkWidget *import_button;
     GtkWidget *value_labels[CONTACTS_NUM_COLUMNS];
     GtkWidget *field_type_comboboxes[CONTACTS_NUM_COLUMNS];
     GtkWidget *first_row_as_header_check_button;
@@ -365,6 +454,21 @@ typedef struct {
     gchar *file_buffer;
     guint file_length;
 
+    PangoFontDescription *fd_ai_font;
+
+    GtkWidget *input_file_entry;
+    GtkWidget *import_type_combobox;
+    GtkWidget *bluetooth_radiobutton;
+    GtkWidget *usb_radiobutton;
+    GtkWidget *bluetooth_address_entry;
+    GtkWidget *file_import_vbox;
+    GtkWidget *syncml_import_vbox;
+    GtkWidget *bluetooth_params_hbox;
+    GtkWidget *usb_params_hbox;
+    GtkWidget *bluetooth_channel_spinbutton;
+    GtkWidget *usb_interface_spinbutton;
+    GtkWidget *use_wbxml_checkbutton;
+
 } CONTACTS;
 
 typedef struct {
@@ -405,11 +509,14 @@ typedef struct {
 
     /* category filter */
     GtkTreeModel *notes_filter;
+    GtkTreeModel *notes_sort;
     gint filter_index;
     GtkWidget *cf_combobox;
     GtkWidget *n_items_label;
 
     /* editor */
+    PangoFontDescription *fd_notes_font;
+
     GtkWidget *title_label;
     GtkWidget *editor_textview;
     gboolean changed;
@@ -437,11 +544,13 @@ typedef struct {
 
     /* calendar */
     GtkWidget *calendar_vbox;
-    GtkWidget *mark_symbol_combobox;
+    GtkWidget *event_marker_type_combobox;
+    GtkWidget *today_marker_type_combobox;
     GtkWidget *header_color_picker;
     GtkWidget *weekend_color_picker;
     GtkWidget *selection_color_picker;
     GtkWidget *mark_color_picker;
+    GtkWidget *mark_current_day_color_picker;
     GtkWidget *cft_hscale;
     GtkWidget *cft_label_1, *cft_label_2, *cft_label_3;
     GtkWidget *show_day_names_checkbutton;
@@ -451,7 +560,9 @@ typedef struct {
     GtkWidget *simple_view_in_fy_calendar_checkbutton;
     GtkWidget *enable_auxilary_calendars_checkbutton;
     GtkWidget *strikethrough_past_notes_checkbutton;
+    GtkWidget *ascending_sorting_in_day_notes_checkbutton;
     GtkWidget *enable_block_cursor_checkbutton;
+    GtkWidget *day_marker_entry;
     GtkWidget *day_name_font_entry;
     GtkWidget *calendar_font_entry;
     GtkWidget *notes_font_entry;
@@ -483,9 +594,11 @@ typedef struct {
     GtkTreeSelection *calendar_ical_files_select;
     GtkWidget *di_show_current_time_checkbutton;
     GtkWidget *di_show_day_number_checkbutton;
+    GtkWidget *di_show_current_day_distance_checkbutton;
     GtkWidget *di_show_marked_days_checkbutton;
     GtkWidget *di_show_week_number_checkbutton;
     GtkWidget *di_show_weekend_days_checkbutton;
+    GtkWidget *di_show_day_category_checkbutton;
     GtkWidget *di_show_moon_phase_checkbutton;
     GtkWidget *di_show_notes_checkbutton;
     GtkWidget *di_show_zodiac_sign_checkbutton;
@@ -507,14 +620,13 @@ typedef struct {
     GtkWidget *ct_bold_items_checkbutton;
     GtkWidget *ct_delete_items_checkbutton;
     GtkWidget *ct_hide_items_checkbutton;
+    GtkWidget *ct_add_item_checkbutton;
     GtkWidget *tasks_enable_rules_hint_checkbutton;
     GtkWidget *vc_due_date_checkbutton;
+    GtkWidget *vc_type_checkbutton;
     GtkWidget *vc_category_checkbutton;
     GtkWidget *vc_priority_checkbutton;
-    GtkObject *name_font_size_spinbutton_adj;
-    GtkWidget *name_font_size_spinbutton;
-    GtkObject *tags_font_size_spinbutton_adj;
-    GtkWidget *tags_font_size_spinbutton;
+    GtkWidget *postpone_time_spinbutton;
 
     /* contacts */
     GtkWidget *contacts_vbox;
@@ -524,6 +636,8 @@ typedef struct {
     GtkWidget *contacts_group_entry;
     GtkListStore *contacts_group_store;
     GtkWidget *contacts_group_treeview;
+    GtkWidget *cn_font_entry;
+    GtkWidget *ci_font_entry;
     GtkTreeSelection *contacts_group_select;
     GtkWidget *contacts_group_add_button;
     GtkWidget *contacts_group_remove_button;
@@ -532,6 +646,8 @@ typedef struct {
     GtkWidget *contacts_photo_size_combobox;
     GtkWidget *contact_tag_color_picker;
     GtkWidget *contact_link_color_picker;
+    GtkWidget *name_font_size_spinbutton;
+    GtkWidget *tags_font_size_spinbutton;
 
     /* notes */
     GtkWidget *notes_vbox;
@@ -545,6 +661,8 @@ typedef struct {
     GtkListStore *notes_category_store;
     GtkWidget *notes_category_treeview;
     GtkTreeSelection *notes_category_select;
+    GtkWidget *notes_sort_order_combobox;
+    GtkWidget *notes_sort_mode_combobox;
     GtkWidget *notes_category_add_button;
     GtkWidget *notes_category_remove_button;
 
@@ -571,32 +689,40 @@ typedef struct {
 
 typedef struct {
 
+    /* gui */
     GtkWidget *main_window;
     GtkWidget *notebook;
-
-    GtkTooltips *osmo_tooltips; 
-
-    GtkStatusIcon *osmo_trayicon;
-    GtkWidget *trayicon_popup_menu;
-    gboolean no_tray;
-
-    gboolean calendar_only;
     gboolean all_pages_added;
     gboolean window_visible;
     gint current_tab;
     gint number_of_tabs;
+
+    /* tooltips */
+    GtkTooltips *osmo_tooltips; 
+
+    /* tray icon */
+    GtkStatusIcon *osmo_trayicon;
+    GtkWidget *trayicon_popup_menu;
+    gboolean no_tray;
+
+    /* command line parameters */
+    gboolean calendar_only;
+    gboolean check_events;
+    gint check_ndays_events;
+    gchar *config_path;
     
-    PangoFontDescription *fd_calendar_day_name;
-    PangoFontDescription *fd_calendar_cal;
-    PangoFontDescription *fd_calendar_notes;
-
-    PangoFontDescription *fd_notes_editor;
-
+    /* links handling */
     gboolean hovering_over_link;
     GdkCursor *hand_cursor;
     GdkCursor *regular_cursor;
     GtkTextTag *gui_url_tag;
 
+    /* check events */
+    GtkWidget *event_checker_window;
+    GtkWidget *event_checker_list;
+    GtkTreeSelection *event_checker_list_selection;
+    GtkListStore *event_checker_list_store;
+
     /* about page */
     GtkWidget *about_radiobutton;
     GtkWidget *license_radiobutton;
@@ -610,8 +736,12 @@ typedef struct {
     GtkTextIter about_entry_iter;
     GtkTextBuffer *about_entry_buffer;
 
-    /* modules */
+	/* miscellaneous */
+	guint32 run_date;
+	gint key_counter;
+	gint run_time;
 
+    /* modules */
     CALENDAR *cal;
     TASKS *tsk;
     CONTACTS *cnt;
@@ -626,10 +756,12 @@ typedef struct {
     GUI *appGUI;
 } MESSAGE;
 
-void        gui_create_window               (GUI *appGUI);
+gboolean    gui_create_window               (GUI *appGUI);
 void        gui_add_to_notebook             (GtkWidget *widget, gchar *text, GUI *appGUI);
 void        gui_create_about                (GUI *appGUI);
-void        gui_quit_osmo                   (GUI *appGUI);
+void        gui_save_all_data               (GUI *appGUI);
+void        gui_save_data_and_run_command   (gchar *command, GUI *appGUI);
+void        gui_quit_osmo                   (gboolean ignore_geometry, GUI *appGUI);
 void        gui_systray_initialize          (GUI *appGUI);
 void        gui_systray_tooltip_update      (GUI *appGUI);
 void        about_switch_buttons            (gboolean left, GUI *appGUI);
