@@ -19,14 +19,9 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include <stdio.h>
-#include <string.h>
-#include <gtk/gtk.h>
-#include <glib.h>
-
+#include "gui_utils.h"
 #include "i18n.h"
 #include "options_prefs.h"
-#include "gui_utils.h"
 #include "stock_icons.h"
 
 static gunichar TAG_CHAR = 0xe000;      /* Unicode chars in the Private Use Area. */
@@ -500,8 +495,41 @@ GtkWidget *image;
 /*------------------------------------------------------------------------------*/
 
 gboolean
-gui_run_helper(gchar *parameter, gint helper) {
-gchar *cmdline[4], command[PATH_MAX];
+gui_is_valid_command (gchar *command) {
+
+gchar *found_path;
+
+    found_path = g_find_program_in_path (command);
+
+    if (found_path != NULL) {
+		g_free (found_path);
+		return TRUE;
+    }
+
+    return FALSE;
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+gui_run_command (gchar *command) {
+
+gchar *cmdline[4];
+
+    cmdline[0] = "sh";
+    cmdline[1] = "-c";
+    cmdline[2] = command;
+    cmdline[3] = 0;
+    g_spawn_async(NULL, (gchar **)cmdline, NULL, G_SPAWN_SEARCH_PATH | G_SPAWN_STDOUT_TO_DEV_NULL, 
+                  NULL, NULL, NULL, FALSE);
+}
+
+/*------------------------------------------------------------------------------*/
+
+gboolean
+gui_run_helper (gchar *parameter, gint helper) {
+
+gchar command[PATH_MAX];
 
     if (helper == EMAIL) {
         sprintf(command, config.email_client, parameter);
@@ -511,12 +539,7 @@ gchar *cmdline[4], command[PATH_MAX];
         return FALSE;
     }
 
-    cmdline[0] = "sh";
-    cmdline[1] = "-c";
-    cmdline[2] = command;
-    cmdline[3] = 0;
-    g_spawn_async(NULL, (gchar **)cmdline, NULL, G_SPAWN_SEARCH_PATH | G_SPAWN_STDOUT_TO_DEV_NULL, 
-                  NULL, NULL, NULL, FALSE);
+    gui_run_command (command);
 
     return TRUE;
 }
@@ -537,9 +560,9 @@ gui_url_initialize(GUI *appGUI) {
 
 void 
 gui_url_insert_link (GSList *links_list, gint *link_index, GtkWidget *textview, 
-                     GtkTextIter *iter, gchar *color, gint font_size, gchar *text, gboolean center, GUI *appGUI) {
+                     GtkTextIter *iter, gchar *color, gchar *font, gchar *text, gboolean center, GUI *appGUI) {
 
-    if (font_size == 0 && color == NULL) {
+    if (font == NULL && color == NULL) {
         if (config.disable_underline_links) {
             if (center == TRUE) {
                 appGUI->gui_url_tag = gtk_text_buffer_create_tag (gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview)),
@@ -566,25 +589,25 @@ gui_url_insert_link (GSList *links_list, gint *link_index, GtkWidget *textview,
             if (center == TRUE) {
                 appGUI->gui_url_tag = gtk_text_buffer_create_tag (gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview)),
                                                           NULL, "foreground", color, 
-                                                          "size", font_size * PANGO_SCALE,
+                                                          "font", font,
                                                           "justification", GTK_JUSTIFY_CENTER, NULL);
             } else {
                 appGUI->gui_url_tag = gtk_text_buffer_create_tag (gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview)),
                                                           NULL, "foreground", color, 
-                                                          "size", font_size * PANGO_SCALE, NULL);
+                                                          "font", font, NULL);
             }
         } else {
             if (center == TRUE) {
                 appGUI->gui_url_tag = gtk_text_buffer_create_tag (gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview)),
                                                           NULL, "foreground", color, 
                                                           "underline", PANGO_UNDERLINE_SINGLE, 
-                                                          "size", font_size * PANGO_SCALE,
+                                                          "font", font,
                                                           "justification", GTK_JUSTIFY_CENTER, NULL);
             } else {
                 appGUI->gui_url_tag = gtk_text_buffer_create_tag (gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview)),
                                                           NULL, "foreground", color, 
                                                           "underline", PANGO_UNDERLINE_SINGLE, 
-                                                          "size", font_size * PANGO_SCALE, NULL);
+                                                          "font", font, NULL);
             }
         }
     }
