@@ -56,10 +56,13 @@ gboolean    gui_run_helper                      (gchar *parameter, gint helper);
 void        gui_clear_text_buffer               (GtkTextBuffer *buffer, GtkTextIter *iter);
 gint        gui_create_dialog                   (gint dialog_type, gchar *message, GtkWindow *parent);
 
+void        gui_run_command                     (gchar *command);
+gboolean    gui_is_valid_command                (gchar *command);
+
 gint        gui_get_link_type                   (gchar *link);
 void        gui_url_initialize                  (GUI *appGUI);
 void        gui_url_setup                       (GSList *links_list, gint *link_index, GtkWidget *textview, GUI *appGUI);
-void        gui_url_insert_link                 (GSList *links_list, gint *link_index, GtkWidget *textview, GtkTextIter *iter, gchar *color, gint font_size, gchar *text, gboolean center, GUI *appGUI);
+void        gui_url_insert_link                 (GSList *links_list, gint *link_index, GtkWidget *textview, GtkTextIter *iter, gchar *color, gchar *font, gchar *text, gboolean center, GUI *appGUI);
 void        gui_url_remove_links                (GSList *links_list, gint *link_index);
 
 #endif /* _GUI_UTILS_H */
