@@ -19,33 +19,20 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-
-#include <stdio.h>
-#include <string.h>
-#include <glib/gprintf.h>
-#include <glib.h>
-#include <time.h>
-#include <ctype.h>
-
-#ifdef HAVE_LIBGRINGOTTS
-#include <libgringotts.h>
-#endif  /* HAVE_LIBGRINGOTTS */
-
+#include "notes.h"
 #include "i18n.h"
 #include "calendar.h"
-#include "gui.h"
 #include "gui_utils.h"
-#include "notes.h"
 #include "calendar_notes.h"
 #include "options_prefs.h"
 #include "notes_items.h"
-#include "time_utils.h"
-#include "date_utils.h"
+#include "calendar_utils.h"
 #include "stock_icons.h"
 
-
 #ifdef HAVE_LIBGRINGOTTS
 
+#include <libgringotts.h>
+
 /*------------------------------------------------------------------------------*/
 
 void
@@ -54,7 +41,7 @@ notes_show_selector_editor (gint mode, GUI *appGUI) {
 GtkTextBuffer *buffer;
 GtkTextIter iter;
 GtkTreeIter n_iter;
-GtkTreePath *path;
+GtkTreePath *path, *sort_path, *filter_path;
 gchar *name;
 gchar tmpbuf[BUFFER_SIZE];
 
@@ -74,12 +61,22 @@ gchar tmpbuf[BUFFER_SIZE];
         gtk_widget_grab_focus (appGUI->nte->editor_textview);
         appGUI->nte->editor_active = TRUE;
 
-        gtk_tree_view_get_cursor (GTK_TREE_VIEW (appGUI->nte->notes_list), &path, NULL);
-        gtk_tree_model_get_iter (GTK_TREE_MODEL(appGUI->nte->notes_filter), &n_iter, path);
-        gtk_tree_model_get (GTK_TREE_MODEL(appGUI->nte->notes_filter), &n_iter, N_COLUMN_NAME, &name, -1);
+        gtk_tree_view_get_cursor (GTK_TREE_VIEW (appGUI->nte->notes_list), &sort_path, NULL);
+
+        if (sort_path == NULL) return;
+        filter_path = gtk_tree_model_sort_convert_path_to_child_path (GTK_TREE_MODEL_SORT(appGUI->nte->notes_sort), sort_path);
+        gtk_tree_path_free (sort_path);
+
+        if (filter_path == NULL) return;
+        path = gtk_tree_model_filter_convert_path_to_child_path (GTK_TREE_MODEL_FILTER(appGUI->nte->notes_filter), filter_path);
+        gtk_tree_path_free (filter_path);
+
+        gtk_tree_model_get_iter (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &n_iter, path);
+        gtk_tree_model_get (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &n_iter, N_COLUMN_NAME, &name, -1);
         sprintf (tmpbuf, "<i>%s</i>", name);
         gtk_label_set_markup (GTK_LABEL (appGUI->nte->title_label), tmpbuf);
         g_free(name);
+        gtk_tree_path_free (path);
 
         buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
         gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &iter);
@@ -99,7 +96,7 @@ guchar *text;
 guint32 current_date;
 gint current_time;
 GtkTreeIter iter;
-GtkTreeIter child_iter;
+GtkTreeIter sort_child_iter, filter_child_iter;
 GtkTreeModel *model;
 
     GUI *appGUI = (GUI *)user_data;
@@ -124,10 +121,12 @@ GtkTreeModel *model;
             current_date = get_julian_for_today ();
             current_time = get_seconds_for_today ();
 
+            gtk_tree_model_sort_convert_iter_to_child_iter (GTK_TREE_MODEL_SORT(appGUI->nte->notes_sort), 
+                                                              &sort_child_iter, &iter);
             gtk_tree_model_filter_convert_iter_to_child_iter (GTK_TREE_MODEL_FILTER(appGUI->nte->notes_filter), 
-                                                              &child_iter, &iter);
+                                                              &filter_child_iter, &sort_child_iter);
 
-            gtk_list_store_set(appGUI->nte->notes_list_store, &child_iter, 
+            gtk_list_store_set(appGUI->nte->notes_list_store, &filter_child_iter, 
                                N_COLUMN_LAST_CHANGES_DATE, get_date_time_str (current_date, current_time),
                                N_COLUMN_LAST_CHANGES_DATE_JULIAN, current_date,
                                N_COLUMN_LAST_CHANGES_TIME, current_time, -1);
@@ -240,7 +239,7 @@ GtkTextBuffer *buffer;
 /*------------------------------------------------------------------------------*/
 
 void
-add_notes_toolbar_selector_widget (GtkUIManager *tasks_uim_widget, GtkWidget *widget, gpointer user_data) {
+add_notes_toolbar_selector_widget (GtkUIManager *notes_uim_widget, GtkWidget *widget, gpointer user_data) {
 
 GtkWidget *handle_box;
 
@@ -267,7 +266,7 @@ GtkWidget *handle_box;
 /*------------------------------------------------------------------------------*/
 
 void
-add_notes_toolbar_editor_widget (GtkUIManager *tasks_uim_widget, GtkWidget *widget, gpointer user_data) {
+add_notes_toolbar_editor_widget (GtkUIManager *notes_uim_widget, GtkWidget *widget, gpointer user_data) {
 
 GtkWidget *handle_box;
 
@@ -549,6 +548,131 @@ gchar *category;
 
 /*------------------------------------------------------------------------------*/
 
+gint 
+custom_notes_sort_function (GtkTreeModel *model, GtkTreeIter *iter_a, GtkTreeIter *iter_b, gpointer user_data) {
+
+gchar *name_a, *name_b;
+gchar *category_a, *category_b;
+guint32 last_changes_date_a, last_changes_date_b;
+gint category_s, name_s;
+guint32 last_changes_date_s;
+
+    if(iter_a == NULL || iter_b == NULL) {
+        return 0;
+    }
+
+    gtk_tree_model_get(model, iter_a, N_COLUMN_NAME, &name_a, 
+                       N_COLUMN_LAST_CHANGES_DATE_JULIAN, &last_changes_date_a, N_COLUMN_CATEGORY, &category_a, -1);
+    gtk_tree_model_get(model, iter_b, N_COLUMN_NAME, &name_b, 
+                       N_COLUMN_LAST_CHANGES_DATE_JULIAN, &last_changes_date_b, N_COLUMN_CATEGORY, &category_b, -1);
+
+    
+    if (name_a == NULL) {
+        name_s = -1;
+    } else if (name_b == NULL) {
+        name_s = 1;
+    } else if (name_a != NULL && name_b != NULL) {
+        name_s = g_utf8_collate(name_a, name_b);
+    } else {
+        name_s = 0;
+    }
+    if (name_a != NULL) {
+        g_free(name_a);
+    }
+    if (name_b != NULL) {
+        g_free(name_b);
+    }
+
+    if (category_a == NULL) {
+        category_s = -1;
+    } else if (category_b == NULL) {
+        category_s = 1;
+    } else if (category_a != NULL && category_b != NULL) {
+        category_s = g_utf8_collate(category_a, category_b);
+    } else {
+        category_s = 0;
+    }
+    if (category_a != NULL) {
+        g_free(category_a);
+    }
+    if (category_b != NULL) {
+        g_free(category_b);
+    }
+
+    if (!last_changes_date_a) last_changes_date_a = 1 << 31;
+    if (!last_changes_date_b) last_changes_date_b = 1 << 31;
+    last_changes_date_s = last_changes_date_a - last_changes_date_b;
+
+    switch(config.notes_sorting_mode) {
+
+        /* Name, Last changes, Category */
+        case 0:
+            if (name_s != 0)
+                return name_s;
+            if (last_changes_date_s != 0)
+                return last_changes_date_s;
+            if (category_s != 0)
+                return category_s;
+            break;
+
+        /* Name, Category, Last changes */
+        case 1:
+            if (name_s != 0)
+                return name_s;
+            if (category_s != 0)
+                return category_s;
+            if (last_changes_date_s != 0)
+                return last_changes_date_s;
+            break;
+
+        /* Category, Last changes, Name */
+        case 2:
+            if (category_s != 0)
+                return category_s;
+            if (last_changes_date_s != 0)
+                return last_changes_date_s;
+            if (name_s != 0)
+                return name_s;
+            break;
+
+        /* Category, Name, Last changes */
+        case 3:
+            if (category_s != 0)
+                return category_s;
+            if (name_s != 0)
+                return name_s;
+            if (last_changes_date_s != 0)
+                return last_changes_date_s;
+            break;
+
+        /* Last changes, Category, Name */
+        case 4:
+            if (last_changes_date_s != 0)
+                return last_changes_date_s;
+            if (category_s != 0)
+                return category_s;
+            if (name_s != 0)
+                return name_s;
+            break;
+
+        /* Last changes, Name, Category */
+        case 5:
+            if (last_changes_date_s != 0)
+                return last_changes_date_s;
+            if (name_s != 0)
+                return name_s;
+            if (category_s != 0)
+                return category_s;
+            break;
+
+        default:
+            break;
+    }
+
+    return 0;
+}
+
+/*------------------------------------------------------------------------------*/
 
 void 
 gui_create_notes(GUI *appGUI) {
@@ -758,8 +882,11 @@ guint n_entries_editor = G_N_ELEMENTS (entries_editor);
                                             (GtkTreeModelFilterVisibleFunc)notes_list_filter_cb, 
                                             appGUI, NULL);
 
-    appGUI->nte->notes_list = gtk_tree_view_new_with_model(GTK_TREE_MODEL(appGUI->nte->notes_filter));
+    appGUI->nte->notes_sort = gtk_tree_model_sort_new_with_model(GTK_TREE_MODEL(appGUI->nte->notes_filter));
+
+    appGUI->nte->notes_list = gtk_tree_view_new_with_model(GTK_TREE_MODEL(appGUI->nte->notes_sort));
     gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(appGUI->nte->notes_list), config.notes_rules_hint);
+    gtk_tree_view_set_enable_search (GTK_TREE_VIEW(appGUI->nte->notes_list), FALSE);
     gtk_widget_show (appGUI->nte->notes_list);
     GTK_WIDGET_SET_FLAGS (appGUI->nte->notes_list, GTK_CAN_DEFAULT);
     gtk_container_add (GTK_CONTAINER (scrolled_win), appGUI->nte->notes_list);
@@ -845,7 +972,14 @@ guint n_entries_editor = G_N_ELEMENTS (entries_editor);
                                                       "text", N_COLUMN_FILENAME,
                                                       NULL);
     gtk_tree_view_column_set_visible (column, FALSE);
-    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->nte->notes_list), column);
+    gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->nte->notes_list), column);
+
+    /* configure sorting */
+
+    gtk_tree_sortable_set_sort_func ((GtkTreeSortable *)appGUI->nte->notes_sort, N_COLUMN_NAME, 
+                                     (GtkTreeIterCompareFunc)custom_notes_sort_function, NULL, NULL);
+    gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable *)appGUI->nte->notes_sort, N_COLUMN_NAME, 
+                                          config.notes_sorting_order);
 
     /*-------------------------------------------------------------------------------------*/
     /* editor */
@@ -880,7 +1014,7 @@ guint n_entries_editor = G_N_ELEMENTS (entries_editor);
     gtk_text_view_set_pixels_above_lines(GTK_TEXT_VIEW(appGUI->nte->editor_textview), 4);
     gtk_text_view_set_left_margin(GTK_TEXT_VIEW(appGUI->nte->editor_textview), 4);
     gtk_text_view_set_right_margin(GTK_TEXT_VIEW(appGUI->nte->editor_textview), 4);
-    gtk_widget_modify_font (GTK_WIDGET(appGUI->nte->editor_textview), appGUI->fd_notes_editor);
+    gtk_widget_modify_font (GTK_WIDGET(appGUI->nte->editor_textview), appGUI->nte->fd_notes_font);
 
     buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
     appGUI->nte->buffer_check_modify_enable = FALSE;
