@@ -19,40 +19,23 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-
-#include <stdio.h>
-#include <string.h>
-#include <glib.h>
-#include <glib/gstdio.h>
-#include <time.h>
-#include <ctype.h>
-#include <libxml/xmlmemory.h>
-#include <libxml/parser.h>
-
-#include <config.h>
-
-#ifdef HAVE_LIBGRINGOTTS
-#include <libgringotts.h>
-#endif  /* HAVE_LIBGRINGOTTS */
-
+#include "notes_items.h"
 #include "i18n.h"
-#include "gui.h"
 #include "gui_utils.h"
 #include "options_gui.h"
 #include "options_prefs.h"
 #include "notes.h"
-#include "notes_items.h"
 #include "calendar.h"
 #include "calendar_notes.h"
 #include "calendar_widget.h"
-#include "time_utils.h"
-#include "date_utils.h"
+#include "calendar_utils.h"
 #include "stock_icons.h"
 #include "options_gui_notes.h"
 
-
 #ifdef HAVE_LIBGRINGOTTS
 
+#include <libgringotts.h>
+
 /*------------------------------------------------------------------------------*/
 
 gboolean
@@ -101,7 +84,7 @@ button_notes_edit_close_cb (GtkWidget *widget, gpointer data) {
 void
 notes_edit_action_cb (GtkWidget *widget, gpointer data) {
 
-GtkTreePath *path;
+GtkTreePath *path, *sort_path, *filter_path;
 GtkTreeIter iter;
 gchar *category;
 gboolean flag;
@@ -109,7 +92,15 @@ gint i, n;
 
     GUI *appGUI = (GUI *)data;
 
-    gtk_tree_view_get_cursor (GTK_TREE_VIEW (appGUI->nte->notes_list), &path, NULL);
+    gtk_tree_view_get_cursor (GTK_TREE_VIEW (appGUI->nte->notes_list), &sort_path, NULL);
+
+    if (sort_path == NULL) return;
+    filter_path = gtk_tree_model_sort_convert_path_to_child_path (GTK_TREE_MODEL_SORT(appGUI->nte->notes_sort), sort_path);
+    gtk_tree_path_free (sort_path);
+
+    if (filter_path == NULL) return;
+    path = gtk_tree_model_filter_convert_path_to_child_path (GTK_TREE_MODEL_FILTER(appGUI->nte->notes_filter), filter_path);
+    gtk_tree_path_free (filter_path);
 
     if (path != NULL) {
 
@@ -139,6 +130,7 @@ gint i, n;
                            N_COLUMN_CATEGORY, category, -1);
 
         g_free (category);
+        gtk_tree_path_free (path);
 
         notes_edit_close_cb (widget, NULL, data);
     }
@@ -180,7 +172,6 @@ notes_add_entry_key_release_cb (GtkWidget *widget, GdkEventKey *event, gpointer
 
 /*------------------------------------------------------------------------------*/
 
-
 void
 notes_edit_dialog_show (GtkWidget *list, GtkTreeModel *model, GUI *appGUI) {
 
@@ -197,11 +188,19 @@ gchar tmpbuf[BUFFER_SIZE];
 gint i, n;
 gchar *c_category, *category, *name;
 GtkTreeIter iter;
-GtkTreePath *path;
+GtkTreePath *sort_path, *filter_path, *path;
 
-    gtk_tree_view_get_cursor (GTK_TREE_VIEW (list), &path, NULL);
+    gtk_tree_view_get_cursor (GTK_TREE_VIEW (list), &sort_path, NULL);
 
-    if (path != NULL) {
+    if (sort_path != NULL) {
+
+        filter_path = gtk_tree_model_sort_convert_path_to_child_path (GTK_TREE_MODEL_SORT(appGUI->nte->notes_sort), sort_path);
+        gtk_tree_path_free (sort_path);
+
+        if (filter_path == NULL) return;
+
+        path = gtk_tree_model_filter_convert_path_to_child_path (GTK_TREE_MODEL_FILTER(appGUI->nte->notes_filter), filter_path);
+        gtk_tree_path_free (filter_path);
 
         appGUI->nte->edit_entry_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
         gtk_container_set_border_width (GTK_CONTAINER (appGUI->nte->edit_entry_window), 4);
@@ -272,8 +271,10 @@ GtkTreePath *path;
         gtk_container_add (GTK_CONTAINER (alignment), appGUI->nte->category_combobox);
         gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->nte->category_combobox), _("None"));
 
-        gtk_tree_view_get_cursor (GTK_TREE_VIEW (appGUI->nte->notes_list), &path, NULL);
-        gtk_tree_model_get_iter (GTK_TREE_MODEL(appGUI->nte->notes_filter), &iter, path);
+        gtk_tree_view_get_cursor (GTK_TREE_VIEW (appGUI->nte->notes_list), &sort_path, NULL);
+        filter_path = gtk_tree_model_sort_convert_path_to_child_path (GTK_TREE_MODEL_SORT(appGUI->nte->notes_sort), sort_path);
+        gtk_tree_model_get_iter (GTK_TREE_MODEL(appGUI->nte->notes_filter), &iter, filter_path);
+        gtk_tree_path_free (filter_path);
         gtk_tree_model_get (GTK_TREE_MODEL(appGUI->nte->notes_filter), &iter, N_COLUMN_CATEGORY, &c_category, -1);
 
         i = n = 0;
@@ -328,7 +329,6 @@ GtkTreePath *path;
                             G_CALLBACK (notes_edit_action_cb), appGUI);
 
         gtk_widget_show (appGUI->nte->edit_entry_window);
-
     }
 }
 
@@ -338,16 +338,22 @@ void
 notes_remove_dialog_show (GtkWidget *list, GtkListStore *list_store, GUI *appGUI) {
 
 gint response;
-GtkTreePath *path, *filter_path;
+GtkTreePath *path, *filter_path, *sort_path;
 GtkTreeIter iter;
 gchar *filename;
 gchar tmpbuf[BUFFER_SIZE];
 
-    gtk_tree_view_get_cursor (GTK_TREE_VIEW (list), &filter_path, NULL);
+    gtk_tree_view_get_cursor (GTK_TREE_VIEW (list), &sort_path, NULL);
+
+    if (sort_path == NULL) return;
+
+    filter_path = gtk_tree_model_sort_convert_path_to_child_path (GTK_TREE_MODEL_SORT(appGUI->nte->notes_sort), sort_path);
+    gtk_tree_path_free (sort_path);
 
     if (filter_path != NULL) {
 
         path = gtk_tree_model_filter_convert_path_to_child_path (GTK_TREE_MODEL_FILTER(appGUI->nte->notes_filter), filter_path);
+        gtk_tree_path_free (filter_path);
 
         if (path != NULL) {
 
@@ -441,7 +447,7 @@ gboolean flag;
 
     current_date = get_julian_for_today ();
     current_time = get_seconds_for_today ();
-    current_filename = g_strdup (notes_get_filename ());
+    current_filename = g_strdup (notes_get_filename (appGUI));
 	context = grg_context_initialize_defaults ((unsigned char*) "OSM");
 	keyholder = grg_key_gen ((unsigned char*) pass, -1);
 
@@ -898,16 +904,16 @@ gchar *notes_dir;
 gint last_changes_time, create_time;
 guint32 last_changes_date_julian, create_date_julian;
 
-    notes_dir = g_strdup(prefs_get_config_filename(NOTES_DIRNAME));
+    notes_dir = g_strdup(prefs_get_config_filename(NOTES_DIRNAME, appGUI));
     if (g_file_test (notes_dir, G_FILE_TEST_IS_DIR | G_FILE_TEST_EXISTS) == FALSE) {
         g_mkdir (notes_dir, 0755);
     }
     g_free(notes_dir);
 
-    if (g_file_test (prefs_get_config_filename(NOTES_ENTRIES_FILENAME), G_FILE_TEST_IS_REGULAR) == FALSE) 
+    if (g_file_test (prefs_get_config_filename(NOTES_ENTRIES_FILENAME, appGUI), G_FILE_TEST_IS_REGULAR) == FALSE) 
         return;
 
-    if((doc = xmlParseFile(prefs_get_config_filename(NOTES_ENTRIES_FILENAME)))) {
+    if((doc = xmlParseFile(prefs_get_config_filename(NOTES_ENTRIES_FILENAME, appGUI)))) {
 
         if(!(node = xmlDocGetRootElement(doc))) {
             xmlFreeDoc(doc);
@@ -1117,21 +1123,21 @@ guint32 last_changes_date_julian, create_date_julian;
         g_free (note_filename);
     }
 
-    xmlSaveFormatFileEnc(prefs_get_config_filename(NOTES_ENTRIES_FILENAME), doc, "utf-8", 1);
+    xmlSaveFormatFileEnc(prefs_get_config_filename(NOTES_ENTRIES_FILENAME, appGUI), doc, "utf-8", 1);
     xmlFreeDoc(doc);
 }
 
 /*------------------------------------------------------------------------------*/
 
 gchar *
-notes_get_filename (void) {
+notes_get_filename (GUI *appGUI) {
 
 guint i;
 static gchar fullpath[PATH_MAX];
 
     for(i=0; i < 99999999; i++) {
         g_snprintf(fullpath, PATH_MAX-1, "%s%c%08d.osm", 
-                   prefs_get_config_filename(NOTES_DIRNAME), G_DIR_SEPARATOR, i);
+                   prefs_get_config_filename(NOTES_DIRNAME, appGUI), G_DIR_SEPARATOR, i);
         if (g_file_test (fullpath, G_FILE_TEST_EXISTS) == FALSE) break;
     }
 
@@ -1151,7 +1157,7 @@ const gchar *item_name;
 gchar *note_filename;
 GtkTreeIter iter;
 
-    g_snprintf(fullpath, PATH_MAX-1, "%s", prefs_get_config_filename(NOTES_DIRNAME));
+    g_snprintf(fullpath, PATH_MAX-1, "%s", prefs_get_config_filename(NOTES_DIRNAME, appGUI));
     dpath = g_dir_open (fullpath, 0, NULL);
 
     if (dpath != NULL) {
@@ -1161,7 +1167,7 @@ GtkTreeIter iter;
             found = FALSE;
 
             g_snprintf(fullpath, PATH_MAX-1, "%s%c%s", 
-                       prefs_get_config_filename(NOTES_DIRNAME), G_DIR_SEPARATOR, item_name);
+                       prefs_get_config_filename(NOTES_DIRNAME, appGUI), G_DIR_SEPARATOR, item_name);
 
             i = 0;
 
