@@ -29,7 +29,7 @@ void        notes_edit_dialog_show      (GtkWidget *list, GtkTreeModel *model, G
 void        notes_remove_dialog_show    (GtkWidget *list, GtkListStore *list_store, GUI *appGUI);
 void        notes_enter_password        (GUI *appGUI);
 void        notes_cleanup_files         (GUI *appGUI);
-gchar *     notes_get_filename          (void);
+gchar *     notes_get_filename          (GUI *appGUI);
 
 void        read_notes_entries          (GUI *appGUI);
 void        write_notes_entries         (GUI *appGUI);
