@@ -19,27 +19,13 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include <stdio.h>
-#include <string.h>
-#include <ctype.h>
-#include <time.h>
-#include <glib/gprintf.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <sys/stat.h>
-#include <glib.h>
-#include <limits.h>
-#include <libxml/xmlmemory.h>
-#include <libxml/parser.h>
-
-#include "gui.h"
+#include "options_gui.h"
 #include "gui_utils.h"
 #include "calendar.h"
 #include "calendar_notes.h"
 #include "calendar_widget.h"
 #include "i18n.h"
 #include "tasks.h"
-#include "options_gui.h"
 #include "options_gui_calendar.h"
 #include "options_gui_tasks.h"
 #include "options_gui_contacts.h"
@@ -49,7 +35,6 @@
 #include "contacts.h"
 #include "stock_icons.h"
 
-
 struct  osmo_prefs              config;
 
 /*------------------------------------------------------------------------------*/
@@ -333,17 +318,22 @@ GSList              *radiobutton_group = NULL;
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->enable_block_cursor_checkbutton), !config.cursor_type);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->enable_auxilary_calendars_checkbutton), config.enable_auxilary_calendars);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->strikethrough_past_notes_checkbutton), config.strikethrough_past_notes);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->ascending_sorting_in_day_notes_checkbutton), config.ascending_sorting_in_day_notes_browser);
 
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->di_show_current_time_checkbutton), 
                                   config.di_show_current_time);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->di_show_day_number_checkbutton), 
                                   config.di_show_day_number);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->di_show_current_day_distance_checkbutton), 
+                                  config.di_show_current_day_distance);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->di_show_marked_days_checkbutton), 
                                   config.di_show_marked_days);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->di_show_week_number_checkbutton), 
                                   config.di_show_week_number);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->di_show_weekend_days_checkbutton), 
                                   config.di_show_weekend_days);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->di_show_day_category_checkbutton), 
+                                  config.di_show_day_category);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->di_show_moon_phase_checkbutton), 
                                   config.di_show_moon_phase);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->di_show_notes_checkbutton), 
@@ -381,8 +371,12 @@ GSList              *radiobutton_group = NULL;
                                   config.hide_completed);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->ct_delete_items_checkbutton), 
                                   config.delete_completed);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->ct_add_item_checkbutton), 
+                                  config.add_edit);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->vc_due_date_checkbutton), 
                                   config.visible_due_date_column);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->vc_type_checkbutton), 
+                                  config.visible_type_column);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->vc_priority_checkbutton), 
                                   config.visible_priority_column);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->vc_category_checkbutton), 
@@ -423,8 +417,8 @@ GSList              *radiobutton_group = NULL;
     gtk_entry_set_text (GTK_ENTRY(appGUI->opt->entry_web_browser), config.web_browser);
     gtk_entry_set_text (GTK_ENTRY(appGUI->opt->entry_email_client), config.email_client);
 
-    gtk_spin_button_set_value (GTK_SPIN_BUTTON(appGUI->opt->name_font_size_spinbutton), config.name_font_size);
-    gtk_spin_button_set_value (GTK_SPIN_BUTTON(appGUI->opt->tags_font_size_spinbutton), config.tags_font_size);
+    gtk_entry_set_text (GTK_ENTRY(appGUI->opt->cn_font_entry), config.contact_name_font);
+    gtk_entry_set_text (GTK_ENTRY(appGUI->opt->ci_font_entry), config.contact_item_font);
 
     appGUI->opt->callback_active = TRUE;
 
