@@ -24,6 +24,17 @@
 
 #include "gui.h"
 
+enum {
+    OPT_PAGE_CALENDAR = 0,
+    OPT_PAGE_TASKS,
+    OPT_PAGE_CONTACTS,
+#ifdef HAVE_LIBGRINGOTTS
+    OPT_PAGE_NOTES,
+#endif  /* HAVE_LIBGRINGOTTS */
+    OPT_PAGE_GENERAL,
+    OPT_NUMBER_OF_PAGES
+};
+
 void    gui_create_options      (GUI *appGUI);
 void    options_switch_buttons  (gboolean left, GUI *appGUI);
 
