@@ -24,7 +24,16 @@
 
 #include "gui.h"
 
-void    gui_create_calendar_page                    (GtkWidget *vbox, GUI *appGUI);
+enum {
+    ICAL_COLUMN_VALID_ICON = 0,
+    ICAL_COLUMN_NAME,
+    ICAL_COLUMN_FILENAME,
+    ICAL_COLUMN_VALID_FLAG,
+    ICAL_COLUMN_ENABLE_DESC,
+    ICAL_COLUMN_USE_YEAR
+};
+
+void    gui_create_calendar_options_page            (GtkWidget *vbox, GUI *appGUI);
 void    calendar_cursor_settings_enable_disable     (GUI *appGUI);
 
 #endif /* _OPTIONS_GUI_CALENDAR_H */
