@@ -19,20 +19,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include <stdio.h>
-#include <string.h>
-#include <ctype.h>
-#include <time.h>
-#include <glib/gprintf.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <sys/stat.h>
-#include <glib.h>
-#include <limits.h>
-#include <libxml/xmlmemory.h>
-#include <libxml/parser.h>
-
-#include "gui.h"
+#include "options_gui_contacts.h"
 #include "gui_utils.h"
 #include "calendar.h"
 #include "calendar_notes.h"
@@ -46,6 +33,72 @@
 #include "contacts.h"
 #include "stock_icons.h"
 
+/*------------------------------------------------------------------------------*/
+
+void
+cn_font_select_cb (GtkWidget *widget, gpointer data) {
+
+GtkWidget *font_selector;
+gchar *font_name;
+gint response;
+
+    GUI *appGUI = (GUI *)data;
+
+    font_selector = gtk_font_selection_dialog_new (_("Select a font..."));
+    gtk_window_set_modal(GTK_WINDOW(font_selector), TRUE);
+    gtk_window_set_position(GTK_WINDOW(font_selector), GTK_WIN_POS_MOUSE);
+    gtk_window_set_transient_for(GTK_WINDOW(font_selector), GTK_WINDOW(appGUI->main_window));
+    gtk_font_selection_dialog_set_font_name (GTK_FONT_SELECTION_DIALOG(font_selector), config.contact_name_font);
+    gtk_widget_show (font_selector);
+    response = gtk_dialog_run (GTK_DIALOG (font_selector));
+
+    if (response == GTK_RESPONSE_OK) {
+
+        font_name = gtk_font_selection_dialog_get_font_name (GTK_FONT_SELECTION_DIALOG(font_selector));
+        strncpy(config.contact_name_font, font_name, MAXFONTNAME-1);
+        gtk_entry_set_text(GTK_ENTRY(appGUI->opt->cn_font_entry), font_name);
+        g_free (font_name);
+
+        /* contact name font */
+        g_object_set (G_OBJECT (appGUI->cnt->contact_name_tag_object), "font", (gchar *)config.contact_name_font, NULL);
+    }
+
+    gtk_widget_destroy (font_selector);
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+ci_font_select_cb (GtkWidget *widget, gpointer data) {
+
+GtkWidget *font_selector;
+gchar *font_name;
+gint response;
+
+    GUI *appGUI = (GUI *)data;
+
+    font_selector = gtk_font_selection_dialog_new (_("Select a font..."));
+    gtk_window_set_modal(GTK_WINDOW(font_selector), TRUE);
+    gtk_window_set_position(GTK_WINDOW(font_selector), GTK_WIN_POS_MOUSE);
+    gtk_window_set_transient_for(GTK_WINDOW(font_selector), GTK_WINDOW(appGUI->main_window));
+    gtk_font_selection_dialog_set_font_name (GTK_FONT_SELECTION_DIALOG(font_selector), config.contact_item_font);
+    gtk_widget_show (font_selector);
+    response = gtk_dialog_run (GTK_DIALOG (font_selector));
+
+    if (response == GTK_RESPONSE_OK) {
+
+        font_name = gtk_font_selection_dialog_get_font_name (GTK_FONT_SELECTION_DIALOG(font_selector));
+        strncpy(config.contact_item_font, font_name, MAXFONTNAME-1);
+        gtk_entry_set_text(GTK_ENTRY(appGUI->opt->ci_font_entry), font_name);
+        g_free (font_name);
+
+        /* contact item font */
+        g_object_set (G_OBJECT (appGUI->cnt->contact_tags_value_tag_object), "font", (gchar *)config.contact_item_font, NULL);
+        g_signal_emit_by_name (appGUI->cnt->contacts_list_selection, "changed");
+    }
+
+    gtk_widget_destroy (font_selector);
+}
 
 /*------------------------------------------------------------------------------*/
 
@@ -135,16 +188,13 @@ gboolean state;
 void
 contact_tag_color_changed_cb (GtkColorButton *widget, gpointer user_data) {
 
-gchar tmpbuf[BUFFER_SIZE];
 GdkColor color;
 
     GUI *appGUI = (GUI *)user_data;
 
     gtk_color_button_get_color(GTK_COLOR_BUTTON(appGUI->opt->contact_tag_color_picker), &color);
-    sprintf(tmpbuf, "#%02X%02X%02X", color.red * 256 / 65536, color.green * 256 / 65536, color.blue * 256 / 65536);
-    strncpy(config.contact_tag_color, tmpbuf, MAXCOLORNAME-1);
-    g_object_set (G_OBJECT (appGUI->cnt->contact_color_tag_object), "foreground-gdk", &color, NULL);
-
+    sprintf (config.contact_tag_color, "#%02X%02X%02X", color.red * 256 / 65536, color.green * 256 / 65536, color.blue * 256 / 65536);
+    g_signal_emit_by_name (appGUI->cnt->contacts_list_selection, "changed");
 }
 
 /*------------------------------------------------------------------------------*/
@@ -215,9 +265,9 @@ name_font_size_changed_cb (GtkSpinButton *spinbutton, gpointer user_data) {
 
     if (!appGUI->opt->callback_active) return;
 
-    config.name_font_size = (gint) gtk_spin_button_get_value (GTK_SPIN_BUTTON(appGUI->opt->name_font_size_spinbutton));
+    /*config.name_font_size = (gint) gtk_spin_button_get_value (GTK_SPIN_BUTTON(appGUI->opt->name_font_size_spinbutton));*/
 
-    g_object_set (G_OBJECT (appGUI->cnt->contact_name_tag_object), "size", config.name_font_size * PANGO_SCALE, NULL);
+    /*g_object_set (G_OBJECT (appGUI->cnt->contact_name_tag_object), "size", config.name_font_size * PANGO_SCALE, NULL);*/
 
 }
 
@@ -230,10 +280,10 @@ tags_font_size_changed_cb (GtkSpinButton *spinbutton, gpointer user_data) {
 
     if (!appGUI->opt->callback_active) return;
 
-    config.tags_font_size = (gint) gtk_spin_button_get_value (GTK_SPIN_BUTTON(appGUI->opt->tags_font_size_spinbutton));
+    /*config.tags_font_size = (gint) gtk_spin_button_get_value (GTK_SPIN_BUTTON(appGUI->opt->tags_font_size_spinbutton));*/
 
-    g_object_set (G_OBJECT (appGUI->cnt->contact_color_tag_object), "size", config.tags_font_size * PANGO_SCALE, NULL);
-    g_object_set (G_OBJECT (appGUI->cnt->contact_tags_value_tag_object), "size", config.tags_font_size * PANGO_SCALE, NULL);
+    /*g_object_set (G_OBJECT (appGUI->cnt->contact_color_tag_object), "size", config.tags_font_size * PANGO_SCALE, NULL);*/
+    /*g_object_set (G_OBJECT (appGUI->cnt->contact_tags_value_tag_object), "size", config.tags_font_size * PANGO_SCALE, NULL);*/
 
 }
 
@@ -343,11 +393,13 @@ GtkWidget           *table;
 GtkWidget           *alignment;
 GtkWidget           *scrolledwindow;
 GtkWidget           *contacts_group_table;
+GtkWidget           *cn_font_button;
+GtkWidget           *ci_font_button;
 GtkCellRenderer     *renderer;
 GtkTreeViewColumn   *column;
 GdkColor            color;
-
-gchar tmpbuf[BUFFER_SIZE];
+gchar               tmpbuf[BUFFER_SIZE];
+gint i;
 
     appGUI->opt->contacts_vbox = gtk_vbox_new (FALSE, 0);
     gtk_box_pack_start (GTK_BOX (vbox), appGUI->opt->contacts_vbox, FALSE, FALSE, 0);
@@ -372,23 +424,25 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_widget_show (appearance_vbox);
     gtk_container_add (GTK_CONTAINER (alignment), appearance_vbox);
 
-    table = gtk_table_new (4, 5, FALSE);
+    table = gtk_table_new (5, 5, FALSE);
     gtk_widget_show (table);
     gtk_box_pack_start (GTK_BOX (appearance_vbox), table, FALSE, FALSE, 0);
     gtk_table_set_col_spacings (GTK_TABLE (table), 4);
     gtk_table_set_row_spacings (GTK_TABLE (table), 8);
 
+    i = 0;
+
     sprintf(tmpbuf, "%s:", _("Colors"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
+    gtk_table_attach (GTK_TABLE (table), label, 0, 1, i, i+1,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
     colors_hbox = gtk_hbox_new (FALSE, 8);
     gtk_widget_show (colors_hbox);
-    gtk_table_attach (GTK_TABLE (table), colors_hbox, 1, 4, 0, 1,
+    gtk_table_attach (GTK_TABLE (table), colors_hbox, 1, 4, i, i+1,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
 
@@ -410,54 +464,79 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_color_button_set_color (GTK_COLOR_BUTTON (appGUI->opt->contact_link_color_picker), &color);
     gtk_box_pack_start (GTK_BOX (colors_hbox), appGUI->opt->contact_link_color_picker, FALSE, FALSE, 0);
 
-    sprintf(tmpbuf, "%s:", _("Name font size"));
+    i++;
+
+    sprintf(tmpbuf, "%s:", _("Name font"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
+    gtk_table_attach (GTK_TABLE (table), label, 0, 1, i, i+1,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
-    appGUI->opt->name_font_size_spinbutton_adj = gtk_adjustment_new (6, 6, 100, 1, 10, 10);
-    appGUI->opt->name_font_size_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (appGUI->opt->name_font_size_spinbutton_adj), 1, 0);
-    g_signal_connect (G_OBJECT (appGUI->opt->name_font_size_spinbutton), "value-changed",
-                      G_CALLBACK (name_font_size_changed_cb), appGUI);
-    gtk_widget_show (appGUI->opt->name_font_size_spinbutton);
-    gtk_table_attach (GTK_TABLE (table), appGUI->opt->name_font_size_spinbutton, 1, 2, 1, 2,
+    appGUI->opt->cn_font_entry = gtk_entry_new ();
+    GTK_WIDGET_UNSET_FLAGS(appGUI->opt->cn_font_entry, GTK_CAN_FOCUS);
+    gtk_widget_show (appGUI->opt->cn_font_entry);
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->cn_font_entry, 1, 2, i, i+1,
+                      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
+
+    if (config.default_stock_icons) {
+        cn_font_button = gui_stock_button (GTK_STOCK_SELECT_FONT, FALSE);
+    } else {
+        cn_font_button = gui_stock_button (OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
+    }
+    GTK_WIDGET_UNSET_FLAGS(cn_font_button, GTK_CAN_FOCUS);
+    gtk_widget_show (cn_font_button);
+    g_signal_connect (G_OBJECT (cn_font_button), "clicked",
+                      G_CALLBACK (cn_font_select_cb), appGUI);
+    gtk_table_attach (GTK_TABLE (table), cn_font_button, 2, 3, i, i+1,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
-    gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (appGUI->opt->name_font_size_spinbutton), TRUE);
 
+    i++;
 
-    sprintf(tmpbuf, "%s:", _("Tags font size"));
+    sprintf(tmpbuf, "%s:", _("Item font"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 2, 3, 1, 2,
+    gtk_table_attach (GTK_TABLE (table), label, 0, 1, i, i+1,
                     (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (GTK_FILL), 6, 0);
+                    (GtkAttachOptions) (GTK_FILL), 0, 0);
+    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
-    appGUI->opt->tags_font_size_spinbutton_adj = gtk_adjustment_new (6, 6, 100, 1, 10, 10);
-    appGUI->opt->tags_font_size_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (appGUI->opt->tags_font_size_spinbutton_adj), 1, 0);
-    g_signal_connect (G_OBJECT (appGUI->opt->tags_font_size_spinbutton), "value-changed",
-                      G_CALLBACK (tags_font_size_changed_cb), appGUI);
-    gtk_widget_show (appGUI->opt->tags_font_size_spinbutton);
-    gtk_table_attach (GTK_TABLE (table), appGUI->opt->tags_font_size_spinbutton, 3, 4, 1, 2,
+    appGUI->opt->ci_font_entry = gtk_entry_new ();
+    GTK_WIDGET_UNSET_FLAGS(appGUI->opt->ci_font_entry, GTK_CAN_FOCUS);
+    gtk_widget_show (appGUI->opt->ci_font_entry);
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->ci_font_entry, 1, 2, i, i+1,
+                      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
+
+    if (config.default_stock_icons) {
+        ci_font_button = gui_stock_button (GTK_STOCK_SELECT_FONT, FALSE);
+    } else {
+        ci_font_button = gui_stock_button (OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
+    }
+    GTK_WIDGET_UNSET_FLAGS(cn_font_button, GTK_CAN_FOCUS);
+    gtk_widget_show (ci_font_button);
+    g_signal_connect (G_OBJECT (ci_font_button), "clicked",
+                      G_CALLBACK (ci_font_select_cb), appGUI);
+    gtk_table_attach (GTK_TABLE (table), ci_font_button, 2, 3, i, i+1,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
-    gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (appGUI->opt->tags_font_size_spinbutton), TRUE);
 
+    i++;
 
     sprintf(tmpbuf, "%s:", _("Photo size"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3,
+    gtk_table_attach (GTK_TABLE (table), label, 0, 1, i, i+1,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
     photo_hbox = gtk_hbox_new (FALSE, 8);
     gtk_widget_show (photo_hbox);
-    gtk_table_attach (GTK_TABLE (table), photo_hbox, 1, 4, 2, 3,
+    gtk_table_attach (GTK_TABLE (table), photo_hbox, 1, 4, i, i+1,
                     (GtkAttachOptions) (GTK_FILL),
                     (GtkAttachOptions) (GTK_FILL), 0, 0);
 
