@@ -19,20 +19,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include <stdio.h>
-#include <string.h>
-#include <ctype.h>
-#include <time.h>
-#include <glib/gprintf.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <sys/stat.h>
-#include <glib.h>
-#include <limits.h>
-#include <libxml/xmlmemory.h>
-#include <libxml/parser.h>
-
-#include "gui.h"
+#include "options_gui_general.h"
 #include "gui_utils.h"
 #include "calendar.h"
 #include "calendar_notes.h"
@@ -47,7 +34,6 @@
 #include "contacts.h"
 #include "stock_icons.h"
 
-
 /*------------------------------------------------------------------------------*/
 
 void
@@ -355,7 +341,7 @@ date_format_changed_cb (GtkComboBox *widget, gpointer user_data) {
     if (!appGUI->opt->callback_active) return;
 
     config.date_format = gtk_combo_box_get_active (GTK_COMBO_BOX(appGUI->opt->date_format_combobox));
-    refresh_due_dates(appGUI);
+    refresh_tasks (appGUI);
 
 }
 
@@ -369,7 +355,7 @@ time_format_changed_cb (GtkComboBox *widget, gpointer user_data) {
     if (!appGUI->opt->callback_active) return;
 
     config.time_format = gtk_combo_box_get_active (GTK_COMBO_BOX(appGUI->opt->time_format_combobox));
-    refresh_due_dates(appGUI);
+    refresh_tasks (appGUI);
 
 }
 
