@@ -24,7 +24,8 @@
 
 #include "gui.h"
 
-void    gui_create_general_page   (GtkWidget *vbox, GUI *appGUI);
+gint    get_visible_tabs                    (GUI *appGUI);
+void    gui_create_general_options_page     (GtkWidget *vbox, GUI *appGUI);
 
 #endif /* _OPTIONS_GUI_GENERAL_H */
 
