@@ -19,31 +19,14 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include <stdio.h>
-#include <string.h>
-#include <ctype.h>
-#include <time.h>
-#include <glib/gprintf.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <sys/stat.h>
-#include <glib.h>
-#include <limits.h>
-#include <libxml/xmlmemory.h>
-#include <libxml/parser.h>
-#include <config.h>
-
-#ifdef HAVE_LIBGRINGOTTS
-#include <libgringotts.h>
-#endif  /* HAVE_LIBGRINGOTTS */
-
-#include "gui.h"
+#include "options_gui_notes.h"
 #include "gui_utils.h"
 #include "calendar.h"
 #include "calendar_notes.h"
 #include "calendar_widget.h"
 #include "i18n.h"
 #include "tasks.h"
+#include "notes.h"
 #include "options_gui.h"
 #include "options_gui_calendar.h"
 #include "options_prefs.h"
@@ -52,6 +35,8 @@
 
 #ifdef HAVE_LIBGRINGOTTS
 
+#include <libgringotts.h>
+
 /*------------------------------------------------------------------------------*/
 
 gint
@@ -121,9 +106,9 @@ gint response;
         gtk_entry_set_text(GTK_ENTRY(appGUI->opt->editor_font_entry), font_name);
         g_free (font_name);
 
-        pango_font_description_free(appGUI->fd_notes_editor);
-        appGUI->fd_notes_editor = pango_font_description_from_string(config.notes_editor_font);
-        gtk_widget_modify_font (GTK_WIDGET(appGUI->nte->editor_textview), appGUI->fd_notes_editor);
+        pango_font_description_free(appGUI->nte->fd_notes_font);
+        appGUI->nte->fd_notes_font = pango_font_description_from_string(config.notes_editor_font);
+        gtk_widget_modify_font (GTK_WIDGET(appGUI->nte->editor_textview), appGUI->nte->fd_notes_font);
     }
 
     gtk_widget_destroy (font_selector);
@@ -317,10 +302,44 @@ GtkTreeModel *model;
 
 /*------------------------------------------------------------------------------*/
 
+void
+notes_sort_order_changed_cb (GtkComboBox *widget, gpointer user_data) {
+
+    GUI *appGUI = (GUI *)user_data;
+
+    if (!appGUI->opt->callback_active) return;
+
+    config.notes_sorting_order = gtk_combo_box_get_active (GTK_COMBO_BOX(appGUI->opt->notes_sort_order_combobox));
+
+    gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable *)appGUI->nte->notes_sort, 
+                                          N_COLUMN_NAME, config.notes_sorting_order);
+
+    gtk_tree_model_filter_refilter(GTK_TREE_MODEL_FILTER(appGUI->nte->notes_filter));
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+notes_sort_mode_changed_cb (GtkComboBox *widget, gpointer user_data) {
+
+    GUI *appGUI = (GUI *)user_data;
+
+    if (!appGUI->opt->callback_active) return;
+
+    config.notes_sorting_mode = gtk_combo_box_get_active (GTK_COMBO_BOX(appGUI->opt->notes_sort_mode_combobox));
+
+    gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable *)appGUI->nte->notes_sort, 
+                                          N_COLUMN_NAME, config.notes_sorting_order);
+
+    gtk_tree_model_filter_refilter(GTK_TREE_MODEL_FILTER(appGUI->nte->notes_filter));
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 gui_create_notes_options_page (GtkWidget *vbox, GUI *appGUI) {
 
-GtkWidget           *appearance_vbox, *encryption_vbox, *categories_vbox;
+GtkWidget           *sorting_vbox, *appearance_vbox, *encryption_vbox, *categories_vbox;
 GtkWidget           *frame;
 GtkWidget           *alignment;
 GtkWidget           *table;
@@ -602,6 +621,80 @@ gchar tmpbuf[BUFFER_SIZE];
                      G_CALLBACK(notes_category_remove_cb), appGUI);
     gtk_widget_set_sensitive(appGUI->opt->notes_category_remove_button, FALSE);
 
+    frame = gtk_frame_new (NULL);
+    gtk_widget_show (frame);
+    gtk_box_pack_start (GTK_BOX (appGUI->opt->notes_vbox), frame, FALSE, TRUE, 0);
+    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
+    sprintf(tmpbuf, "<b>%s</b>", _("Sorting"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_frame_set_label_widget (GTK_FRAME (frame), label);
+    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+    gtk_misc_set_padding (GTK_MISC (label), 0, 4);
+
+    alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
+    gtk_widget_show (alignment);
+    gtk_container_add (GTK_CONTAINER (frame), alignment);
+    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 12, 12, 0);
+
+    sorting_vbox = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (sorting_vbox);
+    gtk_container_add (GTK_CONTAINER (alignment), sorting_vbox);
+
+    table = gtk_table_new (1, 5, FALSE);
+    gtk_widget_show (table);
+    gtk_box_pack_start (GTK_BOX (sorting_vbox), table, FALSE, FALSE, 0);
+    gtk_table_set_row_spacings (GTK_TABLE (table), 4);
+    gtk_table_set_col_spacings (GTK_TABLE (table), 8);
+
+    sprintf(tmpbuf, "%s:", _("Order"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
+                      (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
+                      (GtkAttachOptions) (0), 0, 0);
+    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+
+    sprintf(tmpbuf, "%s:", _("Mode"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_table_attach (GTK_TABLE (table), label, 2, 3, 0, 1,
+                      (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
+                      (GtkAttachOptions) (0), 0, 0);
+    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+
+    appGUI->opt->notes_sort_order_combobox = gtk_combo_box_new_text ();
+    gtk_widget_show (appGUI->opt->notes_sort_order_combobox);
+    g_signal_connect (G_OBJECT (appGUI->opt->notes_sort_order_combobox), "changed",
+                      G_CALLBACK(notes_sort_order_changed_cb), appGUI);
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->notes_sort_order_combobox, 1, 2, 0, 1,
+                      (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
+                      (GtkAttachOptions) (0), 0, 0);
+    gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->opt->notes_sort_order_combobox), _("Ascending"));
+    gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->opt->notes_sort_order_combobox), _("Descending"));
+    gtk_combo_box_set_active (GTK_COMBO_BOX(appGUI->opt->notes_sort_order_combobox), config.notes_sorting_order);
+
+    appGUI->opt->notes_sort_mode_combobox = gtk_combo_box_new_text ();
+    gtk_widget_show (appGUI->opt->notes_sort_mode_combobox);
+    g_signal_connect (G_OBJECT (appGUI->opt->notes_sort_mode_combobox), "changed",
+                      G_CALLBACK(notes_sort_mode_changed_cb), appGUI);
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->notes_sort_mode_combobox, 3, 4, 0, 1,
+                      (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
+                      (GtkAttachOptions) (0), 0, 0);
+    sprintf (tmpbuf, "%s, %s, %s", _("Name"), _("Last changes"), _("Category"));
+    gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->opt->notes_sort_mode_combobox), tmpbuf);
+    sprintf (tmpbuf, "%s, %s, %s", _("Name"), _("Category"), _("Last changes"));
+    gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->opt->notes_sort_mode_combobox), tmpbuf);
+    sprintf (tmpbuf, "%s, %s, %s", _("Category"), _("Last changes"), _("Name"));
+    gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->opt->notes_sort_mode_combobox), tmpbuf);
+    sprintf (tmpbuf, "%s, %s, %s", _("Category"), _("Name"), _("Last changes"));
+    gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->opt->notes_sort_mode_combobox), tmpbuf);
+    sprintf (tmpbuf, "%s, %s, %s", _("Last changes"), _("Category"), _("Name"));
+    gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->opt->notes_sort_mode_combobox), tmpbuf);
+    sprintf (tmpbuf, "%s, %s, %s", _("Last changes"), _("Name"), _("Category"));
+    gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->opt->notes_sort_mode_combobox), tmpbuf);
+    gtk_combo_box_set_active (GTK_COMBO_BOX(appGUI->opt->notes_sort_mode_combobox), config.notes_sorting_mode);
+
 }
 
 /*------------------------------------------------------------------------------*/
