@@ -19,20 +19,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include <stdio.h>
-#include <string.h>
-#include <ctype.h>
-#include <time.h>
-#include <glib/gprintf.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <sys/stat.h>
-#include <glib.h>
-#include <limits.h>
-#include <libxml/xmlmemory.h>
-#include <libxml/parser.h>
-
-#include "gui.h"
+#include "options_gui_tasks.h"
 #include "gui_utils.h"
 #include "calendar.h"
 #include "calendar_notes.h"
@@ -45,7 +32,6 @@
 #include "contacts.h"
 #include "stock_icons.h"
 
-
 /*------------------------------------------------------------------------------*/
 
 void
@@ -116,6 +102,45 @@ delete_items_cb (GtkToggleButton *togglebutton, gpointer user_data) {
 
 /*------------------------------------------------------------------------------*/
 
+void
+add_item_cb (GtkToggleButton *togglebutton, gpointer user_data) {
+
+    config.add_edit = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (togglebutton));
+}
+
+/*------------------------------------------------------------------------------*/
+
+gboolean
+tasks_category_get_state (gchar *category_name, gint type, GUI *appGUI) {
+
+GtkTreeIter iter;
+gboolean state = TRUE;
+gchar *item;
+gint i;
+
+    i = 0;
+
+    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->opt->tasks_category_store), &iter, NULL, i++)) {
+        gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->tasks_category_store), &iter, TC_COLUMN_NAME, &item, -1);
+        if (item != NULL && category_name != NULL) {
+            if (!strcmp(category_name, item)) {
+                if (type == STATE_CALENDAR) {
+                    gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->tasks_category_store), &iter, TC_COLUMN_CALENDAR, &state, -1);
+                } else if (type == STATE_TASKS) {
+                    gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->tasks_category_store), &iter, TC_COLUMN_TASKS, &state, -1);
+                }
+                g_free(item);
+                break;
+            }
+        }
+        g_free(item);
+    }
+
+    return state;
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 tasks_category_add_cb (GtkWidget *widget, gpointer data) {
 
@@ -133,7 +158,7 @@ gchar *item;
         i = 0;
 
         while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->opt->tasks_category_store), &iter, NULL, i++)) {
-            gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->tasks_category_store), &iter, 0, &item, -1);
+            gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->tasks_category_store), &iter, TC_COLUMN_NAME, &item, -1);
             if (!strcmp(category_name, item)) {
                 g_free(item);
                 return;
@@ -144,7 +169,8 @@ gchar *item;
         gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->opt->tasks_category_store), &iter, NULL, 0);
 
         gtk_list_store_append(appGUI->opt->tasks_category_store, &iter);
-        gtk_list_store_set(appGUI->opt->tasks_category_store, &iter, 0, category_name, -1);
+        gtk_list_store_set(appGUI->opt->tasks_category_store, &iter, 
+                           TC_COLUMN_NAME, category_name, TC_COLUMN_CALENDAR, TRUE, TC_COLUMN_TASKS, TRUE, -1);
         gtk_entry_set_text(GTK_ENTRY(appGUI->opt->tasks_category_entry), "");
         gtk_widget_set_sensitive(appGUI->opt->tasks_category_add_button, FALSE);
 
@@ -174,6 +200,7 @@ GtkTreePath *path;
         gtk_tree_model_get_iter(GTK_TREE_MODEL(appGUI->opt->tasks_category_store), &iter, path);
         gtk_list_store_remove(appGUI->opt->tasks_category_store, &iter);
         gtk_tree_path_free(path);
+        refresh_tasks (appGUI);
     }
 }
 
@@ -217,6 +244,7 @@ GdkColor color;
     gtk_color_button_get_color(GTK_COLOR_BUTTON(appGUI->opt->due_today_color_picker), &color);
     sprintf(tmpbuf, "#%02X%02X%02X", color.red * 256 / 65536, color.green * 256 / 65536, color.blue * 256 / 65536);
     strncpy(config.due_today_color, tmpbuf, MAXCOLORNAME-1);
+    refresh_tasks (appGUI);
 
 }
 
@@ -233,6 +261,7 @@ GdkColor color;
     gtk_color_button_get_color(GTK_COLOR_BUTTON(appGUI->opt->due_7days_color_picker), &color);
     sprintf(tmpbuf, "#%02X%02X%02X", color.red * 256 / 65536, color.green * 256 / 65536, color.blue * 256 / 65536);
     strncpy(config.due_7days_color, tmpbuf, MAXCOLORNAME-1);
+    refresh_tasks (appGUI);
 
 }
 
@@ -249,6 +278,7 @@ GdkColor color;
     gtk_color_button_get_color(GTK_COLOR_BUTTON(appGUI->opt->past_due_color_picker), &color);
     sprintf(tmpbuf, "#%02X%02X%02X", color.red * 256 / 65536, color.green * 256 / 65536, color.blue * 256 / 65536);
     strncpy(config.past_due_color, tmpbuf, MAXCOLORNAME-1);
+    refresh_tasks (appGUI);
 
 }
 
@@ -276,6 +306,8 @@ visible_columns_changed_cb (GtkComboBox *widget, gpointer user_data) {
 
     config.visible_due_date_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->vc_due_date_checkbutton));
     gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_DUE_DATE], config.visible_due_date_column);
+    config.visible_type_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->vc_type_checkbutton));
+    gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_TYPE], config.visible_type_column);
     config.visible_category_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->vc_category_checkbutton));
     gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_CATEGORY], config.visible_category_column);
     config.visible_priority_column = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->vc_priority_checkbutton));
@@ -370,13 +402,75 @@ GtkTreeModel *model;
     if (g_ascii_strcasecmp (new_text, "") != 0) {
         model = gtk_tree_view_get_model (GTK_TREE_VIEW(appGUI->opt->tasks_category_treeview));
         if (gtk_tree_model_get_iter_from_string (model, &iter, path)) {
-            gtk_list_store_set(appGUI->opt->tasks_category_store, &iter, 0, new_text, -1);
+            gtk_list_store_set(appGUI->opt->tasks_category_store, &iter, TC_COLUMN_NAME, new_text, -1);
         }
     }
 }
 
 /*------------------------------------------------------------------------------*/
 
+void
+postpone_time_changed_cb (GtkSpinButton *spinbutton, gpointer user_data) {
+
+    GUI *appGUI = (GUI *)user_data;
+
+    if (!appGUI->opt->callback_active) return;
+
+    config.postpone_time = (gint) gtk_spin_button_get_value (GTK_SPIN_BUTTON(appGUI->opt->postpone_time_spinbutton));
+
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+tsk_show_in_calendar_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data) {
+
+GtkTreePath *path;
+GtkTreeIter  iter;
+gboolean done_status;
+GtkTreeModel *model;
+
+    GUI *appGUI = (GUI *)data;
+    model = GTK_TREE_MODEL(appGUI->opt->tasks_category_store);
+
+    path = gtk_tree_path_new_from_string (path_str);
+
+    if (path != NULL) {
+        gtk_tree_model_get_iter (model, &iter, path);   /* get toggled iter */
+        gtk_tree_model_get (model, &iter, TC_COLUMN_CALENDAR, &done_status, -1);
+        gtk_list_store_set (GTK_LIST_STORE(model), &iter, TC_COLUMN_CALENDAR, !done_status, -1);
+        set_day_info (appGUI->cal->day, appGUI->cal->month, appGUI->cal->year, appGUI);
+        calendar_refresh_marks (appGUI);
+        gtk_tree_path_free (path);
+    }
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+tsk_show_in_tasks_list_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data) {
+
+GtkTreePath *path;
+GtkTreeIter  iter;
+gboolean done_status;
+GtkTreeModel *model;
+
+    GUI *appGUI = (GUI *)data;
+    model = GTK_TREE_MODEL(appGUI->opt->tasks_category_store);
+
+    path = gtk_tree_path_new_from_string (path_str);
+
+    if (path != NULL) {
+        gtk_tree_model_get_iter (model, &iter, path);   /* get toggled iter */
+        gtk_tree_model_get (model, &iter, TC_COLUMN_TASKS, &done_status, -1);
+        gtk_list_store_set (GTK_LIST_STORE(model), &iter, TC_COLUMN_TASKS, !done_status, -1);
+        refresh_tasks (appGUI);
+        gtk_tree_path_free (path);
+    }
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 gui_create_tasks_options_page   (GtkWidget *vbox, GUI *appGUI) {
 
@@ -393,6 +487,7 @@ GtkWidget           *tasks_category_table;
 GtkCellRenderer     *renderer;
 GtkTreeViewColumn   *column;
 GdkColor            color;
+GtkObject           *postpone_time_spinbutton_adj;
 
 gchar tmpbuf[BUFFER_SIZE];
 
@@ -524,7 +619,7 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_widget_show (visible_columns_vbox);
     gtk_container_add (GTK_CONTAINER (alignment), visible_columns_vbox);
 
-    table = gtk_table_new (1, 3, FALSE);
+    table = gtk_table_new (1, 4, FALSE);
     gtk_widget_show (table);
     gtk_box_pack_start (GTK_BOX (visible_columns_vbox), table, FALSE, FALSE, 0);
     gtk_table_set_row_spacings (GTK_TABLE (table), 4);
@@ -539,12 +634,21 @@ gchar tmpbuf[BUFFER_SIZE];
                       (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
                       (GtkAttachOptions) (0), 0, 0);
 
+    appGUI->opt->vc_type_checkbutton = gtk_check_button_new_with_mnemonic (_("Type"));
+    GTK_WIDGET_UNSET_FLAGS(appGUI->opt->vc_type_checkbutton, GTK_CAN_FOCUS);
+    gtk_widget_show (appGUI->opt->vc_type_checkbutton);
+    g_signal_connect (G_OBJECT (appGUI->opt->vc_type_checkbutton), "toggled",
+                      G_CALLBACK (visible_columns_changed_cb), appGUI);
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->vc_type_checkbutton, 1, 2, 0, 1,
+                      (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
+                      (GtkAttachOptions) (0), 0, 0);
+
     appGUI->opt->vc_priority_checkbutton = gtk_check_button_new_with_mnemonic (_("Priority"));
     GTK_WIDGET_UNSET_FLAGS(appGUI->opt->vc_priority_checkbutton, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->opt->vc_priority_checkbutton);
     g_signal_connect (G_OBJECT (appGUI->opt->vc_priority_checkbutton), "toggled",
                       G_CALLBACK (visible_columns_changed_cb), appGUI);
-    gtk_table_attach (GTK_TABLE (table), appGUI->opt->vc_priority_checkbutton, 1, 2, 0, 1,
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->vc_priority_checkbutton, 2, 3, 0, 1,
                       (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
                       (GtkAttachOptions) (0), 0, 0);
 
@@ -553,7 +657,7 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_widget_show (appGUI->opt->vc_category_checkbutton);
     g_signal_connect (G_OBJECT (appGUI->opt->vc_category_checkbutton), "toggled",
                       G_CALLBACK (visible_columns_changed_cb), appGUI);
-    gtk_table_attach (GTK_TABLE (table), appGUI->opt->vc_category_checkbutton, 2, 3, 0, 1,
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->vc_category_checkbutton, 3, 4, 0, 1,
                       (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
                       (GtkAttachOptions) (0), 0, 0);
 
@@ -601,7 +705,7 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
     gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow), GTK_SHADOW_IN);
 
-    appGUI->opt->tasks_category_store = gtk_list_store_new(1, G_TYPE_STRING);
+    appGUI->opt->tasks_category_store = gtk_list_store_new(3, G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN);
 
     appGUI->opt->tasks_category_treeview = gtk_tree_view_new_with_model(GTK_TREE_MODEL(appGUI->opt->tasks_category_store));
     appGUI->opt->tasks_category_select = gtk_tree_view_get_selection(GTK_TREE_VIEW(appGUI->opt->tasks_category_treeview));
@@ -610,17 +714,30 @@ gchar tmpbuf[BUFFER_SIZE];
                      G_CALLBACK(tasks_category_selected_cb), appGUI);   
     gtk_container_add (GTK_CONTAINER (scrolledwindow), appGUI->opt->tasks_category_treeview);
     gtk_container_set_border_width (GTK_CONTAINER (appGUI->opt->tasks_category_treeview), 4);
-    gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (appGUI->opt->tasks_category_treeview), FALSE);
+    gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (appGUI->opt->tasks_category_treeview), TRUE);
     gtk_tree_view_set_reorderable (GTK_TREE_VIEW (appGUI->opt->tasks_category_treeview), TRUE);
     gtk_tree_view_set_enable_search (GTK_TREE_VIEW (appGUI->opt->tasks_category_treeview), FALSE);
-    gtk_widget_set_size_request (appGUI->opt->tasks_category_treeview, -1, 80);
+    gtk_widget_set_size_request (appGUI->opt->tasks_category_treeview, -1, 120);
 
     renderer = gtk_cell_renderer_text_new();
     g_object_set (renderer, "editable", TRUE, "editable-set", TRUE, NULL);
     g_signal_connect (G_OBJECT (renderer), "edited", G_CALLBACK (tasks_category_cell_edited_cb), appGUI);
 
-    column = gtk_tree_view_column_new_with_attributes(NULL, renderer, "text", 0, NULL);
+    column = gtk_tree_view_column_new_with_attributes(_("Name"), renderer, "text", TC_COLUMN_NAME, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->opt->tasks_category_treeview), column);
+    gtk_tree_view_column_set_expand (column, TRUE);
+
+    renderer = gtk_cell_renderer_toggle_new();    /* Show in calendar */
+    column = gtk_tree_view_column_new_with_attributes(_("Calendar"), renderer, "active", TC_COLUMN_CALENDAR, NULL);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->opt->tasks_category_treeview), column);
+    
+    g_signal_connect (renderer, "toggled", G_CALLBACK (tsk_show_in_calendar_toggled), appGUI);
+
+    renderer = gtk_cell_renderer_toggle_new();    /* Show in tasks list */
+    column = gtk_tree_view_column_new_with_attributes(_("Tasks"), renderer, "active", TC_COLUMN_TASKS, NULL);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->opt->tasks_category_treeview), column);
+
+    g_signal_connect (renderer, "toggled", G_CALLBACK (tsk_show_in_tasks_list_toggled), appGUI);
 
     if (config.default_stock_icons) {
         appGUI->opt->tasks_category_add_button = gui_stock_button(GTK_STOCK_ADD, FALSE);
@@ -769,6 +886,64 @@ gchar tmpbuf[BUFFER_SIZE];
     g_signal_connect (G_OBJECT (appGUI->opt->ct_delete_items_checkbutton), "toggled",
                       G_CALLBACK (delete_items_cb), appGUI);
 
+    appGUI->opt->ct_add_item_checkbutton = gtk_check_button_new_with_mnemonic (_("Add new task when double clicked on tasks list"));
+    GTK_WIDGET_UNSET_FLAGS(appGUI->opt->ct_add_item_checkbutton, GTK_CAN_FOCUS);
+    gtk_widget_show (appGUI->opt->ct_add_item_checkbutton);
+    gtk_box_pack_start (GTK_BOX (tasks_opt_vbox), appGUI->opt->ct_add_item_checkbutton, FALSE, FALSE, 4);
+    g_signal_connect (G_OBJECT (appGUI->opt->ct_add_item_checkbutton), "toggled",
+                      G_CALLBACK (add_item_cb), appGUI);
+
+    frame = gtk_frame_new (NULL);
+    gtk_widget_show (frame);
+    gtk_box_pack_start (GTK_BOX (appGUI->opt->tasks_vbox), frame, FALSE, TRUE, 0);
+    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
+    g_snprintf (tmpbuf, BUFFER_SIZE, "<b>%s</b>", _("Reminder options"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_frame_set_label_widget (GTK_FRAME (frame), label);
+    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+    gtk_misc_set_padding (GTK_MISC (label), 0, 4);
+
+    alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
+    gtk_widget_show (alignment);
+    gtk_container_add (GTK_CONTAINER (frame), alignment);
+    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 12, 12, 0);
+
+    table = gtk_table_new (1, 4, FALSE);
+    gtk_widget_show (table);
+    gtk_container_add (GTK_CONTAINER (alignment), table);
+    gtk_container_set_border_width (GTK_CONTAINER (table), 4);
+    gtk_table_set_col_spacings (GTK_TABLE (table), 4);
+    gtk_table_set_row_spacings (GTK_TABLE (table), 8);
+
+    g_snprintf (tmpbuf, BUFFER_SIZE, "%s:", _("Postpone time"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
+                      (GtkAttachOptions) (GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
+    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+
+    postpone_time_spinbutton_adj = gtk_adjustment_new (0, 0, 60, 1, 10, 10);
+    appGUI->opt->postpone_time_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (postpone_time_spinbutton_adj), 1, 0);
+    g_signal_connect (G_OBJECT (appGUI->opt->postpone_time_spinbutton), "value-changed",
+                      G_CALLBACK (postpone_time_changed_cb), appGUI);
+    gtk_widget_show (appGUI->opt->postpone_time_spinbutton);
+    gtk_table_attach (GTK_TABLE (table), appGUI->opt->postpone_time_spinbutton, 1, 2, 0, 1,
+                      (GtkAttachOptions) (GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
+    gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (appGUI->opt->postpone_time_spinbutton), TRUE);
+
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON(appGUI->opt->postpone_time_spinbutton), config.postpone_time);
+
+    g_snprintf (tmpbuf, BUFFER_SIZE, "%s (%s)", _("minutes"), _("0 for disable"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_table_attach (GTK_TABLE (table), label, 2, 3, 0, 1,
+                      (GtkAttachOptions) (GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
+    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+
 }
 
 /*------------------------------------------------------------------------------*/
