@@ -24,7 +24,19 @@
 
 #include "gui.h"
 
-void    gui_create_tasks_options_page   (GtkWidget *vbox, GUI *appGUI);
+enum {
+    TC_COLUMN_NAME = 0,
+    TC_COLUMN_CALENDAR,
+    TC_COLUMN_TASKS
+};
+
+enum {
+    STATE_CALENDAR = 0,
+    STATE_TASKS
+};
+
+void        gui_create_tasks_options_page       (GtkWidget *vbox, GUI *appGUI);
+gboolean    tasks_category_get_state            (gchar *category_name, gint type, GUI *appGUI);
 
 #endif /* _OPTIONS_GUI_TASKS_H */
 
