@@ -22,6 +22,8 @@
 #ifndef _OPTIONS_PREFS_H
 #define _OPTIONS_PREFS_H
 
+#include "gui.h"
+
 #define CONFIG_DIRNAME      ".osmo"
 #define CONFIG_FILENAME     "config.xml"
 #define CONFIG_NAME         "osmo_config"
@@ -30,6 +32,7 @@
 #define MAXCOLORNAME        128
 #define MAXHELPERCMD        1024
 #define MAXCONTACTFIELDS    512
+#define MAXADDRESS          64
 
 struct osmo_prefs
 {
@@ -62,30 +65,40 @@ struct osmo_prefs
     gint        fy_window_size_x;
     gint        fy_window_size_y;
     gint        fy_simple_view;
+    gint        fy_alternative_view;
     gint        display_options;
     gint        day_notes_visible;
     gint        timeline_start;
     gint        timeline_end;
     gint        timeline_step;
-    gint        mark_symbol;
     gint        di_show_current_time;
     gint        di_show_day_number;
+    gint        di_show_current_day_distance;
     gint        di_show_marked_days;
     gint        di_show_week_number;
     gint        di_show_weekend_days;
+    gint        di_show_day_category;
     gint        di_show_moon_phase;
     gint        di_show_notes;
     gint        di_show_zodiac_sign;
     gint        cursor_type;
     gint        frame_cursor_thickness;
     gint        enable_auxilary_calendars;
+    gint        enable_day_mark;
     gint        strikethrough_past_notes;
+    gint        ascending_sorting_in_day_notes_browser;
     gint        auxilary_calendars_state;
-    gint        marker_type;
+    gchar       day_note_marker;
+    gint        event_marker_type;
+    gint        today_marker_type;
+    gint        day_notes_browser_filter;
     gchar       header_color[MAXCOLORNAME];
     gchar       weekend_color[MAXCOLORNAME];
     gchar       selection_color[MAXCOLORNAME];
+    gint        selector_alpha;
     gchar       mark_color[MAXCOLORNAME];
+    gchar       mark_current_day_color[MAXCOLORNAME];
+    gint        mark_current_day_alpha;
     gchar       day_name_font[MAXFONTNAME];
     gchar       calendar_font[MAXFONTNAME];
     gchar       notes_font[MAXFONTNAME];
@@ -95,16 +108,19 @@ struct osmo_prefs
     gint        tasks_high_in_bold;
     gint        hide_completed;
     gint        delete_completed;
+    gint        add_edit;
     gint        tasks_pane_pos;
     gint        tasks_sorting_order;
     gint        tasks_sorting_mode;
     gint        visible_due_date_column;
+    gint        visible_type_column;
     gint        visible_priority_column;
     gint        visible_category_column;
     gint        tasks_addedit_win_x;
     gint        tasks_addedit_win_y;
     gint        tasks_addedit_win_w;
     gint        tasks_addedit_win_h;
+    gint        postpone_time;
     gchar       due_today_color[MAXCOLORNAME];
     gchar       due_7days_color[MAXCOLORNAME];
     gchar       past_due_color[MAXCOLORNAME];
@@ -117,8 +133,6 @@ struct osmo_prefs
     gint        contacts_pane_pos;
     gint        contacts_rules_hint;
     gint        photo_width;
-    gint        name_font_size;
-    gint        tags_font_size;
     gint        contacts_sorting_order;
     gint        contacts_sorting_mode;
     gint        contacts_addedit_win_x;
@@ -129,12 +143,22 @@ struct osmo_prefs
     gint        contacts_export_win_y;
     gint        contacts_export_win_w;
     gint        contacts_export_win_h;
+    gint        contacts_import_sel_win_x;
+    gint        contacts_import_sel_win_y;
     gint        contacts_import_win_x;
     gint        contacts_import_win_y;
     gint        contacts_import_win_w;
     gint        contacts_import_win_h;
     gchar       contact_tag_color[MAXCOLORNAME];
     gchar       contact_link_color[MAXCOLORNAME];
+    gchar       contact_name_font[MAXFONTNAME];
+    gchar       contact_item_font[MAXFONTNAME];
+    gint        import_type;
+    gint        import_interface_type;
+    gint        import_bluetooth_channel;
+    gint        import_usb_interface;
+    gint        import_binary_xml;
+    gchar       import_bluetooth_address[MAXADDRESS];
     gint        export_format;
     gchar       export_fields[MAXCONTACTFIELDS];
 
@@ -144,14 +168,16 @@ struct osmo_prefs
     gint        notes_enc_hashing;
     gint        notes_comp_algorithm;
     gint        notes_comp_ratio;
+    gint        notes_sorting_order;
+    gint        notes_sorting_mode;
     gchar       notes_editor_font[MAXFONTNAME];
 };
 
 extern  struct osmo_prefs     config;
 
-gchar*  prefs_get_config_filename   (gchar *config_filename);
-void    prefs_read_config           (void);
-void    prefs_write_config          (void);
+gchar*  prefs_get_config_filename   (gchar *config_filename, GUI *appGUI);
+void    prefs_read_config           (GUI *appGUI);
+void    prefs_write_config          (GUI *appGUI);
 
 #endif /* _OPTIONS_PREFS_H */
 
