@@ -22,7 +22,7 @@
 #ifndef _STOCK_ICONS_H
 #define _STOCK_ICONS_H
 
-#define     TRANSLATION_DOMAIN                  "osmo"
+#include "gui.h"
 
 #define     OSMO_STOCK_BUTTON_ADD               "osmo-button-add"
 #define     OSMO_STOCK_BUTTON_CLEAR             "osmo-button-clear"
@@ -90,7 +90,10 @@
 #define     OSMO_STOCK_TASKS_ADD                "osmo-tasks-add"
 #define     OSMO_STOCK_TASKS_EDIT               "osmo-tasks-edit"
 #define     OSMO_STOCK_TASKS_REMOVE             "osmo-tasks-remove"
-#define     OSMO_STOCK_TASKS                    "osmo-tasks"
+#define     OSMO_STOCK_TASKS_PREV_DAY           "osmo-tasks-prev-day"
+#define     OSMO_STOCK_TASKS_NEXT_DAY           "osmo-tasks-next-day"
+#define     OSMO_STOCK_TASKS_TYPE_NORMAL        "osmo-tasks-type-normal"
+#define     OSMO_STOCK_TASKS_TYPE_RECURRENT     "osmo-tasks-type-recurrent"
 #define     OSMO_STOCK_TASKS                    "osmo-tasks"
 #define     OSMO_STOCK_TODAY                    "osmo-today"
 
