@@ -32,16 +32,47 @@
 #define MAX_SUMMARY_SIZE            512     /* max summary string size */
 #define MAX_DATE_SIZE               12      /* max data string size */
 
+#define WHOLE_WEEK                  127
+
+typedef struct {
+    gboolean done;
+    guint32 due_date_julian;
+    gint due_time;
+    guint32 start_date_julian;
+    gchar *priority;
+    gchar *category;
+    gchar *summary;
+    gchar *desc;
+	gboolean active;
+	gboolean active_warning;
+	gboolean offline_ignore;
+	gboolean repeat;
+	gint repeat_day;
+	gint repeat_month_interval;
+	gint repeat_day_interval;
+	gint repeat_start_day;
+	gint repeat_time_start;
+	gint repeat_time_end;
+	gint repeat_time_interval;
+	gint repeat_counter;
+	gchar *alarm_command;
+	gint warning_days;
+	gint warning_time;
+} TASK_ITEM;
+
 void    gui_create_tasks                        (GUI *appGUI);
 void    update_tasks_number                     (GUI *appGUI);
 gint    get_priority_index                      (gchar *text);
 gchar*  get_priority_text                       (gint index);
+gint    task_calculate_new_date                 (TASK_ITEM *item, GUI *appGUI, guint32 *new_date, gint *new_time);
+void    tasks_repeat_done                       (GtkTreeIter *iter, TASK_ITEM *item, GUI *appGUI);
 void    show_tasks_desc_panel                   (gboolean enable, GUI *appGUI);
-void    tasks_fill_fields                       (GtkWidget *due_date_entry, GtkWidget *summary_entry, GtkWidget *desc_entry, GUI *appGUI);
 void    tasks_select_first_position_in_list     (GUI *appGUI);
 void    apply_task_attributes                   (GUI *appGUI);
-void    refresh_due_dates                       (GUI *appGUI);
-void    add_item_to_list                        (gboolean done, guint32 due_date_julian, guint32 start_date_julian, gchar *priority, gchar *category, gchar *summary, gchar *desc, GUI *appGUI);
+void    refresh_tasks                           (GUI *appGUI);
+void    add_item_to_list                        (TASK_ITEM *item, GUI *appGUI);
+gchar*  get_date_color                          (guint32 julian_day, gint time, gboolean done);
+void    tasks_selection_activate                (gboolean active, GUI *appGUI);
 
 #endif /* _TASKS_H */
 
